HousProf:
/*--generate 2000 SF3 housing profile.
    Julie Hoang, California SDC - pages 1-2
    Jeff Wallace, Oklahoma SDC - pages 3-4
-----*/

* do all 4 pages if _pages is null, blank or ALL ;
IF _pages IN ('',' ','all','ALL') THEN _pages='1234' ;

*--generate housing profile, page 1. --*;
    
IF INDEX(_pages,'1') THEN DO;

%PutTitle(
   %STR(Housing Profile 1: SUMMARY; HH SIZE; UNITS IN STRUCTURE; HEATING FUEL; VEHICLES; YEAR BUILT),
   %STR(Housing-1) ) ;

**--Draw horizontal lines--**;
PUT #22 @44 47*'_' @92 57*'_' ;
PUT #43 @2 148*'_';

**--Draw (internal) vertical lines--**;
do _i_=6 to 42;
  PUT #_I_ @43 '|' @91 '|' ;
  end;
do _i_=44 to 61;
  PUT #_I_ @83 '|' ;
  end;

  **--Generate tables H1-H8.--**;
if h1i1>0 then persamp = (h2i1/h1i1)*100;
else persamp = .;

PUT #6
    @2 'H1/H2/H3/H4/H5/H6/H7/H8. HOUSING SUMMARY'
  / @2 'Universe: Housing Units'
  /
  / @2 'Total Housing Units' @31 h1i1 comma11. 
  / @2 '100% Count of Housing Units' @31 h3i1 comma11. 
 // @2 'Unweighted Sample Units--' 
  / @2 ' Total:' @31 h2i1 comma11.
  / @2 '   Occupied' @31 h2i2 comma11.
  / @2 '   Vacant' @31 h2i3 comma11.
 // @2 'Percent of Units in Sample--' 
  / @2 ' Total:' @31 persamp 10.1 '%'
  / @2 '   Occupied' @31 h4i1 10.1 '%'
  / @2 '   Vacant' @31 h4i2 10.1 '%'
 // @2 'Total Housing Units:'
  / @2 ' Urban:' @31 h5i2 comma11.
  / @2 '  Inside Urbanized Areas' @31 h5i3 comma11.
  / @2 '  Inside Urban Clusters' @31 h5i4 comma11.
  / @2 ' Rural:' @31 h5i5 comma11.
  / @2 '  Farm' @31 h5i6 comma11.
  / @2 '  NonFarm' @31 h5i7 comma11.
 // @2 'Occupied Housing Units:' @31 h7i1 comma11.
  / @2 ' Owner Occupied' @31 h7i2 comma11.
  / @2 ' Renter Occupied' @31 h7i3 comma11.
 // @2 'Vacant Housing Units:' @31 h8i1 comma11.
  / @2 ' For Rent' @31 h8i2 comma11.
  / @2 ' For Sale Only' @31 h8i3 comma11.
  / @2 ' Rented/Sold, Not Occupied' @31 h8i4 comma11.
  / @2 ' For Seasonal, Recreational,'
  / @2 '  or Occasional Use' @31 h8i5 comma11.
  / @2 ' For Migrant Workers' @31 h8i6 comma11.
  / @2 ' Other Vacant' @31 h8i7 comma11.
;

**--Generate tables H44/H46.--**;
array h44t{6};
array h44o1{6} h44i3-h44i8;
array h44r2{6} h44i10-h44i15;

do i=1 to 6;
h44t{i}=h44o1{i}+h44r2{i};
end;

if h44i1>0 then avtveh = h46i1/h44i1;
 else avtveh = .;
if h44i2>0 then avoveh = h46i2/h44i2;
 else avoveh = .;
if h44i9>0 then avrveh = h46i3/h44i9;
 else avrveh = .;

PUT #6
    @44 'H44/H46. VEHICLES AVAILABLE BY TENURE'
  / @44 'Universe: Occupied Housing Units'
  /
  / @60 'Occupied'    @74 'Owner' @84 'Renter' 
  / @63 'Units'    @71 'Occupied   Occupied' 
  /
  / @44 'Total Units:' @57 h44i1 comma11. @69 h44i2 comma10. @80 h44i9 comma10.
  / @44 ' No Vehicle' @57 h44t1 comma11. @69 h44i3 comma10. @80 h44i10 comma10.
  / @44 ' 1 Vehicle' @57 h44t2 comma11. @69 h44i4 comma10. @80 h44i11 comma10.
  / @44 ' 2 Vehicles' @57 h44t3 comma11. @69 h44i5 comma10. @80 h44i12 comma10.
  / @44 ' 3 Vehicles' @57 h44t4 comma11. @69 h44i6 comma10. @80 h44i13 comma10.
  / @44 ' 4 Vehicles' @57 h44t5 comma11. @69 h44i7 comma10. @80 h44i14 comma10.
  / @44 ' 5+ Vehicles' @57 h44t6 comma11. @69 h44i8 comma10. @80 h44i15 comma10.
 // @44 'Mean Vehicles'
  / @44 'Available' @62 avtveh 6.2 @73 avoveh 6.2 @84 avrveh 6.2
;

**--Generate tables H16-H18.--**;

PUT #23
    @44 'H16/H17/H18. HOUSEHOLD SIZE BY TENURE'
  / @44 'Universe: Occupied Housing Units'
 // @44 'Household' @60 'Occupied'   @74 'Owner'   @84 'Renter'
  / @46 'Size--'    @63 'Units'   @71 'Occupied' @82 'Occupied' 
  /
  / @44 'Total Units:' @57 h16i1 comma11. @69 h17i2 comma10. @80 h17i10 comma10.
  / @44 ' 1 Person' @57 h16i2 comma11. @69 h17i3 comma10. @80 h17i11 comma10. 
  / @44 ' 2 Persons' @57 h16i3 comma11. @69 h17i4 comma10. @80 h17i12 comma10. 
  / @44 ' 3 Persons' @57 h16i4 comma11. @69 h17i5 comma10. @80 h17i13 comma10. 
  / @44 ' 4 Persons' @57 h16i5 comma11. @69 h17i6 comma10. @80 h17i14 comma10. 
  / @44 ' 5 Persons' @57 h16i6 comma11. @69 h17i7 comma10. @80 h17i15 comma10. 
  / @44 ' 6 Persons' @57 h16i7 comma11. @69 h17i8 comma10. @80 h17i16 comma10. 
  / @44 ' 7+ Persons' @57 h16i8 comma11. @69 h17i9 comma10. @80 h17i17 comma10. 
 // @44 'Mean' 
  / @44 'Household Size' @62 h18i1 6.2 @73 h18i2 6.2 @84 h18i3 6.2 
;

**--Generate tables H40/HCT10.--**;

Put #6
    @92 'H40/HCT10. HOUSE HEATING FUEL BY TENURE'
  / @92 'Universe: Occupied Housing Units' 
  /   @118 'Occupied'      @132 'Owner' @142 'Renter'
  /      @121 'Units'   @129 'Occupied' @140 'Occupied'
  /
  / @92 'Total Units:' @115 h40i1 comma11. @127 hct10i2 comma10. @138 hct10i12 comma10.
  / @92 ' Utility Gas' @115 h40i2 comma11. @127 hct10i3 comma10. @138 hct10i13 comma10. 
  / @92 ' Bottled, Tank, LP Gas ' @115 h40i3 comma11. @127 hct10i4 comma10. @138 hct10i14 comma10.
  / @92 ' Electricity' @115 h40i4 comma11. @127 hct10i5 comma10. @138 hct10i15 comma10. 
  / @92 ' Fuel Oil,Kerosine,etc.' @115 h40i5 comma11. @127 hct10i6 comma10. @138 hct10i16 comma10.
  / @92 ' Coal or Coke' @115 h40i6 comma11. @127 hct10i7 comma10. @138 hct10i17 comma10. 
  / @92 ' Wood' @115 h40i7 comma11. @127 hct10i8 comma10. @138 hct10i18 comma10.
  / @92 ' Solar Energy' @115 h40i8 comma11. @127 hct10i9 comma10. @138 hct10i19 comma10. 
  / @92 ' Other Fuel' @115 h40i9 comma11. @127 hct10i10 comma10. @138 hct10i20 comma10.
  / @92 ' No Fuel Used' @115 h40i10 comma11. @127 hct10i11 comma10. @138 hct10i21 comma10.
;

**--Generate tables H34-H37.--**;

Put #23
    @92 'H34/H35/H36/H37. YEAR STRUCTURE BUILT BY TENURE'
  / @92 'Universe: Housing Units' 
  / @117 '    All' @126 'Occupied Housing Units'
  / @117 'Housing'     @131 'Owner' @142 'Renter'
  / @92 'Year Built--' @119 'Units' @128 'Occupied' @140 'Occupied'
 // @92 'Total Units:' @113  h34i1 comma11. @126 h36i2 comma10. @138 h36i12 comma10.
  / @92 ' 1999 to March 2000' @113  h34i2 comma11. @126 h36i3 comma10. @138 h36i13 comma10.
  / @92 ' 1995 to 1998' @113  h34i3 comma11. @126 h36i4 comma10. @138 h36i14 comma10.
  / @92 ' 1990 to 1994' @113  h34i4 comma11. @126 h36i5 comma10. @138 h36i15 comma10.
  / @92 ' 1980 to 1989' @113  h34i5 comma11. @126 h36i6 comma10. @138 h36i16 comma10.
  / @92 ' 1970 to 1979' @113  h34i6 comma11. @126 h36i7 comma10. @138 h36i17 comma10.
  / @92 ' 1960 to 1969' @113  h34i7 comma11. @126 h36i8 comma10. @138 h36i18 comma10.
  / @92 ' 1950 to 1959' @113  h34i8 comma11. @126 h36i9 comma10. @138 h36i19 comma10.
  / @92 ' 1940 to 1949' @113  h34i9 comma11. @126 h36i10 comma10. @138 h36i20 comma10.
  / @92 ' 1939 or Earlier' @113  h34i10 comma11. @126 h36i11 comma10. @138 h36i21 comma10.
 // @92 'Median Year Built' @120  h35i1 4.0 @133 h37i2 4.0 @144 h37i3 4.0
  ;

**--generate tables H30-H32--**;
array h32t{11};
array h32ow{11} h32i2-h32i12;
array h32rt{11} h32i13-h32i23;

do i=1 to 11;
h32t{i}=h32ow{i}+h32rt{i};
end;
Put #44
    @2  'H30/H31/H32. UNITS IN STRUCTURE BY TENURE/VACANCY STATUS'
  / @2  'Universe: Housing Units'
  / @29 '  All'  @76 'Vacant'
  / @27 'Housing' @37 '---- Occupied Housing Units ---- :' @75 'Housing' 
  / @29 'Units' @42 'Total' @53 'Owner' @63 'Renter :' @77 'Units'
  / @70 ':'
  / @2 'Total Units:' @23 H30i1 comma11. @36 h32t1 comma11. @48 h32i2 comma10. @59 h32i13 comma10. @70 ':' @72 h31i1 comma10.
  / @2 ' 1, Detached' @23 H30i2 comma11. @36 h32t2 comma11. @48 h32i3 comma10. @59 h32i14 comma10. @70 ':' @72 h31i2 comma10.
  / @2 ' 1, Attached' @23 H30i3 comma11. @36 h32t3 comma11. @48 h32i4 comma10. @59 h32i15 comma10. @70 ':' @72 h31i3 comma10.
  / @2 ' 2' @23 H30i4 comma11. @36 h32t4 comma11. @48 h32i5 comma10. @59 h32i16 comma10. @70 ':' @72 h31i4 comma10.
  / @2 ' 3 or 4' @23 H30i5 comma11. @36 h32t5 comma11. @48 h32i6 comma10. @59 h32i17 comma10. @70 ':' @72 h31i5 comma10.
  / @2 ' 5 to 9' @23 H30i6 comma11. @36 h32t6 comma11. @48 h32i7 comma10. @59 h32i18 comma10. @70 ':' @72 h31i6 comma10.
  / @2 ' 10 to 19' @23 H30i7 comma11. @36 h32t7 comma11. @48 h32i8 comma10. @59 h32i19 comma10. @70 ':' @72 h31i7 comma10.
  / @2 ' 20 to 49' @23 H30i8 comma11. @36 h32t8 comma11. @48 h32i9 comma10. @59 h32i20 comma10. @70 ':' @72 h31i8 comma10.
  / @2 ' 50 or More' @23 H30i9 comma11. @36 h32t9 comma11. @48 h32i10 comma10. @59 h32i21 comma10. @70 ':' @72 h31i9 comma10.
  / @2 ' Mobile Home' @23 H30i10 comma11. @36 h32t10 comma11. @48 h32i11 comma10. @59 h32i22 comma10. @70 ':' @72 h31i10 comma10.
  / @2 ' Boat, RV, Van, etc.' @23 H30i11 comma11. @36 h32t11 comma11. @48 h32i12 comma10. @59 h32i23 comma10. @70 ':' @72 h31i11 comma10.
;

**--Generate table H33.--**;
array h33t{11};
array h33ow{11} h33i2-h33i12;
array h33rt{11} h33i13-h33i23;
array phh{11};

do i=1 to 11;
h33t{i}=h33ow{i}+h33rt{i};
if h32t{i}>0 then phh{i}=h33t{i}/h32t{i};
 else phh{i}=.;
end;

PUT #44
    @84  'H33. POPULATION BY UNITS IN STRUCTURE BY TENURE'
  / @84  'Universe: Population in Occupied Housing Units'
  / @106 '------------ Persons in Units ------------'
  / @120 'Per' @131 'Owner' @142 'Renter'
  / @111 'Total' @119 'Hhld' @128 'Occupied'  @140 'Occupied'           
 // @84  'Total Persons:' @105 h33t1 comma11. @117 phh1 6.2 @125 h33i2 comma11. @137 h33i13 comma11.
  / @84  ' 1, Detached' @105 h33t2 comma11. @117 phh2 6.2 @125 h33i3 comma11. @137 h33i14 comma11.
  / @84  ' 1, Attached' @105 h33t3 comma11. @117 phh3 6.2 @125 h33i4 comma11. @137 h33i15 comma11.
  / @84  ' 2' @105 h33t4 comma11. @117 phh4 6.2 @125 h33i5 comma11. @137 h33i16 comma11.
  / @84  ' 3 or 4' @105 h33t5 comma11. @117 phh5 6.2 @125 h33i6 comma11. @137 h33i17 comma11.
  / @84  ' 5 to 9' @105 h33t6 comma11. @117 phh6 6.2 @125 h33i7 comma11. @137 h33i18 comma11.
  / @84  ' 10 to 19' @105 h33t7 comma11. @117 phh7 6.2 @125 h33i8 comma11. @137 h33i19 comma11.
  / @84  ' 20 to 49' @105 h33t8 comma11. @117 phh8 6.2 @125 h33i9 comma11. @137 h33i20 comma11.
  / @84  ' 50 or More' @105 h33t9 comma11. @117 phh9 6.2 @125 h33i10 comma11. @137 h33i21 comma11.
  / @84  ' Mobile Home' @105 h33t10 comma11. @117 phh10 6.2 @125 h33i11 comma11. @137 h33i22 comma11.
  / @84  ' Boat, RV, Van, etc.' @105 h33t11 comma11. @117 phh11 6.2 @125 h33i12 comma11. @137 h33i23 comma11.
;


link HeadFoot; 
end;  *<-----------of code to generate 1st page----;

*--generate housing profile, page 2.--*;
  
if index(_pages,'2') then do;

%PutTitle(
   %STR(Housing Profile 2: ROOMS; BEDROOMS; YEAR MOVED; OWNER COSTS; PLUMBING; KITCHENS; TELEPHONE),
   %STR(Housing-2) ) ;

**--Draw horizontal lines.--**;
PUT #18 @56 48*'_' ;
PUT #24 @105 44*'_' ;
PUT #34 @2 147*'_';

**--Draw (internal) vertical lines--**;
do _I_=6 to 33;
  PUT #_I_ @55 '|' @104 '|' ;
  end;

do _I_=35 to 61;
  PUT #_I_ @68 '|' @104 '|';
  end;

  **--Generate tables H23-H28/H41-H42.--**;
array h26t{9};
array h26ow{9} h26i3-h26i11;
array h26rt{9} h26i13-h26i21;

do i=1 to 9;
 h26t{i}=h26ow{i}+h26rt{i};
end;

if h23i1>0 then humroom = h25i1/h23i1; else humroom = .;
if h26i1>0 then occmroom = h28i1/h26i1; else occmroom = .;
if h26i2>0 then omroom = h28i2/h26i2; else omroom = .;
if h26i12>0 then rmroom = h28i3/h26i12; else rmroom = .;

array h42t{6};
array h42ow{6} h42i3-h42i8;
array h42rt{6} h42i10-h42i15;

do i=1 to 6;
 h42t{i}=h42ow{i}+h42rt{i};
end;

PUT #6
    @2  'H23-H28/H41/H42. ROOMS AND BEDROOMS BY TENURE'
  / @2  'Universe: Housing Units'
 // @13 '    All  ---- Occupied Housing Units ----' 
  / @15 'Units' @27 'Total' @38 'Owner' @48 'Renter'
 // @2  'Total:' @9 h23i1 comma11. @21 h26i1 comma11. @33 h26i2 comma10. @44 h26i12 comma10.
  / @2  ' Rooms--'
  / @2  '  1' @9 h23i2 comma11. @21 h26t1 comma11. @33 h26i3 comma10. @44 h26i13 comma10.
  / @2  '  2' @9 h23i3 comma11. @21 h26t2 comma11. @33 h26i4 comma10. @44 h26i14 comma10.
  / @2  '  3' @9 h23i4 comma11. @21 h26t3 comma11. @33 h26i5 comma10. @44 h26i15 comma10.
  / @2  '  4' @9 h23i5 comma11. @21 h26t4 comma11. @33 h26i6 comma10. @44 h26i16 comma10.
  / @2  '  5' @9 h23i6 comma11. @21 h26t5 comma11. @33 h26i7 comma10. @44 h26i17 comma10.
  / @2  '  6' @9 h23i7 comma11. @21 h26t6 comma11. @33 h26i8 comma10. @44 h26i18 comma10.
  / @2  '  7' @9 h23i8 comma11. @21 h26t7 comma11. @33 h26i9 comma10. @44 h26i19 comma10.
  / @2  '  8' @9 h23i9 comma11. @21 h26t8 comma11. @33 h26i10 comma10. @44 h26i20 comma10.
  / @2  '  9+' @9 h23i10 comma11. @21 h26t9 comma11. @33 h26i11 comma10. @44 h26i21 comma10.
  / @2  ' Rooms per Unit--' 
  / @2  '  Median' @14 h24i1 6.1 @26 h27i1 6.1 @37 h27i2 6.1 @48 h27i3 6.1
  / @2  '  Mean' @14 humroom 6.1 @26 occmroom 6.1 @37 omroom 6.1 @48 rmroom 6.1
 // @2  ' Bedrooms--'
  / @2  '  None' @9 h41i2 comma11. @21 h42t1 comma11. @33 h42i3 comma10. @44 h42i10 comma10.
  / @2  '  1' @9 h41i3 comma11. @21 h42t2 comma11. @33 h42i4 comma10. @44 h42i11 comma10.
  / @2  '  2' @9 h41i4 comma11. @21 h42t3 comma11. @33 h42i5 comma10. @44 h42i12 comma10.
  / @2  '  3' @9 h41i5 comma11. @21 h42t4 comma11. @33 h42i6 comma10. @44 h42i13 comma10.
  / @2  '  4' @9 h41i6 comma11. @21 h42t5 comma11. @33 h42i7 comma10. @44 h42i14 comma10.
  / @2  '  5+' @9 h41i7 comma11. @21 h42t6 comma11. @33 h42i8 comma10. @44 h42i15 comma10.
;

**--Generate tables H90-H92/H98.--**;
tocc1 = h98i3+h98i19+h98i20+h98i21;
tocc2 = h98i4+h98i22+h98i23;
tocc3 = h98i5+h98i24+h98i25;
tocc4 = h98i6+h98i26;
tocc5 = h98i7+h98i27;
tocc6 = h98i8+h98i28;
tocc7 = h98i9+h98i29;
tocc8 = h98i10+h98i30;
tocc9 = h98i11+h98i31;
tocc10 = h98i12+h98i13+h98i14+h98i15+h98i16+h98i17+h98i32;

tsocc1 = h90i3+h90i19+h90i20+h90i21;
tsocc2 = h90i4+h90i22+h90i23;
tsocc3 = h90i5+h90i24+h90i25;
tsocc4 = h90i6+h90i26;
tsocc5 = h90i7+h90i27;
tsocc6 = h90i8+h90i28;
tsocc7 = h90i9+h90i29;
tsocc8 = h90i10+h90i30;
tsocc9 = h90i11+h90i31;
tsocc10 = h90i12+h90i13+h90i14+h90i15+h90i16+h90i17+h90i32;

Wmt1000 = h90i12+h90i13+h90i14+h90i15+h90i16+h90i17;
womt200 = h90i19+h90i20+h90i21;
womt299 = h90i22+h90i23;
womt399 = h90i24+h90i25; 

if h90i1>0 then tmcost=h92i1/h90i1; else tmcost = .;
if h90i2>0 then wmcost=h92i2/h90i2; else wmcost = .;
if h90i18>0 then womcost=h92i3/h90i18; else womcost = .;

PUT #35
    @2  'H90/H91/H92/H98. MORTGAGE STATUS AND SELECTED MONTHLY OWNER COSTS'
  / @2  'Two Universes: All/Specified Owner-Occupied Housing Units'
 // @27 'Total : --- Specified Owner Occupied ---' 
  / @27 'Owner :' @50 'With A  Without A'
  / @2  'Monthly Costs--' @24 'Occupied :' @40 'Total' @48 'Mortgage' @59 'Mortgage'
  / @33 ':'
  / @2  'Total Units:' @22 h98i1 comma10. @33 ':' @35 h90i1 comma10. @46 h90i2 comma10. @57 h90i18 comma10.
  / @2  ' Less than $200' @22 tocc1 comma10. @33 ':' @35 tsocc1 comma10. @46 h90i3 comma10. @57 womt200 comma10.
  / @2  ' $200 to $299' @22 tocc2 comma10. @33 ':' @35 tsocc2 comma10. @46 h90i4 comma10. @57 womt299 comma10.
  / @2  ' $300 to $399' @22 tocc3 comma10. @33 ':' @35 tsocc3 comma10. @46 h90i5 comma10. @57 womt399 comma10.
  / @2  ' $400 to $499' @22 tocc4 comma10. @33 ':' @35 tsocc4 comma10. @46 h90i6 comma10. @57 h90i26 comma10.
  / @2  ' $500 to $599' @22 tocc5 comma10. @33 ':' @35 tsocc5 comma10. @46 h90i7 comma10. @57 h90i27 comma10.
  / @2  ' $600 to $699' @22 tocc6 comma10. @33 ':' @35 tsocc6 comma10. @46 h90i8 comma10. @57 h90i28 comma10.
  / @2  ' $700 to $799' @22 tocc7 comma10. @33 ':' @35 tsocc7 comma10. @46 h90i9 comma10. @57 h90i29 comma10.
  / @2  ' $800 to $899' @22 tocc8 comma10. @33 ':' @35 tsocc8 comma10. @46 h90i10 comma10. @57 h90i30 comma10.
  / @2  ' $900 to $999' @22 tocc9 comma10. @33 ':' @35 tsocc9 comma10. @46 h90i11 comma10. @57 h90i31 comma10.
  / @2  ' $1,000 or More' @22 tocc10 comma10. @33 ':' @35 tsocc10 comma10. @46 wmt1000 comma10. @57 h90i32 comma10.
  / @2  '   $1,000 to $1,249' @29 'N/A'  @33 ':' @42 'N/A' @46 h90i12 comma10. @64 'N/A'
  / @2  '   $1,250 to $1,499' @29 'N/A'  @33 ':' @42 'N/A' @46 h90i13 comma10. @64 'N/A'
  / @2  '   $1,500 to $1,999' @29 'N/A'  @33 ':' @42 'N/A' @46 h90i14 comma10. @64 'N/A'
  / @2  '   $2,000 to $2,499' @29 'N/A'  @33 ':' @42 'N/A' @46 h90i15 comma10. @64 'N/A'
  / @2  '   $2,500 to $2,999' @29 'N/A'  @33 ':' @42 'N/A' @46 h90i16 comma10. @64 'N/A'
  / @2  '   $3,000 or More' @29 'N/A'  @33 ':' @42 'N/A' @46 h90i17 comma10. @64 'N/A'
  / @33 ':'
  / @2  'Median Monthly Costs' @33 ':' @42 'N/A' @49 H91i1 dollar7. @60  h91i2 dollar7.  
  / @2  'Mean Monthly Costs' @33 ':' @38  tmcost dollar7. @49  wmcost dollar7. @60  womcost dollar7.  
;

 **--Generate table H20.--**;
array h20t{5};
array h20ow{5} h20i3-h20i7;
array h20rt{5} h20i9-h20i13;

do i=1 to 5;
 h20t{i}=h20ow{i}+h20rt{i};
end;

PUT #6
    @56 'H20. OCCUPANTS PER ROOM BY TENURE'
  / @56 'Universe: Occupied Housing Units'
  /
  / @73 'Occupied' @87 'Owner' @97 'Renter'
  / @76 'Units' @84 'Occupied' @95 'Occupied'
 // @56 'Total Units:' @70 h20i1 comma11. @82 h20i2 comma10. @93 h20i8 comma10.
  / @56 ' 0.50 or less' @70 h20t1 comma11. @82 h20i3 comma10. @93 h20i9 comma10.
  / @56 ' 0.51 to 1.00' @70 h20t2 comma11. @82 h20i4 comma10. @93 h20i10 comma10.
  / @56 ' 1.01 to 1.50' @70 h20t3 comma11. @82 h20i5 comma10. @93 h20i11 comma10.
  / @56 ' 1.51 to 2.00' @70 h20t4 comma11. @82 h20i6 comma10. @93 h20i12 comma10.
  / @56 ' 2.01 or more' @70 h20t5 comma11. @82 h20i7 comma10. @93 h20i13 comma10.
;

**--Generate tables H38-H39.--**;
array h38t{6};
array h38ow{6} h38i3-h38i8;
array h38rt{6} h38i10-h38i15;

do i=1 to 6;
 h38t{i}=h38ow{i}+h38rt{i};
end;

PUT #19
    @56 'H38/H39. YEAR HOUSEHOLDER MOVED INTO UNIT'
  / @56 'Universe: Occupied Housing Units'
  / 
  / @56 'Year Moved' @73 'Occupied' @87 'Owner' @97 'Renter'
  / @56 'Into Unit--' @76 'Units' @84 'Occupied' @95 'Occupied'
 // @56 'Total Units:' @70 h38i1 comma11. @82 h38i2 comma10. @93 h38i9 comma10.
  / @56 ' 1999-Mar 00' @70 h38t1 comma11. @82 h38i3 comma10. @93 h38i10 comma10.
  / @56 ' 1995-98 ' @70 h38t2 comma11. @82 h38i4 comma10. @93 h38i11 comma10.
  / @56 ' 1990-94' @70 h38t3 comma11. @82 h38i5 comma10. @93 h38i12 comma10.
  / @56 ' 1980-89' @70 h38t4 comma11. @82 h38i6 comma10. @93 h38i13 comma10.
  / @56 ' 1970-79' @70 h38t5 comma11. @82 h38i7 comma10. @93 h38i14 comma10.
  / @56 ' Before 1970' @70 h38t6 comma11. @82 h38i8 comma10. @93 h38i15 comma10.
 // @56 'Median Year' @77 h39i1 4. @88 h39i2 4. @99 h39i3 4. 
;

**--Generate tables HCT19-HCT21.--**;
if hct19i1>0 then mret=hct21i1/hct19i1; else mret=.;

PUT #35
    @69 'HCT19-HCT21. REAL ESTATE TAXES'
  / @69 'Universe: Specified Owner-'
  / @69 '          Occupied Housing Units'
 // @69 'Spec. Owner-Occ. Units:' @93 hct19i1 comma10.
  / @69 ' Less than $200' @93 hct19i2 comma10. 
  / @69 ' $200 to $299' @93 hct19i3 comma10.
  / @69 ' $300 to $399' @93 hct19i4 comma10. 
  / @69 ' $400 to $599' @93 hct19i5 comma10. 
  / @69 ' $600 to $799 ' @93 hct19i6 comma10.
  / @69 ' $800 to $999' @93 hct19i7 comma10. 
  / @69 ' $1,000 to $1,499' @93 hct19i8 comma10. 
  / @69 ' $1,500 to $1,999' @93 hct19i9 comma10.
  / @69 ' $2,000 to $2,999' @93 hct19i10 comma10. 
  / @69 ' $3,000 to $3,999' @93 hct19i11 comma10. 
  / @69 ' $4,000 to $4,999' @93 hct19i12 comma10.
  / @69 ' $5,000 to $7,499' @93 hct19i13 comma10. 
  / @69 ' $7,500 to $9,999' @93 hct19i14 comma10.
  / @69 ' $10,000 or more' @93 hct19i15 comma10. 
  / @69 ' No Taxes Paid' @93 hct19i16 comma10.
 // @69 'Median Real Estate Taxes' @95 hct20i1 dollar8.
  / @69 'Mean Real Estate Taxes' @95  mret dollar8.
;

**--Generate tables H47-H48/H50-H51.--**;
PUT #6
    @105 'H47/H48/H50/H51. PLUMBING AND KITCHEN'
  / @105 '                 FACILITIES BY TENURE'
  / @105 'Universe: Housing Units'
 // @122 'Total  -- Occupied Units --'
  / @120 'Housing' @133 'Owner' @143 'Renter'
  / @122 'Units'  @130 'Occupied' @141 'Occupied'
 // @105 'All Units:' @116 h47i1 comma11. @128 h48i2 comma10. @139 h48i5 comma10.
  / @105 'Complete'
  / @105 'Facilities--'
  / @105 ' Plumbing' @116 h47i2 comma11. @128 h48i3 comma10. @139 h48i6 comma10.
  / @105 ' Kitchen'  @116 h50i2 comma11. @128 h51i3 comma10. @139 h51i6 comma10. 
  / @105 'Lacking Complete'
  / @105 'Facilities--'
  / @105 ' Plumbing' @116 h47i3 comma11. @128 h48i4 comma10. @139 h48i7 comma10.
  / @105 ' Kitchen'  @116 h50i3 comma11. @128 h51i4 comma10. @139 h51i7 comma10. 
; ;

**--Generate table H43.--**;
twphone=h43i3+h43i20;
twophone=h43i11+h43i28;

PUT #25
    @105 'H43. TELEPHONE SERVICE AVAILABLE BY TENURE'
  / @105 'Universe: Occupied Housing Units'
 // @126                            '----Occupied Units----'
  / @126                            '   Total    Renter-Occ'
 // @105 'Total Units:'    @123 h43i1    comma11. @138 h43i19 comma10.
  / @105 ' With Telephone' @123 twphone  comma11. @138 h43i20 comma10.
  / @105 ' No Telephone'   @123 twophone comma11. @138 h43i28 comma10.
 ;
 
**--Generate tables H94-H95.--**;
array h94t{10};
array h94ow{10} h94i3-h94i12;
array h94rt{10} h94i14-h94i23;

do i=1 to 10;
 h94t{i}=h94ow{i}+h94rt{i};
end;

PUT #35
    @105 'H94/H95. MORTGAGE STATUS BY SELECTED MONTHLY'
  / @105 '         OWNER COSTS AS A PERCENTAGE OF'
  / @105 '         HOUSEHOLD INCOME IN 1999'
  / @105 'Universe: Specified Owner-Occupied'
  / @105 '          Housing Units' 
 // @105 'Percentage' @132 'With A' @140 'Without A'
  / @105 'of HH Income--' @123 'Total' @130 'Mortgage' @141 'Mortgage'
 // @105 'Spec. Units:' @117 h94i1 comma11. @128 h94i2 comma10. @139 h94i13 comma10.
  / @105 ' Under 10.0%' @117 h94t1 comma11. @128 h94i3 comma10. @139 h94i14 comma10.
  / @105 ' 10.0-14.9%' @117 h94t2 comma11. @128 h94i4 comma10. @139 h94i15 comma10.
  / @105 ' 15.0-19.9%' @117 h94t3 comma11. @128 h94i5 comma10. @139 h94i16 comma10. 
  / @105 ' 20.0-24.9%' @117 h94t4 comma11. @128 h94i6 comma10. @139 h94i17 comma10.
  / @105 ' 25.0-29.9%' @117 h94t5 comma11. @128 h94i7 comma10. @139 h94i18 comma10.
  / @105 ' 30.0-34.9%' @117 h94t6 comma11. @128 h94i8 comma10. @139 h94i19 comma10.
  / @105 ' 35.0-39.9%' @117 h94t7 comma11. @128 h94i9 comma10. @139 h94i20 comma10.
  / @105 ' 40.0-49.9%' @117 h94t8 comma11. @128 h94i10 comma10. @139 h94i21 comma10.
  / @105 ' 50.0%+' @117 h94t9 comma11. @128 h94i11 comma10. @139 h94i22 comma10.
  / @105 ' Not'
  / @105 ' Computed' @117 h94t10 comma11. @128 h94i12 comma10. @139 h94i23 comma10.
 // @105 'Median Percentage'
  / @105 'of 1999 Household'
  / @105 'Income Spent on'
  / @105 'Home Ownership' @121 h95i1 6.1 '%' @131 h95i2 6.1 '%' @142 h95i3 6.1 '%'
;
 
link HeadFoot; 
end;  *<-----------of code to generate 2nd page----;

/*--generate housing profile, page 3. */

IF INDEX(_pages,'3') THEN DO;

%PutTitle(
   %STR(Housing Profile 3: VALUE AND TENURE BY RACE & HISPANIC/LATINO, HOUSEHOLD INCOME BY TENURE),
   %STR(Housing-3) ) ;

**--Draw horizontal line--**;

PUT #42 @2 147*'_';

**--Draw (internal) vertical lines--**;

do _i_=9 to 41;
  PUT #_I_ @30 ':';
  end;

do _j_=10 to 41;
  PUT #_J_ @113 ':';
  end;

do _k_=9 to 41;
  PUT #_K_ @137 '|';
  end;

do _l_=45 to 59;
  PUT #_L_ @58 ':';
  end;

do _m_=43 to 61;
  PUT #_M_ @83 '|';
  end;

%LET f=comma10.;
%LET g=comma10. comma11. comma10. comma10. comma10. comma9. comma10. comma10.;
%LET h=comma10. comma11.;
%LET k=comma11. comma12. comma11.;
%LET l=comma11. comma13. comma13.;
%LET p=dollar10.;
%LET q=dollar10. dollar11. dollar10. dollar10. dollar10. dollar9. dollar10. dollar10.;
%LET r=dollar10. dollar11.;
%LET s=dollar11. dollar13. dollar13.;

**--Generate tables H74/H76/H78/H84-H86/HCT41A-I/HCT42A-I/HCT43A-I/H87-H89.--**;

if h84i1>0 then mean1=h86i1/h84i1; else mean1=.;
if h74i1>0 then mean2=h78i1/h74i1; else mean2 = .;
if hct41ai1>0 then mean3=hct43ai1/hct41ai1; else mean3 = .;
if hct41bi1>0 then mean4=hct43bi1/hct41bi1; else mean4 = .;
if hct41ci1>0 then mean5=hct43ci1/hct41ci1; else mean5 = .;
if hct41di1>0 then mean6=hct43di1/hct41di1; else mean6 = .;
if hct41ei1>0 then mean7=hct43ei1/hct41ei1; else mean7 = .;
if hct41fi1>0 then mean8=hct43fi1/hct41fi1; else mean8 = .;
if hct41gi1>0 then mean9=hct43gi1/hct41gi1; else mean9 = .;
if hct41hi1>0 then mean10=hct43hi1/hct41hi1; else mean10 = .;
if hct41ii1>0 then mean11=hct43ii1/hct41ii1; else mean11 = .;
if h87i1>0 then mean12=h89i1/h87i1; else mean12 = .;

PUT #6
    @2 'H74/H76/H78/H84-H86/HCT41A-I/HCT42A-I/HCT43A-I/H87-H89. VALUE OF HOUSING UNITS BY 
RACE AND HISPANIC OR LATINO ORIGIN OF HOUSEHOLDER; PRICE ASKED'
  / @2 'Three Universes: All Owner-Occupied Housing Units/Specified Owner-Occupied Housing Units/Specified Vacant-for-Sale-Only Housing Units'
  / @138 '...........'
  / @32 '---------------------------------Specified Owner-Occupied Housing Units----------
-----------------------' @138 'PRICE ASKED'
  / @21 '     All' @55 '   Black' @65 'Amer Ind'
    @84 ' Nat Haw' @97 'Other' @106 'Two or' @125 'White Alone' @140 'Specified'
  / @21 '   Owner' @48 'White' @55 '/Af Amer' @65 '/Ala Nat' @78 'Asian'
    @84 '/Pac Isl' @97 ' Race' @106 '  More' @116 ' Hispanic' 
    @127 'not Hisp.' @138 'Vacant-for-'
  / @2 'Value--' @21 'Occupied' @37 'Total' @48 'Alone' @55 '   Alone' @65 '   Alone' 
    @78 'Alone' @84 '   Alone' @97 'Alone' @106 ' Races' @116 'or Latino' 
    @127 'or Latino' @140 'Sale-Only'
 // @2 'Total Units:' @19 h84i1 &f @32 (h74i1 hct41ai1 hct41bi1 hct41ci1 hct41di1 hct41ei1
                hct41fi1 hct41gi1) (&g) @115 (hct41hi1 hct41ii1) (&h) @139 h87i1 &f 
  / @2 ' Under 10,000' @19 h84i2 &f @32 (h74i2 hct41ai2 hct41bi2 hct41ci2 hct41di2 hct41ei2 
                hct41fi2 hct41gi2) (&g) @115 (hct41hi2 hct41ii2) (&h) @139 h87i2 &f 
  / @2 ' 10,000-14,999' @19 h84i3 &f @32 (h74i3 hct41ai3 hct41bi3 hct41ci3 hct41di3 hct41ei3 
                hct41fi3 hct41gi3) (&g) @115 (hct41hi3 hct41ii3) (&h) @139 h87i3 &f 
  / @2 ' 15,000-19,999' @19 h84i4 &f @32 (h74i4 hct41ai4 hct41bi4 hct41ci4 hct41di4 hct41ei4 
                hct41fi4 hct41gi4) (&g) @115 (hct41hi4 hct41ii4) (&h) @139 h87i4 &f 
  / @2 ' 20,000-24,999' @19 h84i5 &f @32 (h74i5 hct41ai5 hct41bi5 hct41ci5 hct41di5 hct41ei5 
                hct41fi5 hct41gi5) (&g) @115 (hct41hi5 hct41ii5) (&h) @139 h87i5 &f 
  / @2 ' 25,000-29,999' @19 h84i6 &f @32 (h74i6 hct41ai6 hct41bi6 hct41ci6 hct41di6 hct41ei6 
                hct41fi6 hct41gi6) (&g) @115 (hct41hi6 hct41ii6) (&h) @139 h87i6 &f 
  / @2 ' 30,000-34,999' @19 h84i7 &f @32 (h74i7 hct41ai7 hct41bi7 hct41ci7 hct41di7 hct41ei7 
                hct41fi7 hct41gi7) (&g) @115 (hct41hi7 hct41ii7) (&h) @139 h87i7 &f 
  / @2 ' 35,000-39,999' @19 h84i8 &f @32 (h74i8 hct41ai8 hct41bi8 hct41ci8 hct41di8 hct41ei8 
                hct41fi8 hct41gi8) (&g) @115 (hct41hi8 hct41ii8) (&h) @139 h87i8 &f 
  / @2 ' 40,000-49,999' @19 h84i9 &f @32 (h74i9 hct41ai9 hct41bi9 hct41ci9 hct41di9 hct41ei9 
                hct41fi9 hct41gi9) (&g) @115 (hct41hi9 hct41ii9) (&h) @139 h87i9 &f 
  / @2 ' 50,000-59,999' @19 h84i10 &f @32 (h74i10 hct41ai10 hct41bi10 hct41ci10 hct41di10 hct41ei10 
                hct41fi10 hct41gi10) (&g) @115 (hct41hi10 hct41ii10) (&h) @139 h87i10 &f 
  / @2 ' 60,000-69,999' @19 h84i11 &f @32 (h74i11 hct41ai11 hct41bi11 hct41ci11 hct41di11 hct41ei11 
                hct41fi11 hct41gi11) (&g) @115 (hct41hi11 hct41ii11) (&h) @139 h87i11 &f 
  / @2 ' 70,000-79,999' @19 h84i12 &f @32 (h74i12 hct41ai12 hct41bi12 hct41ci12 hct41di12 hct41ei12 
                hct41fi12 hct41gi12) (&g) @115 (hct41hi12 hct41ii12) (&h) @139 h87i12 &f 
  / @2 ' 80,000-89,999' @19 h84i13 &f @32 (h74i13 hct41ai13 hct41bi13 hct41ci13 hct41di13 hct41ei13 
                hct41fi13 hct41gi13) (&g) @115 (hct41hi13 hct41ii13) (&h) @139 h87i13 &f 
  / @2 ' 90,000-99,999' @19 h84i14 &f @32 (h74i14 hct41ai14 hct41bi14 hct41ci14 hct41di14 hct41ei14 
                hct41fi14 hct41gi14) (&g) @115 (hct41hi14 hct41ii14) (&h) @139 h87i14 &f 
  / @2 ' 100,000-124,999' @19 h84i15 &f @32 (h74i15 hct41ai15 hct41bi15 hct41ci15 hct41di15 hct41ei15 
                hct41fi15 hct41gi15) (&g) @115 (hct41hi15 hct41ii15) (&h) @139 h87i15 &f 
  / @2 ' 125,000-149,999' @19 h84i16 &f @32 (h74i16 hct41ai16 hct41bi16 hct41ci16 hct41di16 hct41ei16 
                hct41fi16 hct41gi16) (&g) @115 (hct41hi16 hct41ii16) (&h) @139 h87i16 &f 
  / @2 ' 150,000-174,999' @19 h84i17 &f @32 (h74i17 hct41ai17 hct41bi17 hct41ci17 hct41di17 hct41ei17 
                hct41fi17 hct41gi17) (&g) @115 (hct41hi17 hct41ii17) (&h) @139 h87i17 &f 
  / @2 ' 175,000-199,999' @19 h84i18 &f @32 (h74i18 hct41ai18 hct41bi18 hct41ci18 hct41di18 hct41ei18 
                hct41fi18 hct41gi18) (&g) @115 (hct41hi18 hct41ii18) (&h) @139 h87i18 &f 
  / @2 ' 200,000-249,999' @19 h84i19 &f @32 (h74i19 hct41ai19 hct41bi19 hct41ci19 hct41di19 hct41ei19 
                hct41fi19 hct41gi19) (&g) @115 (hct41hi19 hct41ii19) (&h) @139 h87i19 &f 
  / @2 ' 250,000-299,999' @19 h84i20 &f @32 (h74i20 hct41ai20 hct41bi20 hct41ci20 hct41di20 hct41ei20 
                hct41fi20 hct41gi20) (&g) @115 (hct41hi20 hct41ii20) (&h) @139 h87i20 &f 
  / @2 ' 300,000-399,999' @19 h84i21 &f @32 (h74i21 hct41ai21 hct41bi21 hct41ci21 hct41di21 hct41ei21 
                hct41fi21 hct41gi21) (&g) @115 (hct41hi21 hct41ii21) (&h) @139 h87i21 &f 
  / @2 ' 400,000-499,999' @19 h84i22 &f @32 (h74i22 hct41ai22 hct41bi22 hct41ci22 hct41di22 hct41ei22 
                hct41fi22 hct41gi22) (&g) @115 (hct41hi22 hct41ii22) (&h) @139 h87i22 &f 
  / @2 ' 500,000-749,999' @19 h84i23 &f @32 (h74i23 hct41ai23 hct41bi23 hct41ci23 hct41di23 hct41ei23 
                hct41fi23 hct41gi23) (&g) @115 (hct41hi23 hct41ii23) (&h) @139 h87i23 &f 
  / @2 ' 750,000-999,999' @19 h84i24 &f @32 (h74i24 hct41ai24 hct41bi24 hct41ci24 hct41di24 hct41ei24 
                hct41fi24 hct41gi24) (&g) @115 (hct41hi24 hct41ii24) (&h) @139 h87i24 &f 
  / @2 ' 1,000,000 & over' @19 h84i25 &f @32 (h74i25 hct41ai25 hct41bi25 hct41ci25 hct41di25 hct41ei25 
                hct41fi25 hct41gi25) (&g) @115 (hct41hi25 hct41ii25) (&h) @139 h87i25 &f
 // @2 'Median Value' @19 h85i1 &p @32 (h76i1 hct42ai1 hct42bi1 hct42ci1 hct42di1 hct42ei1
                hct42fi1 hct42gi1) (&q) @115 (hct42hi1 hct42ii1) (&r) @139 h88i1 &p 
  / @2 'Mean Value' @19 mean1 &p @32 (mean2 mean3 mean4 mean5 mean6 mean7 
                mean8 mean9) (&q) @115 (mean10 mean11) (&r) @139 mean12 &p;

**--Generate tables H9-H13.--**;

PUT #43
    @2 'H9/H10/H11/H12/H13. TENURE BY RACE AND HISPANIC OR LATINO ORIGIN OF HOUSEHOLDER'
  / @2 'Universe: Occupied Housing Units'
  / @23 '----- Occupied Housing Units -----'
  / @35 'Not Hispanic' @48 ' Hispanic'  @62 '   Owner' @73 '  Renter' 
  / @2 'Householder--' @29 'Total' @35 '  or Latino'  @48 'or Latino' @62 'Occupied' @73 'Occupied'
 // @2 'Total Units:' @23 (h9i1 h10i2 h10i10) (&k) @61 (h11i2 h11i10) (&h)
  / @2 ' White Alone' @23 (h9i2 h10i3 h10i11) (&k) @61(h11i3 h11i11) (&h)
  / @2 ' Black/Af Amer Alone' @23 (h9i3 h10i4 h10i12) (&k) @61 (h11i4 h11i12) (&h)
  / @2 ' American Indian/'
  / @2 ' Alaska Native Alone' @23 (h9i4 h10i5 h10i13) (&k) @61(h11i5 h11i13) (&h)
  / @2 ' Asian Alone' @23 (h9i5 h10i6 h10i14) (&k) @61 (h11i6 h11i14) (&h)
  / @2 ' Native Hawaiian/'
  / @2 ' Pacific Isl Alone' @23 (h9i6 h10i7 h10i15) (&k) @61 (h11i7 h11i15) (&h)
  / @2 ' Other Race Alone' @23 (h9i7 h10i8 h10i16) (&k) @61 (h11i8 h11i16) (&h)
  / @2 ' Two or More Races' @23 (h9i8 h10i9 h10i17) (&k) @61 (h11i9 h11i17) (&h)
 // @2 'Hispanic or Latino.........................................' @61 (h12i2 h12i3) (&h)
  / @2 'White Alone, not Hispanic or Latino........................' @61 (h13i2 h13i3) (&h);
  
**--Generate tables HCT11-HCT13.--**;

array own{11} hct11i3-hct11i13;
array rent{11} hct11i15-hct11i25;
array  totocc{11};

do i=1 to 11;
  totocc{i}=own{i}+rent{i};
end;

if hct11i1>0 then mninc1=hct13i1/hct11i1; else mninc1=.;
if hct11i2>0 then mninc2=hct13i2/hct11i2; else mninc2 = .;
if hct11i14>0 then mninc3=hct13i5/hct11i14; else mninc3 = .;

PUT #43
    @85 'HCT11/HCT12/HCT13. HOUSEHOLD INCOME IN 1999 BY TENURE'
  / @85 'Universe: Occupied Housing Units' @127 '   Owner' @140 '  Renter'
  / @117 'Total'                           @127 'Occupied' @140 'Occupied'
 // @85 'Total Units:' @111 (hct11i1 hct11i2 hct11i14) (&l) 
  / @85 ' Less than $5,000' @111 (totocc1 hct11i3 hct11i15) (&l)
  / @85 ' $5,000 to $9,999' @111 (totocc2 hct11i4 hct11i16) (&l)
  / @85 ' $10,000 to $14,999' @111 (totocc3 hct11i5 hct11i17) (&l)
  / @85 ' $15,000 to $19,999' @111 (totocc4 hct11i6 hct11i18) (&l)
  / @85 ' $20,000 to $24,999' @111 (totocc5 hct11i7 hct11i19) (&l)
  / @85 ' $25,000 to $34,999' @111 (totocc6 hct11i8 hct11i20) (&l)
  / @85 ' $35,000 to $49,999' @111 (totocc7 hct11i9 hct11i21) (&l)
  / @85 ' $50,000 to $74,999' @111 (totocc8 hct11i10 hct11i22) (&l)
  / @85 ' $75,000 to $99,999' @111 (totocc9 hct11i11 hct11i23) (&l)
  / @85 ' $100,000 to $149,999' @111 (totocc10 hct11i12 hct11i24) (&l)
  / @85 ' $150,000 or more' @111 (totocc11 hct11i13 hct11i25) (&l)
 // @85 'Median Household Income' @111 (hct12i1 hct12i2 hct12i3) (&s)
  / @85 'Mean Household Income' @111 (mninc1 mninc2 mninc3) (&s);

link HeadFoot; 
end;  *<-----------of code to generate page 3 ----;

/*--generate housing profile, page 4.---*/

IF INDEX(_pages,'4') THEN DO;

%PutTitle(
   %STR(Housing Profile 4: UTILITY PAYMENT; MEALS IN RENT; BEDROOMS; RENT BY RACE & HISP/LATINO),
   %STR(Housing-4) ) ;

**--Draw horizontal lines--**;

PUT #14 @2 75*'_';
PUT #26 @2 147*'_';

**--Draw (internal) vertical lines--**;

do _i_=6 to 13;
  PUT #_I_ @40 '|';
  end;

do _j_=6 to 25;
  PUT #_J_ @77 '|';
  end;

do _k_=30 to 61;
  PUT #_K_ @28 ':';
  end;

do _l_=30 to 61;
  PUT #_L_ @113 ':';
  end;

do _m_=30 to 61;
  PUT #_M_ @137 '|';
  end;


%LET f=comma10.;
%LET g=comma10. comma11. comma11. comma10. comma11. comma8. comma11. comma10.;
%LET k=comma10. comma11.;
%LET h=comma10. comma11. comma11. comma11. comma11.;
%LET p=dollar10.;
%LET q=dollar10. dollar11. dollar11. dollar10. dollar11. dollar8. dollar11. dollar10.;
%LET r=dollar10. dollar11.;

**--Generate table H68.--**;
 
PUT #6
    @2 'H68. INCLUSION OF UTILITIES IN RENT'
  / @2 'Universe: Specified Renter-Occupied'
  / @2 '          Housing Units'
 // @2 'Specified Units:' @28 h68i1 comma11.
  / @2 ' Pay Extra for One or'
  / @2 '  More Utilities' @28 h68i2 comma11.            
  / @2 ' No Extra Payment' @28 h68i3 comma11.;  
 
**--Generate tables H53/H65.--**;

if h53i1>0 then totmeal=h65i1/h53i1; else totmeal=.;
if (h53i3+h53i6+h53i9+h53i12)>0 then withmeal=h65i2/(h53i3+h53i6+h53i9+h53i12); else withmeal=.;
if (h53i4+h53i7+h53i10+h53i13)>0 then nomeal=h65i3/(h53i4+h53i7+h53i10+h53i13); else nomeal=.;

Put #6
    @41 'H52/H65. MEAN GROSS RENT BY MEALS'
  / @41 '         INCLUDED IN RENT'
  / @41 'Universe: Specified Renter-Occupied' 
  / @41 '   Housing Units Paying Cash Rent'
 // @41 'Specified Units:' @68 totmeal dollar8.  
  / @41 ' Meals Included' @68 withmeal dollar8.
  / @41 ' Meals Not Included' @68 nomeal dollar8.;

 **--Generate table H67.--**;

array bed0{8} h67i3-h67i10;
array bed1{8} h67i12-h67i19;
array bed2{8} h67i21-h67i28;
array bed3{8} h67i30-h67i37;
array  totbed{8};

do i=1 to 8;
  totbed{i}=bed0{i}+bed1{i}+bed2{i}+bed3{i};
end;
 
Put #6
    @78 'H67. BEDROOMS BY GROSS RENT'
  / @78 'Universe: Specified Renter-Occupied Housing Units' 
 // @106 '----------------- Bedrooms ----------------'
  / @100 'Total       None          1          2  3 or more'
 // @78 'Specified Units:' @95 (h67i1 h67i2 h67i11 h67i20 h67i29) (&h)
  / @78 ' With Cash Rent:' @95 (totbed1 h67i3 h67i12 h67i21 h67i30) (&h)
  / @78 '  Less than $200' @95 (totbed2 h67i4 h67i13 h67i22 h67i31) (&h) 
  / @78 '  $200 to $299' @95 (totbed3 h67i5 h67i14 h67i23 h67i32) (&h)
  / @78 '  $300 to $499' @95 (totbed4 h67i6 h67i15 h67i24 h67i33) (&h) 
  / @78 '  $500 to $749' @95 (totbed5 h67i7 h67i16 h67i25 h67i34) (&h)
  / @78 '  $750 to $999' @95 (totbed6 h67i8 h67i17 h67i26 h67i35) (&h)
  / @78 '  $1,000 or More' @95 (totbed7 h67i9 h67i18 h67i27 h67i36) (&h) 
  / @78 ' No Cash Rent' @95 (totbed8 h67i10 h67i19 h67i28 h67i37) (&h); 

 **--Generate tables H69-H70.--**;

Put #15
    @2 'H69/H70. GROSS RENT AS A PERCENTAGE OF HOUSEHOLD INCOME IN 1999'
  / @2 'Universe: Specified Renter-Occupied Housing Units'
 // @2 'Specified Units:' @26 h69i1 comma10.
  / @2 ' Less than 10.0 Percent' @26 h69i2 comma10. @43 '30.0 to 34.9 Percent' @66 h69i7 comma10.
  / @2 ' 10.0 to 14.9 Percent' @26 h69i3 comma10. @43 '35.0 to 39.9 Percent' @66 h69i8 comma10.
  / @2 ' 15.0 to 19.9 Percent' @26 h69i4 comma10. @43 '40.0 to 49.9 Percent' @66 h69i9 comma10.
  / @2 ' 20.0 to 24.9 Percent' @26 h69i5 comma10. @43 '50.0 Percent or More' @66 h69i10 comma10.
  / @2 ' 25.0 to 29.9 Percent' @26 h69i6 comma10. @43 'Not Computed' @66 h69i11 comma10.
 // @2 'Median Percentage of 1999 Household Income spent on Gross Rent' @71 h70i1 5.1 '%';

 **--Generate tables H54/H56/H58-H64/HCT36A-I/HCT37A-1/HCT38A-I.--**;

if h54i1>0 then mnrt1=h58i1/h54i1; else mnrt1=.;
if h62i1>0 then mnrt2=h64i1/h62i1; else mnrt2=.;
if hct36ai1>0 then mnrt3=hct38ai1/hct36ai1; else mnrt3=.;
if hct36bi1>0 then mnrt4=hct38bi1/hct36bi1; else mnrt4=.;
if hct36ci1>0 then mnrt5=hct38ci1/hct36ci1; else mnrt5=.;
if hct36di1>0 then mnrt6=hct38di1/hct36di1; else mnrt6=.;
if hct36ei1>0 then mnrt7=hct38ei1/hct36ei1; else mnrt7=.;
if hct36fi1>0 then mnrt8=hct38fi1/hct36fi1; else mnrt8=.;
if hct36gi1>0 then mnrt9=hct38gi1/hct36gi1; else mnrt9=.;
if hct36hi1>0 then mnrt10=hct38hi1/hct36hi1; else mnrt10=.;
if hct36ii1>0 then mnrt11=hct38ii1/hct36ii1; else mnrt11=.;
if h59i1> 0 then mnrt12=h61i1/h59i1; else mnrt12=.;

 Put #27
    @2 'H54/H56/H58-H64/HCT36A-I/HCT37A-1/HCT38A-I. CONTRACT RENT; GROSS RENT BY RACE AND 
HISPANIC OR LATINO ORIGIN OF HOUSEHOLDER; RENT ASKED'
  / @2  'Two Universes: Specified Renter-Occupied and Specified Vacant-for-Rent Housing Units' 
  / @138 '...........'
  / @30 '------------------------- Gross Rent For Specified Renter-Occupied Housing Units ----------
---------------' @139 'RENT ASKED'
  / @19 'Contract' @35 'Gross' @57 'Black' @64 'Amer Ind'
    @84 ' Nat Haw' @97 'Other' @106 'Two or' @125 'White Alone' @140 'Specified'
  / @23 'Rent' @36 'Rent' @46 'White' @54 '/Af Amer' @64 '/Ala Nat' @78 'Asian'
    @84 '/Pac Isl' @98 'Race' @108 'More' @117 'Hispanic' 
    @127 'not Hisp.' @142 'Vacant-'
  / @22 'Total' @35 'Total' @46 'Alone' @57 'Alone' @67 'Alone' 
    @78 'Alone' @86 'Alone' @97 'Alone' @107 'Races' @116 'or Latino' 
    @127 'or Latino' @141 'For-Rent'
 // @2 'Spec. Units:' @17 h54i1 &f @30 (h62i1 hct36ai1 hct36bi1 hct36ci1 hct36di1 hct36ei1
                hct36fi1 hct36gi1) (&g) @115 (hct36hi1 hct36ii1) (&k) @139 h59i1 &f
  / @2 ' Cash Rent:' @17 h54i2 &f @30 (h62i2 hct36ai2 hct36bi2 hct36ci2 hct36di2 hct36ei2
                hct36fi2 hct36gi2) (&g) @115 (hct36hi2 hct36ii2) (&k)
  / @2 ' Under $100' @17 h54i3 &f @30 (h62i3 hct36ai3 hct36bi3 hct36ci3 hct36di3 hct36ei3
                hct36fi3 hct36gi3) (&g) @115 (hct36hi3 hct36ii3) (&k) @139 h59i2 &f
  / @2 ' $100-$149' @17 h54i4 &f @30 (h62i4 hct36ai4 hct36bi4 hct36ci4 hct36di4 hct36ei4
                hct36fi4 hct36gi4) (&g) @115 (hct36hi4 hct36ii4) (&k) @139 h59i3 &f
  / @2 ' $150-$199' @17 h54i5 &f @30 (h62i5 hct36ai5 hct36bi5 hct36ci5 hct36di5 hct36ei5
                hct36fi5 hct36gi5) (&g) @115 (hct36hi5 hct36ii5) (&k) @139 h59i4 &f
  / @2 ' $200-$249' @17 h54i6 &f @30 (h62i6 hct36ai6 hct36bi6 hct36ci6 hct36di6 hct36ei6
                hct36fi6 hct36gi6) (&g) @115 (hct36hi6 hct36ii6) (&k) @139 h59i5 &f
  / @2 ' $250-$299' @17 h54i7 &f @30 (h62i7 hct36ai7 hct36bi7 hct36ci7 hct36di7 hct36ei7
                hct36fi7 hct36gi7) (&g) @115 (hct36hi7 hct36ii7) (&k) @139 h59i6 &f
  / @2 ' $300-$349' @17 h54i8 &f @30 (h62i8 hct36ai8 hct36bi8 hct36ci8 hct36di8 hct36ei8
                hct36fi8 hct36gi8) (&g) @115 (hct36hi8 hct36ii8) (&k) @139 h59i7 &f
  / @2 ' $350-$399' @17 h54i9 &f @30 (h62i9 hct36ai9 hct36bi9 hct36ci9 hct36di9 hct36ei9
                hct36fi9 hct36gi9) (&g) @115 (hct36hi9 hct36ii9) (&k) @139 h59i8 &f
  / @2 ' $400-$449' @17 h54i10 &f @30 (h62i10 hct36ai10 hct36bi10 hct36ci10 hct36di10 hct36ei10
                hct36fi10 hct36gi10) (&g) @115 (hct36hi10 hct36ii10) (&k) @139 h59i9 &f
  / @2 ' $450-$499' @17 h54i11 &f @30 (h62i11 hct36ai11 hct36bi11 hct36ci11 hct36di11 hct36ei11
                hct36fi11 hct36gi11) (&g) @115 (hct36hi11 hct36ii11) (&k) @139 h59i10 &f
  / @2 ' $500-$549' @17 h54i12 &f @30 (h62i12 hct36ai12 hct36bi12 hct36ci12 hct36di12 hct36ei12
                hct36fi12 hct36gi12) (&g) @115 (hct36hi12 hct36ii12) (&k) @139 h59i11 &f 
  / @2 ' $550-$599' @17 h54i13 &f @30 (h62i13 hct36ai13 hct36bi13 hct36ci13 hct36di13 hct36ei13
                hct36fi13 hct36gi13) (&g) @115 (hct36hi13 hct36ii13) (&k) @139 h59i12 &f
  / @2 ' $600-$649' @17 h54i14 &f @30 (h62i14 hct36ai14 hct36bi14 hct36ci14 hct36di14 hct36ei14
                hct36fi14 hct36gi14) (&g) @115 (hct36hi14 hct36ii14) (&k) @139 h59i13 &f
  / @2 ' $650-$699' @17 h54i15 &f @30 (h62i15 hct36ai15 hct36bi15 hct36ci15 hct36di15 hct36ei15
                hct36fi15 hct36gi15) (&g) @115 (hct36hi15 hct36ii15) (&k) @139 h59i14 &f
  / @2 ' $700-$749' @17 h54i16 &f @30 (h62i16 hct36ai16 hct36bi16 hct36ci16 hct36di16 hct36ei16
                hct36fi16 hct36gi16) (&g) @115 (hct36hi16 hct36ii16) (&k) @139 h59i15 &f
  / @2 ' $750-$799' @17 h54i17 &f @30 (h62i17 hct36ai17 hct36bi17 hct36ci17 hct36di17 hct36ei17
                hct36fi17 hct36gi17) (&g) @115 (hct36hi17 hct36ii17) (&k) @139 h59i16 &f
  / @2 ' $800-$899' @17 h54i18 &f @30 (h62i18 hct36ai18 hct36bi18 hct36ci18 hct36di18 hct36ei18
                hct36fi18 hct36gi18) (&g) @115 (hct36hi18 hct36ii18) (&k) @139 h59i17 &f
  / @2 ' $900-$999' @17 h54i19 &f @30 (h62i19 hct36ai19 hct36bi19 hct36ci19 hct36di19 hct36ei19
                hct36fi19 hct36gi19) (&g) @115 (hct36hi19 hct36ii19) (&k) @139 h59i18 &f
  / @2 ' $1,000-$1,249' @17 h54i20 &f @30 (h62i20 hct36ai20 hct36bi20 hct36ci20 hct36di20 hct36ei20
                hct36fi20 hct36gi20) (&g) @115 (hct36hi20 hct36ii20) (&k) @139 h59i19 &f
  / @2 ' $1,250-$1,499' @17 h54i21 &f @30 (h62i21 hct36ai21 hct36bi21 hct36ci21 hct36di21 hct36ei21
                hct36fi21 hct36gi21) (&g) @115 (hct36hi21 hct36ii21) (&k) @139 h59i20 &f
  / @2 ' $1,500-$1,999' @17 h54i22 &f @30 (h62i22 hct36ai22 hct36bi22 hct36ci22 hct36di22 hct36ei22
                hct36fi22 hct36gi22) (&g) @115 (hct36hi22 hct36ii22) (&k) @139 h59i21 &f 
  / @2 ' $2,000 or more' @17 h54i23 &f @30 (h62i23 hct36ai23 hct36bi23 hct36ci23 hct36di23 hct36ei23
                hct36fi23 hct36gi23) (&g) @115 (hct36hi23 hct36ii23) (&k) @139 h59i22 &f
  / @2 ' No Cash Rent' @17 h54i24 &f @30 (h62i24 hct36ai24 hct36bi24 hct36ci24 hct36di24 hct36ei24
                hct36fi24 hct36gi24) (&g) @115 (hct36hi24 hct36ii24) (&k) @139  '       N/A' 
 // @2 'Median Rent' @17 h56i1 &p @30 (h63i1 hct37ai1 hct37bi1 hct37ci1 hct37di1 hct37ei1
                hct37fi1 hct37gi1) (&q) @115 (hct37hi1 hct37ii1) (&r) @139 h60i1 &p
  / @2 'Mean Rent' @17 mnrt1 &p @30 (mnrt2 mnrt3 mnrt4 mnrt5 mnrt6 mnrt7
                mnrt8 mnrt9) (&q) @115 (mnrt10 mnrt11) (&r) @139 mnrt12 &p;

link HeadFoot; 
end;  *<-----------of code to generate page 4 ----;
RETURN;




