povprof:

/* generate poverty profile, eight pages of poverty characteristics.
    Phyllis Smith & Amrut Khatri, Arkansas.
  8/02/02: corrections by rw & PSU group
  8/08/02: column added to p.8 by Amrut & rw
  8/12/02: all percent calculations tested for division by zero (rw)
  8/30/02: testing mean income deficit for division by zero (Thanks, Sen-Yuan Wu, NJ SDC)
*/

* do all 8 pages if _pages is null, blank or ALL ;
IF _pages IN ('',' ','all','ALL') THEN _pages='12345678' ;

* because some long lines are getting truncated-- ;
%LET f9  = Comma9. ;
%LET f10 = Comma10. ;
%LET f11 = Comma11. ;

IF INDEX(_pages,'1') THEN DO;

%PutTitle(
   %STR(Poverty Profile 1: PERSONS AND HOUSEHOLDS BY HOUSEHOLD TYPE AND HOUSEHOLDER AGE),
   %STR(Pov-1)) ;

**--Draw horizontal lines--**;
PUT #24 @2 148*'-';
PUT #42 @2 148*'-';
PUT #57 @2 148*'-';

**--Draw (internal) vertical lines--**;

do _i_=13 to 23;
  PUT #_I_ @105 '|';
  end;

do _i_=43 to 56;
  PUT #_I_ @74 '|';
  end;

do _i_=51 to 55;
  PUT #_I_ @112 '|';
  end;


*--Generate table P89.--**;

PUT #8

   @3 'P89. POVERTY STATUS IN 1999 BY AGE BY HOUSEHOLD TYPE'
 / @3 'Universe: Population for whom poverty status is determined (*)';

*--Generate table P91.--**;
array P89TB (5);
array P89TA (5);
array Tot (5);

**-----Calculate Total Below Poverty-----**;
P89TB1=P89i4+P89i10+P89i16;
P89TB2=P89i5+P89i11+P89i17;
P89TB3=P89i6+P89i12+P89i18;
P89TB4=P89i7+P89i13+P89i19;
P89TB5=P89i8+P89i14+P89i20;

**-----Calculate Total Above Poverty-----**;
P89TA1=P89i23+P89i29+P89i35;
P89TA2=P89i24+P89i30+P89i36;
P89TA3=P89i25+P89i31+P89i37;
P89TA4=P89i26+P89i32+P89i38;
P89TA5=P89i27+P89i33+P89i39;

Do i=1 to 5;
   Tot(i)=P89TB(i)+P89TA(i);
end;

**-----Calculate Percent Total Below Poverty-----**;
IF P89i1=0 THEN PCT1=. ; ELSE PCT1=P89i2 *100/P89i1;
IF Tot1=0 THEN PCT2=.  ; ELSE PCT2=P89TB1*100/Tot1;
IF Tot2=0 THEN PCT3=.  ; ELSE PCT3=P89TB2*100/Tot2;
IF Tot3=0 THEN PCT4=.  ; ELSE PCT4=P89TB3*100/Tot3;
IF Tot4=0 THEN PCT5=.  ; ELSE PCT5=P89TB4*100/Tot4;
IF Tot5=0 THEN PCT6=.  ; ELSE PCT6=P89TB5*100/Tot5;

**-----Calculate Mean Income Deficit-----**;
* must include the aggreg. deficit of unrelated indiv's in MEINC1! 8/2/02 ;
IF P89i2=0  THEN MEINC1=. ; ELSE MEINC1 = (P91i1+PCT54i1)/P89i2;  
IF P89TB1=0 THEN MEINC2=. ; ELSE MEINC2 = P91i2/P89TB1;
IF P89TB2=0 THEN MEINC3=. ; ELSE MEINC3 = P91i3/P89TB2;
IF P89TB3=0 THEN MEINC4=. ; ELSE MEINC4 = P91i4/P89TB3;
IF P89TB4=0 THEN MEINC5=. ; ELSE MEINC5 = P91i5/P89TB4;
IF P89TB5=0 THEN MEINC6=. ; ELSE MEINC6 = PCT54i1/P89TB5;

PUT #10

   @3 'P91/PCT54. INCOME DEFICIT IN 1999 FOR FAMILIES BY FAMILY TYPE AND UNRELATED INDIVIDUALS'
 / @3 'Two universes: Families and unrelated individuals with income in 1999 below the poverty level'
 /                                                                                                                                                                                                       @121 'Population with'
 /                                                          @48 '---Population with Income in 1999 below Poverty Level---'                                                           @106 '- Income in 1999 at or above Poverty Level-'
 /                                                                                                                                                               @101'Mean'
 /                                                          @51'--All Ages--'                                                                                    @99'Income'
 /                                      @41'Total'          @51'Number'         @59'Pct.'    @66    'Under 65'   @77'65 to 74'         @87'75 & Over'      @97':'@98'Deficit'       @108 'All Ages'     @119 'Under 65'    @130'65 to 74'     @140'75 & Over'
 /                                                                                                                                                         @97':'
/   @3 'Total in Poverty Universe*:'    @35 P89i1 &f11   @47 P89i2   &f10 @58 PCT1 5.1 @64  P89i3 &f10  @75  P89i9  &f10   @86 P89i15 &f10  @97':'@98 MEINC1 Dollar7.@106 P89i21 &f10 @117P89i22 &f10 @128P89i28 &f10 @139P89i34 &f10
 / @3 ' In Married-Couple Families'     @35 Tot1  &f11   @47 P89TB1  &f10 @58 PCT2 5.1 @64  P89i4 &f10  @75  P89i10 &f10   @86 P89i16 &f10  @97':'@98 MEINC2 Dollar7.@106 P89TA1 &f10 @117P89i23 &f10 @128P89i29 &f10 @139P89i35 &f10
 / @3 ' In Other Families:'             @35 Tot2  &f11   @47 P89TB2  &f10 @58 PCT3 5.1 @64  P89i5 &f10  @75  P89i11 &f10   @86 P89i17 &f10  @97':'@98 MEINC3 Dollar7.@106 P89TA2 &f10 @117P89i24 &f10 @128P89i30 &f10 @139P89i36 &f10
 / @3 '  Male Householder,No Wife'      @35 Tot3  &f11   @47 P89TB3  &f10 @58 PCT4 5.1 @64  P89i6 &f10  @75  P89i12 &f10   @86 P89i18 &f10  @97':'@98 MEINC4 Dollar7.@106 P89TA3 &f10 @117P89i25 &f10 @128P89i31 &f10 @139P89i37 &f10
 / @3 '  Female Householder,No Husband' @35 Tot4  &f11   @47 P89TB4  &f10 @58 PCT5 5.1 @64  P89i7 &f10  @75  P89i13 &f10   @86 P89i19 &f10  @97':'@98 MEINC5 Dollar7.@106 P89TA4 &f10 @117P89i26 &f10 @128P89i32 &f10 @139P89i38 &f10
 / @3 ' Unrelated Individuals'          @35 Tot5  &f11   @47 P89TB5  &f10 @58 PCT6 5.1 @64  P89i8 &f10  @75  P89i14 &f10   @86 P89i20 &f10  @97':'@98 MEINC6 Dollar7.@106 P89TA5 &f10 @117P89i27 &f10 @128P89i33 &f10 @139P89i39 &f10 ;


/*--Generate table P92.--**/;

**-----Calculate NonFamily HH below Poverty-----**;

array maleb (4) P92i22-P92i25;
array femaleb (4) P92i27-P92i30;
array tbnf (4);

Do i=1 to 4;
    tbnf(i)=maleb(i)+ femaleb(i);
end;

**-----Calculate NonFamily HH above Poverty-----**;

array malea (4) P92i51-P92i54;
array femalea (4) P92i56-P92i59;
array tanf (4);

Do i=1 to 4;
    tanf(i)=malea(i)+ femalea(i);
end;

**-----Calculate Other Family HH below Poverty-----**;

array mbof (4) P92i11-P92i14;
array fbof (4) P92i16-P92i19;
array tbof (4);

Do i=1 to 4;
    tbof(i)=mbof(i)+ fbof(i);
end;

**-----Calculate Other Family HH above Poverty-----**;

array maof (4) P92i40-P92i43;
array faof (4) P92i45-P92i48;
array taoff (4);

Do i=1 to 4;
    taoff(i)=maof(i)+ faof(i);
end;

**-----Calculate Family HH below Poverty-----**;
array mcfb (4) P92i5-P92i8;
array fhb  (4);

Do i=1 to 4;
    fhb(i)=mcfb (i)+ tbof (i);
end;

**-----Calculate Family HH above Poverty-----**;

array mcfa (4) P92i34-P92i37;
array fha  (4);

Do i=1 to 4;
    fha(i)=mcfa (i)+ taoff (i);
end;

**-----Calculate HH below Poverty-----**;

array thb (4);
Do i=1 to 4;
    thb(i)=fhb (i)+ tbnf (i);
end;

**-----Calculate HH above Poverty-----**;

array tha (4);
Do i=1 to 4;
    tha(i)=fha (i)+ tanf (i);
end;

**-----Calculate Total In Poverty-----**;
P92t1=P92i3+P92i32;
P92t2=P92i4+P92i33;
P92t3=P92i9+P92i38;
P92t4=P92i10+P92i39;
P92t5=P92i15+P92i44;
P92t6=P92i20+P92i49;
P92t7=P92i21+P92i50;
P92t8=P92i26+P92i55;

**-----Calculate Percent Total below Poverty-----**;
IF  P92i1=0 THEN PCT1=. ; ELSE PCT1=P92i2 *100/ P92i1;
IF  P92t1=0 THEN PCT2=. ; ELSE PCT2=P92i3 *100/ P92t1;
IF  P92t2=0 THEN PCT3=. ; ELSE PCT3=P92i4 *100/ P92t2;
IF  P92t3=0 THEN PCT4=. ; ELSE PCT4=P92i9 *100/ P92t3;
IF  P92t4=0 THEN PCT5=. ; ELSE PCT5=P92i10*100/ P92t4;
IF  P92t5=0 THEN PCT6=. ; ELSE PCT6=P92i15*100/ P92t5;
IF  P92t6=0 THEN PCT7=. ; ELSE PCT7=P92i20*100/ P92t6;
IF  P92t7=0 THEN PCT8=. ; ELSE PCT8=P92i21*100/ P92t7;
IF  P92t8=0 THEN PCT9=. ; ELSE PCT9=P92i26*100/ P92t8;



PUT #26
   @3 'P92. POVERTY STATUS IN 1999 OF HOUSEHOLDS BY HOUSEHOLD TYPE BY AGE OF HOUSEHOLDER'
 / @3 'Universe: Households(**)'
 /                                                                              @64 'Households with'                                                                                                      @114 'Households with'
 /                                                          @46 '---------Income in 1999 below Poverty Level---------'                                                    @98 ' ----Income in 1999 at or above Poverty Level----- '
 /                                                          @46 '--All Ages--'
 /                                      @38 'Total'         @47 'Number'        @54'Pct.'         @60'Under 25'     @70 '25 to 44'      @80 '45 to 64'  @89'65 & Over'        @100 'All Ages'     @110'Under 25'      @120 '25 to 44'     @130 '45 to 64'
@139  '65 & Over'
 //@3 'Total Households:'               @34  P92i1 &f9   @44  P92i2  &f9  @54 PCT1 4.1   @59 thb1   &f9 @69   thb2   &f9 @79 thb3   &f9 @89  thb4   &f9  @99  P92i31 &f9  @109  tha1   &f9 @119  tha2   &f9 @129  tha3   &f9
@139  tha4   &f9
 / @3 ' Family Households:'             @34  P92t1 &f9   @44  P92i3  &f9  @54 PCT2 4.1   @59 fhb1   &f9 @69   fhb2   &f9 @79 fhb3   &f9 @89  fhb4   &f9  @99  P92i32 &f9  @109  fha1   &f9 @119  fha2   &f9 @129  fha3   &f9
@139  fha4   &f9
 / @3 '  Marr-Cpl Family Households'    @34  P92t2 &f9   @44  P92i4  &f9  @54 PCT3 4.1   @59 P92i5  &f9 @69   P92i6  &f9 @79 P92i7  &f9 @89  P92i8  &f9  @99  P92i33 &f9  @109  P92i34 &f9 @119  P92i35 &f9 @129  P92i36 &f9
@139  P92i37 &f9
 / @3 '  Other Fam Hholds (No Spouse):' @34  P92t3 &f9   @44  P92i9  &f9  @54 PCT4 4.1   @59 tbof1  &f9 @69   tbof2  &f9 @79 tbof3  &f9 @89  tbof4  &f9  @99  P92i38 &f9  @109  taoff1 &f9 @119  taoff2 &f9 @129  taoff3 &f9
@139  taoff4 &f9
 / @3 '   Male Householder,No Wife'     @34  P92t4 &f9   @44  P92i10 &f9  @54 PCT5 4.1   @59 P92i11 &f9 @69   P92i12 &f9 @79 P92i13 &f9 @89  P92i14 &f9  @99  P92i39 &f9  @109  P92i40 &f9 @119  P92i41 &f9 @129  P92i42 &f9
@139  P92i43 &f9
 / @3 '   Female Hholder,No Husband'    @34  P92t5 &f9   @44  P92i15 &f9  @54 PCT6 4.1   @59 P92i16 &f9 @69   P92i17 &f9 @79 P92i18 &f9 @89  P92i19 &f9  @99  P92i44 &f9  @109  P92i45 &f9 @119  P92i46 &f9 @129  P92i47 &f9
@139  P92i48 &f9
 / @3 ' Nonfamily Households:'          @34  P92t6 &f9   @44  P92i20 &f9  @54 PCT7 4.1   @59 tbnf1  &f9 @69   tbnf2  &f9 @79 tbnf3  &f9 @89  tbnf4  &f9  @99  P92i49 &f9  @109  tanf1  &f9 @119  tanf2  &f9 @129  tanf3  &f9
@139  tanf4  &f9
 / @3 '  Male Householder'              @34  P92t7 &f9   @44  P92i21 &f9  @54 PCT8 4.1   @59 P92i22 &f9 @69   P92i23 &f9 @79 P92i24 &f9 @89  P92i25 &f9  @99  P92i50 &f9  @109  P92i51 &f9 @119  P92i52 &f9 @129  P92i53 &f9
@139  P92i54 &f9
 / @3 '  Female Householder'            @34  P92t8 &f9   @44  P92i26 &f9  @54 PCT9 4.1   @59 P92i27 &f9 @69   P92i28 &f9 @79 P92i29 &f9 @89  P92i30 &f9  @99  P92i55 &f9  @109  P92i56 &f9 @119  P92i57 &f9 @129  P92i58 &f9
@139  P92i59 &f9  ;


/*--Generate table P93.--**/;
array P93low (8) P93i3 -P93i10;
array P93hi  (8) P93i12-P93i19;
array P93sum (8);

Do i=1 to 8;
    P93sum(i)=P93low(i)+ P93hi(i);
end;

PUT #44
   @3 'P93. RATIO OF INCOME IN 1999 TO POVERTY LEVEL BY HOUSEHOLD TYPE'
 / @3 'Universe: Households(**)'
 /                                      @42 'Total'             @49 'Under 1.50'    @61'1.50 & Over'
 // @3'Total Households:'               @36 P93i1    &f11    @49 P93i2  &f10  @62  P93i11 &f10
 / @3' Family Households:'              @36 P93sum1  &f11    @49 P93i3  &f10  @62  P93i12 &f10
 / @3'  Marr-Couple Family Households:' @36 P93sum2  &f11    @49 P93i4  &f10  @62  P93i13 &f10
 / @3'  Other Family Households:'       @36 P93sum3  &f11    @49 P93i5  &f10  @62  P93i14 &f10
 / @3'   Male Householder,No Wife'      @36 P93sum4  &f11    @49 P93i6  &f10  @62  P93i15 &f10
 / @3'   Female Householder,No Husband' @36 P93sum5  &f11    @49 P93i7  &f10  @62  P93i16 &f10
 / @3' Nonfamily Households:'           @36 P93sum6  &f11    @49 P93i8  &f10  @62  P93i17 &f10
 / @3'  Male Householder'               @36 P93sum7  &f11    @49 P93i9  &f10  @62  P93i18 &f10
 / @3'  Female Householder'             @36 P93sum8  &f11    @49 P93i10 &f10  @62  P93i19 &f10  ;

/*--Generate table P88.--**/;
IF  P88i1=0 THEN DO ;
  PCT1 =. ; PCT2 =. ; PCT3 =. ; PCT4 =. ; PCT5 =. ;
  PCT6 =. ; PCT7 =. ; PCT8 =. ; PCT9 =. ; PCT10=. ;
END ;
ELSE DO ;
  PCT1 =P88i1  *100/ P88i1 ;
  PCT2 =P88i2  *100/ P88i1 ;
  PCT3 =P88i3  *100/ P88i1 + PCT2 ;
  PCT4 =P88i4  *100/ P88i1 + PCT3 ;
  PCT5 =P88i5  *100/ P88i1 + PCT4 ;
  PCT6 =P88i6  *100/ P88i1 + PCT5 ;
  PCT7 =P88i7  *100/ P88i1 + PCT6 ;
  PCT8 =P88i8  *100/ P88i1 + PCT7 ;
  PCT9 =P88i9  *100/ P88i1 + PCT8 ;
  PCT10=P88i10 *100/ P88i1 + PCT9 ;
END ;

PUT #44
   @76 'P88. RATIO OF 1999 INCOME TO POVERTY LEVEL'
 / @76 'Universe: Population for whom poverty status is determined(*)'
 //                                @101 'Cumulative'                                  @138'Cumulative'
 /                  @93 'Persons'      @104'Percent'                  @130 'Persons'      @141'Percent'
 / @76 'Total:'     @89  P88i1 &f11 @106 PCT1 5.1
 //@76 'Under 0.50' @89  P88i2 &f11 @106 PCT2 5.1 @114'1.50 - 1.74'@126 P88i7 &f11 @143 PCT7 5.1
 / @76 '0.50 - 0.74'@89  P88i3 &f11 @106 PCT3 5.1 @114'1.75 - 1.84'@126 P88i8 &f11 @143 PCT8 5.1
 / @76 '0.75 - 0.99'@89  P88i4 &f11 @106 PCT4 5.1 @114'1.85 - 1.99'@126 P88i9 &f11 @143 PCT9 5.1
 / @76 '1.00 - 1.24'@89  P88i5 &f11 @106 PCT5 5.1 @114'2.00 & Over'@126 P88i10 &f11@143 PCT10 5.1
 / @76 '1.25 - 1.49'@89  P88i6 &f11 @106 PCT6 5.1 ;

PUT #58
 @3' * Poverty universe includes all people EXCEPT (1) those in institutions, military group quarters, and college dormitories and (2) unrelated'
/@3'   individuals under 15 years old (children who are not related family members).'
/@3'** Poverty status is NOT determined for households. The counts in this table actually reflect the poverty status of the householder.'  ;
link HeadFoot;
end;  *<-----------of code to generate 1st page----;


IF INDEX(_pages,'2') THEN DO;


%PutTitle(
   %STR(Poverty Profile 2: FAMILIES BY FAMILY TYPE (PART 1 OF 2: BELOW POVERTY)),
   %STR(Pov-2)) ;

**--Draw horizontal lines--**;
PUT #57 @2 147*'-';

**--Draw (internal) vertical lines--**;

do _i_=15 to 54;
  PUT #_I_ @50 ':';
  end;

do _i_=15 to 54;
  PUT #_I_ @127 ':';
  end;

*--Generate table P90/P160.--**;

*--Total Families Percent below poverty --**;
IF (P90i2+P90i22)=0     THEN PTFBP1=. ; ELSE PTFBP1=P90i2  *100/(P90i2+P90i22);
IF (P160Ai2+P160Ai22)=0 THEN PTFBP2=. ; ELSE PTFBP2=P160Ai2*100/(P160Ai2+P160Ai22);
IF (P160Bi2+P160Bi22)=0 THEN PTFBP3=. ; ELSE PTFBP3=P160Bi2*100/(P160Bi2+P160Bi22);
IF (P160Ci2+P160Ci22)=0 THEN PTFBP4=. ; ELSE PTFBP4=P160Ci2*100/(P160Ci2+P160Ci22);
IF (P160Di2+P160Di22)=0 THEN PTFBP5=. ; ELSE PTFBP5=P160Di2*100/(P160Di2+P160Di22);
IF (P160Ei2+P160Ei22)=0 THEN PTFBP6=. ; ELSE PTFBP6=P160Ei2*100/(P160Ei2+P160Ei22);
IF (P160Fi2+P160Fi22)=0 THEN PTFBP7=. ; ELSE PTFBP7=P160Fi2*100/(P160Fi2+P160Fi22);
IF (P160Gi2+P160Gi22)=0 THEN PTFBP8=. ; ELSE PTFBP8=P160Gi2*100/(P160Gi2+P160Gi22);
IF (P160Hi2+P160Hi22)=0 THEN PTFBP9=. ; ELSE PTFBP9=P160Hi2*100/(P160Hi2+P160Hi22);
IF (P160ii2+P160ii22)=0 THEN PTFBP10=.; ELSE PTFBP10=P160ii2*100/(P160ii2+P160ii22);

*--Married-Couples Percent below poverty --**;

IF (P90i3+P90i23)=0 THEN     PMCBP1=. ; ELSE PMCBP1=P90i3  *100/(P90i3+P90i23);
IF (P160Ai3+P160Ai23)=0 THEN PMCBP2=. ; ELSE PMCBP2=P160Ai3*100/(P160Ai3+P160Ai23);
IF (P160Bi3+P160Bi23)=0 THEN PMCBP3=. ; ELSE PMCBP3=P160Bi3*100/(P160Bi3+P160Bi23);
IF (P160Ci3+P160Ci23)=0 THEN PMCBP4=. ; ELSE PMCBP4=P160Ci3*100/(P160Ci3+P160Ci23);
IF (P160Di3+P160Di23)=0 THEN PMCBP5=. ; ELSE PMCBP5=P160Di3*100/(P160Di3+P160Di23);
IF (P160Ei3+P160Ei23)=0 THEN PMCBP6=. ; ELSE PMCBP6=P160Ei3*100/(P160Ei3+P160Ei23);
IF (P160Fi3+P160Fi23)=0 THEN PMCBP7=. ; ELSE PMCBP7=P160Fi3*100/(P160Fi3+P160Fi23);
IF (P160Gi3+P160Gi23)=0 THEN PMCBP8=. ; ELSE PMCBP8=P160Gi3*100/(P160Gi3+P160Gi23);
IF (P160Hi3+P160Hi23)=0 THEN PMCBP9=. ; ELSE PMCBP9=P160Hi3*100/(P160Hi3+P160Hi23);
IF (P160ii3+P160ii23)=0 THEN PMCBP10=.; ELSE PMCBP10=P160ii3*100/(P160ii3+P160ii23);

*--Other Families Percent below poverty --**;

IF (P90i9+P90i29)=0 THEN     POFBP1=. ; ELSE POFBP1=P90i9  *100/(P90i9+P90i29);
IF (P160Ai9+P160Ai29)=0 THEN POFBP2=. ; ELSE POFBP2=P160Ai9*100/(P160Ai9+P160Ai29);
IF (P160Bi9+P160Bi29)=0 THEN POFBP3=. ; ELSE POFBP3=P160Bi9*100/(P160Bi9+P160Bi29);
IF (P160Ci9+P160Ci29)=0 THEN POFBP4=. ; ELSE POFBP4=P160Ci9*100/(P160Ci9+P160Ci29);
IF (P160Di9+P160Di29)=0 THEN POFBP5=. ; ELSE POFBP5=P160Di9*100/(P160Di9+P160Di29);
IF (P160Ei9+P160Ei29)=0 THEN POFBP6=. ; ELSE POFBP6=P160Ei9*100/(P160Ei9+P160Ei29);
IF (P160Fi9+P160Fi29)=0 THEN POFBP7=. ; ELSE POFBP7=P160Fi9*100/(P160Fi9+P160Fi29);
IF (P160Gi9+P160Gi29)=0 THEN POFBP8=. ; ELSE POFBP8=P160Gi9*100/(P160Gi9+P160Gi29);
IF (P160Hi9+P160Hi29)=0 THEN POFBP9=. ; ELSE POFBP9=P160Hi9*100/(P160Hi9+P160Hi29);
IF (P160ii9+P160ii29)=0 THEN POFBP10=.; ELSE POFBP10=P160ii9*100/(P160ii9+P160ii29);

*--Male Householder, No wife Percent below poverty --**;

IF (P90i10+P90i30)=0     THEN PMHBP1=. ; ELSE PMHBP1=P90i10  *100/(P90i10+P90i30);
IF (P160Ai10+P160Ai30)=0 THEN PMHBP2=. ; ELSE PMHBP2=P160Ai10*100/(P160Ai10+P160Ai30);
IF (P160Bi10+P160Bi30)=0 THEN PMHBP3=. ; ELSE PMHBP3=P160Bi10*100/(P160Bi10+P160Bi30);
IF (P160Ci10+P160Ci30)=0 THEN PMHBP4=. ; ELSE PMHBP4=P160Ci10*100/(P160Ci10+P160Ci30);
IF (P160Di10+P160Di30)=0 THEN PMHBP5=. ; ELSE PMHBP5=P160Di10*100/(P160Di10+P160Di30);
IF (P160Ei10+P160Ei30)=0 THEN PMHBP6=. ; ELSE PMHBP6=P160Ei10*100/(P160Ei10+P160Ei30);
IF (P160Fi10+P160Fi30)=0 THEN PMHBP7=. ; ELSE PMHBP7=P160Fi10*100/(P160Fi10+P160Fi30);
IF (P160Gi10+P160Gi30)=0 THEN PMHBP8=. ; ELSE PMHBP8=P160Gi10*100/(P160Gi10+P160Gi30);
IF (P160Hi10+P160Hi30)=0 THEN PMHBP9=. ; ELSE PMHBP9=P160Hi10*100/(P160Hi10+P160Hi30);
IF (P160ii10+P160ii30)=0 THEN PMHBP10=.; ELSE PMHBP10=P160ii10*100/(P160ii10+P160ii30);

*--Female Householder, No Husband Percent below poverty --**;

IF (P90i16+P90i36)=0     THEN PFHBP1=. ; ELSE PFHBP1=P90i16  *100/(P90i16+P90i36);
IF (P160Ai16+P160Ai36)=0 THEN PFHBP2=. ; ELSE PFHBP2=P160Ai16*100/(P160Ai16+P160Ai36);
IF (P160Bi16+P160Bi36)=0 THEN PFHBP3=. ; ELSE PFHBP3=P160Bi16*100/(P160Bi16+P160Bi36);
IF (P160Ci16+P160Ci36)=0 THEN PFHBP4=. ; ELSE PFHBP4=P160Ci16*100/(P160Ci16+P160Ci36);
IF (P160Di16+P160Di36)=0 THEN PFHBP5=. ; ELSE PFHBP5=P160Di16*100/(P160Di16+P160Di36);
IF (P160Ei16+P160Ei36)=0 THEN PFHBP6=. ; ELSE PFHBP6=P160Ei16*100/(P160Ei16+P160Ei36);
IF (P160Fi16+P160Fi36)=0 THEN PFHBP7=. ; ELSE PFHBP7=P160Fi16*100/(P160Fi16+P160Fi36);
IF (P160Gi16+P160Gi36)=0 THEN PFHBP8=. ; ELSE PFHBP8=P160Gi16*100/(P160Gi16+P160Gi36);
IF (P160Hi16+P160Hi36)=0 THEN PFHBP9=. ; ELSE PFHBP9=P160Hi16*100/(P160Hi16+P160Hi36);
IF (P160ii16+P160ii36)=0 THEN PFHBP10=.; ELSE PFHBP10=P160ii16*100/(P160ii16+P160ii36);

%LET p9=8.1 '%' ; * so % signs will be flush ;
%LET p10=9.1 '%' ;
PUT #9
@3 'P90/P160 A-I. POVERTY STATUS IN 1999 OF FAMILIES BY FAMILY TYPE BY PRESENCE AND AGE OF RELATED CHILDREN UNDER 18 YEARS BY'
/@3'              RACE AND HISPANIC/LATINO [PART 1 OF 2 - INCOME IN 1999 BELOW POVERTY LEVEL]'
/@3'Universe: Families'
//                                      @39'----------------------------- Families with Income in 1999 below Poverty Level -------------------------------'
//                                      @51'---------------------------------- Race* -----------------------------------'                                                                               @128'----- Hispanic** -----'
/                                                                                                                                  @96 '  Native'
/                                                                                           @74 'American'                         @96 'Hawaiian'
/                                                                           @63'Black or'   @76 'Indian'                           @97 '& Other'        @111 'Some'                                     @144 'White'
/                                                                           @64'African'    @74 '& Alaska'                         @97 'Pacific'        @110'Other'    @123'Two'                        @139 'Alone, Not'
/                                                          @56'White'       @63'American'   @76 'Native'      @88'Asian'           @96 'Islander'       @111'Race'     @119'or More'   @130'Hispanic'    @141 'Hispanic'
/                                        @40'All Races'    @56'Alone'       @66'Alone'      @77 'Alone'       @88'Alone'           @99 'Alone'          @110'Alone'    @121'Races'     @129'or Latino'   @140 'or Latino'
/
/@3'Total Families below Poverty:'       @40 P90i2  &f9 @52 P160Ai2  &f9 @62 P160Bi2  &f9 @72 P160Ci2  &f10 @83 P160Di2  &f10 @94 P160Ei2  &f10 @105 P160Fi2  &f10 @116 P160Gi2  &f10 @128 P160Hi2  &f10 @139 P160ii2  &f10
/@3' Percent below Poverty Level'        @40 PTFBP1 &p9 @52 PTFBP2   &p9 @62 PTFBP3   &p9 @72 PTFBP4   &p10 @83 PTFBP5   &p10 @94 PTFBP6   &p10 @105 PTFBP7   &p10 @116 PTFBP8   &p10 @128 PTFBP9   &p10 @139 PTFBP10  &p10

//@3' Married-Couple Families:'           @40 P90i3  &f9 @52 P160Ai3  &f9 @62 P160Bi3  &f9 @72 P160Ci3  &f10 @83 P160Di3  &f10 @94 P160Ei3  &f10 @105 P160Fi3  &f10 @116 P160Gi3  &f10 @128 P160Hi3  &f10 @139 P160ii3  &f10
/@3'  Percent below Poverty Level'       @40 PMCBP1 &p9 @52 PMCBP2   &p9 @62 PMCBP3   &p9 @72 PMCBP4   &p10 @83 PMCBP5   &p10 @94 PMCBP6   &p10 @105 PMCBP7   &p10 @116 PMCBP8   &p10 @128 PMCBP9   &p10 @139 PMCBP10  &p10

//@5'With Related Children under 18 Yrs:'@40 P90i4  &f9 @52 P160Ai4  &f9 @62 P160Bi4  &f9 @72 P160Ci4  &f10 @83 P160Di4  &f10 @94 P160Ei4  &f10 @105 P160Fi4  &f10 @116 P160Gi4  &f10 @128 P160Hi4  &f10 @139 P160ii4  &f10
/@3'   Under 5 Years Only'               @40 P90i5  &f9 @52 P160Ai5  &f9 @62 P160Bi5  &f9 @72 P160Ci5  &f10 @83 P160Di5  &f10 @94 P160Ei5  &f10 @105 P160Fi5  &f10 @116 P160Gi5  &f10 @128 P160Hi5  &f10 @139 P160ii5  &f10
/@3'   Under 5 Years and 5 to 17 Years'  @40 P90i6  &f9 @52 P160Ai6  &f9 @62 P160Bi6  &f9 @72 P160Ci6  &f10 @83 P160Di6  &f10 @94 P160Ei6  &f10 @105 P160Fi6  &f10 @116 P160Gi6  &f10 @128 P160Hi6  &f10 @139 P160ii6  &f10
/@3'   5 to 17 Years Only'               @40 P90i7  &f9 @52 P160Ai7  &f9 @62 P160Bi7  &f9 @72 P160Ci7  &f10 @83 P160Di7  &f10 @94 P160Ei7  &f10 @105 P160Fi7  &f10 @116 P160Gi7  &f10 @128 P160Hi7  &f10 @139 P160ii7  &f10
/@3'  No Related Children under 18 Years'@40 P90i8  &f9 @52 P160Ai8  &f9 @62 P160Bi8  &f9 @72 P160Ci8  &f10 @83 P160Di8  &f10 @94 P160Ei8  &f10 @105 P160Fi8  &f10 @116 P160Gi8  &f10 @128 P160Hi8  &f10 @139 P160ii8  &f10

//@3' Other Families:'                   @40 P90i9  &f9 @52 P160Ai9  &f9 @62 P160Bi9  &f9 @72 P160Ci9  &f10 @83 P160Di9  &f10 @94 P160Ei9  &f10 @105 P160Fi9  &f10 @116 P160Gi9  &f10 @128 P160Hi9  &f10 @139 P160ii9  &f10
/@3'  Percent below Poverty Level'       @40 POFBP1 &p9 @52 POFBP2   &p9 @62 POFBP3   &p9 @72 POFBP4   &p10 @83 POFBP5   &p10 @94 POFBP6   &p10 @105 POFBP7   &p10 @116 POFBP8   &p10 @128 POFBP9   &p10 @139 POFBP10  &p10

//@3'  Male Householder, no wife:'        @40 P90i10 &f9 @52 P160Ai10 &f9 @62 P160Bi10 &f9 @72 P160Ci10 &f10 @83 P160Di10 &f10 @94 P160Ei10 &f10 @105 P160Fi10 &f10 @116 P160Gi10 &f10 @128 P160Hi10 &f10 @139 P160ii10 &f10
/@3'   Percent below Poverty Level'       @40 PMHBP1 &p9 @52 PMHBP2   &p9 @62 PMHBP3   &p9 @72 PMHBP4   &p10 @83 PMHBP5   &p10 @94 PMHBP6   &p10 @105 PMHBP7   &p10 @116 PMHBP8   &p10 @128 PMHBP9   &p10 @139 PMHBP10  &p10

//@5' With Related Children und. 18 Yrs:'@40 P90i11 &f9 @52 P160Ai11 &f9 @62 P160Bi11 &f9 @72 P160Ci11 &f10 @83 P160Di11 &f10 @94 P160Ei11 &f10 @105 P160Fi11 &f10 @116 P160Gi11 &f10 @128 P160Hi11 &f10 @139 P160ii11 &f10
/@3'    Under 5 Years Only'               @40 P90i12 &f9 @52 P160Ai12 &f9 @62 P160Bi12 &f9 @72 P160Ci12 &f10 @83 P160Di12 &f10 @94 P160Ei12 &f10 @105 P160Fi12 &f10 @116 P160Gi12 &f10 @128 P160Hi12 &f10 @139 P160ii12 &f10
/@3'    Under 5 Years and 5 to 17 Years'  @40 P90i13 &f9 @52 P160Ai13 &f9 @62 P160Bi13 &f9 @72 P160Ci13 &f10 @83 P160Di13 &f10 @94 P160Ei13 &f10 @105 P160Fi13 &f10 @116 P160Gi13 &f10 @128 P160Hi13 &f10 @139 P160ii13 &f10
/@3'    5 to 17 Years Only'               @40 P90i14 &f9 @52 P160Ai14 &f9 @62 P160Bi14 &f9 @72 P160Ci14 &f10 @83 P160Di14 &f10 @94 P160Ei14 &f10 @105 P160Fi14 &f10 @116 P160Gi14 &f10 @128 P160Hi14 &f10 @139 P160ii14 &f10
/@3'   No Related Children under 18 Years'@40 P90i15 &f9 @52 P160Ai15 &f9 @62 P160Bi15 &f9 @72 P160Ci15 &f10 @83 P160Di15 &f10 @94 P160Ei15 &f10 @105 P160Fi15 &f10 @116 P160Gi15 &f10 @128 P160Hi15 &f10 @139 P160ii15 &f10

//@3'  Female Householder, No Husband:'   @40 P90i16 &f9 @52 P160Ai16 &f9 @62 P160Bi16 &f9 @72 P160Ci16 &f10 @83 P160Di16 &f10 @94 P160Ei16 &f10 @105 P160Fi16 &f10 @116 P160Gi16 &f10 @128 P160Hi16 &f10 @139 P160ii16 &f10
/@3'   Percent below Poverty Level'       @40 PFHBP1 &p9 @52 PFHBP2   &p9 @62 PFHBP3   &p9 @72 PFHBP4   &p10 @83 PFHBP5   &p10 @94 PFHBP6   &p10 @105 PFHBP7   &p10 @116 PFHBP8   &p10 @128 PFHBP9   &p10 @139 PFHBP10  &p10

//@5' With Related Children und. 18 Yrs:'@40 P90i17 &f9 @52 P160Ai17 &f9 @62 P160Bi17 &f9 @72 P160Ci17 &f10 @83 P160Di17 &f10 @94 P160Ei17 &f10 @105 P160Fi17 &f10 @116 P160Gi17 &f10 @128 P160Hi17 &f10 @139 P160ii17 &f10
/@3'    Under 5 Years Only'               @40 P90i18 &f9 @52 P160Ai18 &f9 @62 P160Bi18 &f9 @72 P160Ci18 &f10 @83 P160Di18 &f10 @94 P160Ei18 &f10 @105 P160Fi18 &f10 @116 P160Gi18 &f10 @128 P160Hi18 &f10 @139 P160ii18 &f10
/@3'    Under 5 Years and 5 to 17 Years'  @40 P90i19 &f9 @52 P160Ai19 &f9 @62 P160Bi19 &f9 @72 P160Ci19 &f10 @83 P160Di19 &f10 @94 P160Ei19 &f10 @105 P160Fi19 &f10 @116 P160Gi19 &f10 @128 P160Hi19 &f10 @139 P160ii19 &f10
/@3'    5 to 17 Years Only'               @40 P90i20 &f9 @52 P160Ai20 &f9 @62 P160Bi20 &f9 @72 P160Ci20 &f10 @83 P160Di20 &f10 @94 P160Ei20 &f10 @105 P160Fi20 &f10 @116 P160Gi20 &f10 @128 P160Hi20 &f10 @139 P160ii20 &f10
/@3'   No Related Children under 18 Years'@40 P90i21 &f9 @52 P160Ai21 &f9 @62 P160Bi21 &f9 @72 P160Ci21 &f10 @83 P160Di21 &f10 @94 P160Ei21 &f10 @105 P160Fi21 &f10 @116 P160Gi21 &f10 @128 P160Hi21 &f10 @139 P160ii21 &f10 ;

PUT # 58
 @3' * For Census 2000, persons could report more than one race, but the seven racial categories shown are mutually exclusive and include everyone.'
/@3'** Hispanic or Latino is NOT considered a race.  People who reported themselves as Hispanic or Latino are also counted in the seven racial'
/@3'   categories.';
link HeadFoot;
end;  *<-----------of code to generate 2nd page----;

IF INDEX(_pages,'3') THEN DO;


%PutTitle(
   %STR(Poverty Profile 3: FAMILIES BY FAMILY TYPE (PART 2 OF 2: ABOVE POVERTY)),
   %STR(Pov-3)) ;

**--Draw horizontal lines--**;
PUT #57 @2 147*'-';

**--Draw (internal) vertical lines--**;
do _i_=15 to 50;
  PUT #_I_ @50 ':';
  end;

do _i_=15 to 50;
  PUT #_I_ @127 ':';
  end;

*--Generate table P90/P160.--**;
PUT #9
@3 'P90/P160 A-I. POVERTY STATUS IN 1999 OF FAMILIES BY FAMILY TYPE BY PRESENCE AND AGE OF RELATED CHILDREN UNDER 18 YEARS BY'
/@3'              RACE AND HISPANIC/LATINO [PART 2 OF 2 - INCOME AT OR ABOVE POVERTY LEVEL]'
/@3'Universe: Families'
//                                        @40'------------------------- Families with Income in 1999 at or above Poverty Level ----------------------------'
//                                        @51'--------------------------------- Race* ------------------------------------'                                                                              @128'----- Hispanic** -----'
/                                                                                                                                 @96'  Native'
/                                                                                                     @74'American'               @96'Hawaiian'
/                                                                                @63'Black or'        @76 'Indian'                @97'& Other'         @111 'Some'                                         @144'White'
/                                                                                @64'African'         @74 '& Alaska'              @97'Pacific'         @110'Other'   @123'Two'                             @139'Alone, Not'
/                                                           @56'White'           @63'American'        @76'Native'     @88'Asian'  @96'Islander'        @111'Race'    @119'or More'   @130'Hispanic'        @141'Hispanic'
/                                         @40'All Races'    @56'Alone'           @66'Alone'           @77'Alone'      @88'Alone'  @99'Alone'           @110'Alone'   @121'Races'     @129'or Latino'       @140'or Latino'
/
/
/@3'Total Families at or above Poverty:'  @40 P90i22 &f9 @52 P160Ai22 &f9 @62 P160Bi22 &f9 @72 P160Ci22 &f10 @83 P160Di22 &f10 @94 P160Ei22 &f10 @105 P160Fi22 &f10 @116 P160Gi22 &f10 @128 P160Hi22 &f10 @139 P160ii22 &f10

//@3' Married-Couple Families:'           @40 P90i23 &f9 @52 P160Ai23 &f9 @62 P160Bi23 &f9 @72 P160Ci23 &f10 @83 P160Di23 &f10 @94 P160Ei23 &f10 @105 P160Fi23 &f10 @116 P160Gi23 &f10 @128 P160Hi23 &f10 @139 P160ii23 &f10

//@4' With Related Children under 18 Yrs:'@40 P90i24 &f9 @52 P160Ai24 &f9 @62 P160Bi24 &f9 @72 P160Ci24 &f10 @83 P160Di24 &f10 @94 P160Ei24 &f10 @105 P160Fi24 &f10 @116 P160Gi24 &f10 @128 P160Hi24 &f10 @139 P160ii24 &f10
/@3'   Under 5 Years Only'                @40 P90i25 &f9 @52 P160Ai25 &f9 @62 P160Bi25 &f9 @72 P160Ci25 &f10 @83 P160Di25 &f10 @94 P160Ei25 &f10 @105 P160Fi25 &f10 @116 P160Gi25 &f10 @128 P160Hi25 &f10 @139 P160ii25 &f10
/@3'   Under 5 Years and 5 to 17 Years'   @40 P90i26 &f9 @52 P160Ai26 &f9 @62 P160Bi26 &f9 @72 P160Ci26 &f10 @83 P160Di26 &f10 @94 P160Ei26 &f10 @105 P160Fi26 &f10 @116 P160Gi26 &f10 @128 P160Hi26 &f10 @139 P160ii26 &f10
/@3'   5 to 17 Years Only'                @40 P90i27 &f9 @52 P160Ai27 &f9 @62 P160Bi27 &f9 @72 P160Ci27 &f10 @83 P160Di27 &f10 @94 P160Ei27 &f10 @105 P160Fi27 &f10 @116 P160Gi27 &f10 @128 P160Hi27 &f10 @139 P160ii27 &f10
/@3'  No Related Children under 18 Years' @40 P90i28 &f9 @52 P160Ai28 &f9 @62 P160Bi28 &f9 @72 P160Ci28 &f10 @83 P160Di28 &f10 @94 P160Ei28 &f10 @105 P160Fi28 &f10 @116 P160Gi28 &f10 @128 P160Hi28 &f10 @139 P160ii28 &f10

//@3' Other Families:'                    @40 P90i29 &f9 @52 P160Ai29 &f9 @62 P160Bi29 &f9 @72 P160Ci29 &f10 @83 P160Di29 &f10 @94 P160Ei29 &f10 @105 P160Fi29 &f10 @116 P160Gi29 &f10 @128 P160Hi29 &f10 @139 P160ii29 &f10

//@3'  Male Householder, No Wife:'          @40 P90i30 &f9 @52 P160Ai30 &f9 @62 P160Bi30 &f9 @72 P160Ci30 &f10 @83 P160Di30 &f10 @94 P160Ei30 &f10 @105 P160Fi30 &f10 @116 P160Gi30 &f10 @128 P160Hi30 &f10 @139 P160ii30 &f10

//@3'   With Related Children und. 18 Yrs:' @40 P90i31 &f9 @52 P160Ai31 &f9 @62 P160Bi31 &f9 @72 P160Ci31 &f10 @83 P160Di31 &f10 @94 P160Ei31 &f10 @105 P160Fi31 &f10 @116 P160Gi31 &f10 @128 P160Hi31 &f10 @139 P160ii31 &f10
/@3'    Under 5 Years Only'                 @40 P90i32 &f9 @52 P160Ai32 &f9 @62 P160Bi32 &f9 @72 P160Ci32 &f10 @83 P160Di32 &f10 @94 P160Ei32 &f10 @105 P160Fi32 &f10 @116 P160Gi32 &f10 @128 P160Hi32 &f10 @139 P160ii32 &f10
/@3'    Under 5 Years and 5 to 17 Years'    @40 P90i33 &f9 @52 P160Ai33 &f9 @62 P160Bi33 &f9 @72 P160Ci33 &f10 @83 P160Di33 &f10 @94 P160Ei33 &f10 @105 P160Fi33 &f10 @116 P160Gi33 &f10 @128 P160Hi33 &f10 @139 P160ii33 &f10
/@3'    5 to 17 Years Only'                 @40 P90i34 &f9 @52 P160Ai34 &f9 @62 P160Bi34 &f9 @72 P160Ci34 &f10 @83 P160Di34 &f10 @94 P160Ei34 &f10 @105 P160Fi34 &f10 @116 P160Gi34 &f10 @128 P160Hi34 &f10 @139 P160ii34 &f10
/@3'   No Related Children under 18 Years'  @40 P90i35 &f9 @52 P160Ai35 &f9 @62 P160Bi35 &f9 @72 P160Ci35 &f10 @83 P160Di35 &f10 @94 P160Ei35 &f10 @105 P160Fi35 &f10 @116 P160Gi35 &f10 @128 P160Hi35 &f10 @139 P160ii35 &f10

//@3'  Female Householder, No Husband:'     @40 P90i36 &f9 @52 P160Ai36 &f9 @62 P160Bi36 &f9 @72 P160Ci36 &f10 @83 P160Di36 &f10 @94 P160Ei36 &f10 @105 P160Fi36 &f10 @116 P160Gi36 &f10 @128 P160Hi36 &f10 @139 P160ii36 &f10

//@3'   With Related Children und. 18 Yrs: '@40 P90i37 &f9 @52 P160Ai37 &f9 @62 P160Bi37 &f9 @72 P160Ci37 &f10 @83 P160Di37 &f10 @94 P160Ei37 &f10 @105 P160Fi37 &f10 @116 P160Gi37 &f10 @128 P160Hi37 &f10 @139 P160ii37 &f10
/@3'    Under 5 Years Only'                 @40 P90i38 &f9 @52 P160Ai38 &f9 @62 P160Bi38 &f9 @72 P160Ci38 &f10 @83 P160Di38 &f10 @94 P160Ei38 &f10 @105 P160Fi38 &f10 @116 P160Gi38 &f10 @128 P160Hi38 &f10 @139 P160ii38 &f10
/@3'    Under 5 Years and 5 to 17 Years'    @40 P90i39 &f9 @52 P160Ai39 &f9 @62 P160Bi39 &f9 @72 P160Ci39 &f10 @83 P160Di39 &f10 @94 P160Ei39 &f10 @105 P160Fi39 &f10 @116 P160Gi39 &f10 @128 P160Hi39 &f10 @139 P160ii39 &f10
/@3'    5 to 17 Years Only'                 @40 P90i40 &f9 @52 P160Ai40 &f9 @62 P160Bi40 &f9 @72 P160Ci40 &f10 @83 P160Di40 &f10 @94 P160Ei40 &f10 @105 P160Fi40 &f10 @116 P160Gi40 &f10 @128 P160Hi40 &f10 @139 P160ii40 &f10
/@3'   No Related Children under 18 Years'  @40 P90i41 &f9 @52 P160Ai41 &f9 @62 P160Bi41 &f9 @72 P160Ci41 &f10 @83 P160Di41 &f10 @94 P160Ei41 &f10 @105 P160Fi41 &f10 @116 P160Gi41 &f10 @128 P160Hi41 &f10 @139 P160ii41 &f10 ;

PUT # 58
 @3' * For Census 2000, persons could report more than one race, but the seven racial categories shown are mutually exclusive and include everyone.'
/@3'** Hispanic or Latino is NOT considered a race. People who reported themselves as Hispanic or Latino are also counted in the seven racial'
/@3'   categories.';
link HeadFoot;
end;  *<-----------of code to generate 3rd page----;


IF INDEX(_pages,'4') THEN DO;


%PutTitle(
   %STR(Poverty Profile 4: PERSONS BY SEX, AGE, RACE & HISPANIC/LATINO (PART 1 OF 2: BELOW POVERTY)),
   %STR(Pov-4)) ;

**--Draw horizontal lines--**;
PUT #55 @2 147*'-';

**--Draw (internal) vertical lines--**;

do _i_=14 to 53;
  PUT #_I_ @43 ':';
  end;

do _i_=14 to 53;
  PUT #_I_ @121 ':';
  end;

*--Generate table P49/PCT75 A-I.--**;

*--Percent Total Population, All Races--**;

array PBPL  (29) PCT49i2-PCT49i30;
array PABL  (29) PCT49i31-PCT49i59;
array PCTTP (29);

DO i=1 TO 29;
  IF (PBPL (i) + PABL (i))=0 THEN PCTTP(i)=. ; ELSE PCTTP(i)=PBPL (i)*100/(PBPL (i) + PABL (i));
END;

*--Percent Below Poverty Level --**;

IF (PCT49i2+PCT49i31)=0   THEN PCTBP1=. ; ELSE PCTBP1=PCT49i2 *100/(PCT49i2+PCT49i31);
IF (PCT75Ai2+PCT75Ai31)=0 THEN PCTBP2=. ; ELSE PCTBP2=PCT75Ai2*100/(PCT75Ai2+PCT75Ai31);
IF (PCT75Bi2+PCT75Bi31)=0 THEN PCTBP3=. ; ELSE PCTBP3=PCT75Bi2*100/(PCT75Bi2+PCT75Bi31);
IF (PCT75Ci2+PCT75Ci31)=0 THEN PCTBP4=. ; ELSE PCTBP4=PCT75Ci2*100/(PCT75Ci2+PCT75Ci31);
IF (PCT75Di2+PCT75Di31)=0 THEN PCTBP5=. ; ELSE PCTBP5=PCT75Di2*100/(PCT75Di2+PCT75Di31);
IF (PCT75Ei2+PCT75Ei31)=0 THEN PCTBP6=. ; ELSE PCTBP6=PCT75Ei2*100/(PCT75Ei2+PCT75Ei31);
IF (PCT75Fi2+PCT75Fi31)=0 THEN PCTBP7=. ; ELSE PCTBP7=PCT75Fi2*100/(PCT75Fi2+PCT75Fi31);
IF (PCT75Gi2+PCT75Gi31)=0 THEN PCTBP8=. ; ELSE PCTBP8=PCT75Gi2*100/(PCT75Gi2+PCT75Gi31);
IF (PCT75Hi2+PCT75Hi31)=0 THEN PCTBP9=. ; ELSE PCTBP9=PCT75Hi2*100/(PCT75Hi2+PCT75Hi31);
IF (PCT75Ii2+PCT75Ii31)=0 THEN PCTBP10=.; ELSE PCTBP10=PCT75Ii2*100/(PCT75Ii2+PCT75Ii31);

%LET p4=4.1 '%' ; * % symbol won't be flush in this case ;

PUT #9
@3'PCT49/PCT75 A-I. POVERTY STATUS IN 1999 BY SEX BY AGE BY RACE AND HISPANIC/LATINO [PART 1 OF 2 - INCOME IN 1999 BELOW POVERTY LEVEL]'
/@3'Universe: Population for whom poverty status is determined (*)'
// @28'----------------------------- Population with Income in 1999 below Poverty level -------------------------------------'
// @44'-------------------------------- Race** ------------------------------------'                                                                                  @123'----- Hispanic*** -----'
/                                                                                                                       @92'Native'
/                                                                                    @68'American'                      @90'Hawaiian'
/                                                            @56' Black or'          @70'Indian'                        @91'& Other'     @105'Some'                                     @141 'White'
/                                                            @57' African'           @68'& Alaska'                      @91'Pacific'     @104'Other'    @117'Two'                       @136'Alone, Not'
/  @28'---All Races---'                @50'White'            @56' American'          @70'Native'            @82'Asian'  @90'Islander'    @105'Race'     @113'or More'  @125'Hispanic'   @138 'Hispanic'
/  @31'Number'          @38'Pct.'      @50'Alone'            @59' Alone'             @71'Alone'             @82'Alone'  @93'Alone'       @104'Alone'    @115 'Races'   @124'or Latino'  @137 'or Latino'
/@3'Total in Universe*'
/@3'below Poverty Level:'@27 PCT49i2  &f10 @38 PCTTP1 &p4 @45 PCT75Ai2  &f10 @56 PCT75Bi2  &f9  @66 PCT75Ci2  &f10  @77 PCT75Di2  &f10  @88 PCT75Ei2  &f10  @99 PCT75Fi2   &f10 @110 PCT75Gi2  &f10  @123 PCT75Hi2  &f10
@136 PCT75Ii2 &f10
/@3' Pct. below Poverty Lvl:'@27 PCTBP1 &p10                     @45 PCTBP2 &p10       @56 PCTBP3 &p9         @66 PCTBP4 &p10        @77 PCTBP5 &p10        @88 PCTBP6 &p10        @99 PCTBP7 &p10        @110 PCTBP8 &p10        @123 PCTBP9 &p10
@136 PCTBP10 &p10
//@3' Male:'             @27 PCT49i3  &f10 @38 PCTTP2 &p4 @45 PCT75Ai3  &f10 @56 PCT75Bi3  &f9  @66 PCT75Ci3  &f10  @77 PCT75Di3  &f10  @88 PCT75Ei3  &f10  @99 PCT75Fi3  &f10  @110 PCT75Gi3  &f10  @123 PCT75Hi3  &f10
@136 PCT75Ii3 &f10
/@3'  Under 5 Years'     @27 PCT49i4  &f10 @38 PCTTP3 &p4 @45 PCT75Ai4  &f10 @56 PCT75Bi4  &f9  @66 PCT75Ci4  &f10  @77 PCT75Di4  &f10  @88 PCT75Ei4  &f10  @99 PCT75Fi4  &f10  @110 PCT75Gi4  &f10  @123 PCT75Hi4  &f10
@136 PCT75Ii4 &f10
/@3'  5 Years'           @27 PCT49i5  &f10 @38 PCTTP4 &p4 @45 PCT75Ai5  &f10 @56 PCT75Bi5  &f9  @66 PCT75Ci5  &f10  @77 PCT75Di5  &f10  @88 PCT75Ei5  &f10  @99 PCT75Fi5  &f10  @110 PCT75Gi5  &f10  @123 PCT75Hi5  &f10
@136 PCT75Ii5 &f10
/@3'  6 to 11 Years'     @27 PCT49i6  &f10 @38 PCTTP5 &p4 @45 PCT75Ai6  &f10 @56 PCT75Bi6  &f9  @66 PCT75Ci6  &f10  @77 PCT75Di6  &f10  @88 PCT75Ei6  &f10  @99 PCT75Fi6  &f10  @110 PCT75Gi6  &f10  @123 PCT75Hi6  &f10
@136 PCT75Ii6 &f10
/@3'  12 to 14 Years'    @27 PCT49i7  &f10 @38 PCTTP6 &p4 @45 PCT75Ai7  &f10 @56 PCT75Bi7  &f9  @66 PCT75Ci7  &f10  @77 PCT75Di7  &f10  @88 PCT75Ei7  &f10  @99 PCT75Fi7  &f10  @110 PCT75Gi7  &f10  @123 PCT75Hi7  &f10
@136 PCT75Ii7 &f10
/@3'  15 Years'          @27 PCT49i8  &f10 @38 PCTTP7 &p4 @45 PCT75Ai8  &f10 @56 PCT75Bi8  &f9  @66 PCT75Ci8  &f10  @77 PCT75Di8  &f10  @88 PCT75Ei8  &f10  @99 PCT75Fi8  &f10  @110 PCT75Gi8  &f10  @123 PCT75Hi8  &f10
@136 PCT75Ii8 &f10
/@3'  16 and 17 Years'   @27 PCT49i9  &f10 @38 PCTTP8 &p4 @45 PCT75Ai9  &f10 @56 PCT75Bi9  &f9  @66 PCT75Ci9  &f10  @77 PCT75Di9  &f10  @88 PCT75Ei9  &f10  @99 PCT75Fi9  &f10  @110 PCT75Gi9  &f10  @123 PCT75Hi9  &f10
@136 PCT75Ii9 &f10
/@3'  18 to 24 Years'    @27 PCT49i10 &f10 @38 PCTTP9 &p4 @45 PCT75Ai10 &f10 @56 PCT75Bi10 &f9  @66 PCT75Ci10 &f10  @77 PCT75Di10 &f10  @88 PCT75Ei10 &f10  @99 PCT75Fi10 &f10  @110 PCT75Gi10 &f10  @123 PCT75Hi10 &f10
@136 PCT75Ii10 &f10
/@3'  25 to 34 Years'    @27 PCT49i11 &f10 @38 PCTTP10 &p4 @45 PCT75Ai11 &f10 @56 PCT75Bi11 &f9  @66 PCT75Ci11 &f10  @77 PCT75Di11 &f10  @88 PCT75Ei11 &f10  @99 PCT75Fi11 &f10  @110 PCT75Gi11 &f10  @123 PCT75Hi11 &f10
@136 PCT75Ii11 &f10
/@3'  35 to 44 Years'    @27 PCT49i12 &f10 @38 PCTTP11 &p4 @45 PCT75Ai12 &f10 @56 PCT75Bi12 &f9  @66 PCT75Ci12 &f10  @77 PCT75Di12 &f10  @88 PCT75Ei12 &f10  @99 PCT75Fi12 &f10  @110 PCT75Gi12 &f10  @123 PCT75Hi12 &f10
@136 PCT75Ii12 &f10
/@3'  45 to 54 Years'    @27 PCT49i13 &f10 @38 PCTTP12 &p4 @45 PCT75Ai13 &f10 @56 PCT75Bi13 &f9  @66 PCT75Ci13 &f10  @77 PCT75Di13 &f10  @88 PCT75Ei13 &f10  @99 PCT75Fi13 &f10  @110 PCT75Gi13 &f10  @123 PCT75Hi13 &f10
@136 PCT75Ii13 &f10
/@3'  55 to 64 Years'    @27 PCT49i14 &f10 @38 PCTTP13 &p4 @45 PCT75Ai14 &f10 @56 PCT75Bi14 &f9  @66 PCT75Ci14 &f10  @77 PCT75Di14 &f10  @88 PCT75Ei14 &f10  @99 PCT75Fi14 &f10  @110 PCT75Gi14 &f10  @123 PCT75Hi14 &f10
@136 PCT75Ii14 &f10
/@3'  65 to 74 Years'    @27 PCT49i15 &f10 @38 PCTTP14 &p4 @45 PCT75Ai15 &f10 @56 PCT75Bi15 &f9  @66 PCT75Ci15 &f10  @77 PCT75Di15 &f10  @88 PCT75Ei15 &f10  @99 PCT75Fi15 &f10  @110 PCT75Gi15 &f10  @123 PCT75Hi15 &f10
@136 PCT75Ii15 &f10
/@3'  75 Years and Over' @27 PCT49i16 &f10 @38 PCTTP15 &p4 @45 PCT75Ai16 &f10 @56 PCT75Bi16 &f9  @66 PCT75Ci16 &f10  @77 PCT75Di16 &f10  @88 PCT75Ei16 &f10  @99 PCT75Fi16 &f10  @110 PCT75Gi16 &f10  @123 PCT75Hi16 &f10
@136 PCT75Ii16 &f10

//@3' Female:'           @27 PCT49i17 &f10 @38 PCTTP16 &p4 @45 PCT75Ai17 &f10 @56 PCT75Bi17 &f9  @66 PCT75Ci17 &f10  @77 PCT75Di17 &f10  @88 PCT75Ei17 &f10  @99 PCT75Fi17 &f10  @110 PCT75Gi17 &f10  @123 PCT75Hi17 &f10
@136 PCT75Ii17 &f10
/@3'  Under 5 Years'     @27 PCT49i18 &f10 @38 PCTTP17 &p4 @45 PCT75Ai18 &f10 @56 PCT75Bi18 &f9  @66 PCT75Ci18 &f10  @77 PCT75Di18 &f10  @88 PCT75Ei18 &f10  @99 PCT75Fi18 &f10  @110 PCT75Gi18 &f10  @123 PCT75Hi18 &f10
@136 PCT75Ii18 &f10
/@3'  5 Years'           @27 PCT49i19 &f10 @38 PCTTP18 &p4 @45 PCT75Ai19 &f10 @56 PCT75Bi19 &f9  @66 PCT75Ci19 &f10  @77 PCT75Di19 &f10  @88 PCT75Ei19 &f10  @99 PCT75Fi19 &f10  @110 PCT75Gi19 &f10  @123 PCT75Hi19 &f10
@136 PCT75Ii19 &f10
/@3'  6 to 11 Years'     @27 PCT49i20 &f10 @38 PCTTP19 &p4 @45 PCT75Ai20 &f10 @56 PCT75Bi20 &f9  @66 PCT75Ci20 &f10  @77 PCT75Di20 &f10  @88 PCT75Ei20 &f10  @99 PCT75Fi20 &f10  @110 PCT75Gi20 &f10  @123 PCT75Hi20 &f10
@136 PCT75Ii20 &f10
/@3'  12 to 14 Years'    @27 PCT49i21 &f10 @38 PCTTP20 &p4 @45 PCT75Ai21 &f10 @56 PCT75Bi21 &f9  @66 PCT75Ci21 &f10  @77 PCT75Di21 &f10  @88 PCT75Ei21 &f10  @99 PCT75Fi21 &f10  @110 PCT75Gi21 &f10  @123 PCT75Hi21 &f10
@136 PCT75Ii21 &f10
/@3'  15 Years'          @27 PCT49i22 &f10 @38 PCTTP21 &p4 @45 PCT75Ai22 &f10 @56 PCT75Bi22 &f9  @66 PCT75Ci22 &f10  @77 PCT75Di22 &f10  @88 PCT75Ei22 &f10  @99 PCT75Fi22 &f10  @110 PCT75Gi22 &f10  @123 PCT75Hi22 &f10
@136 PCT75Ii22 &f10
/@3'  16 and 17 Years'   @27 PCT49i23 &f10 @38 PCTTP22 &p4 @45 PCT75Ai23 &f10 @56 PCT75Bi23 &f9  @66 PCT75Ci23 &f10  @77 PCT75Di23 &f10  @88 PCT75Ei23 &f10  @99 PCT75Fi23 &f10  @110 PCT75Gi23 &f10  @123 PCT75Hi23 &f10
@136 PCT75Ii23 &f10
/@3'  18 to 24 Years'    @27 PCT49i24 &f10 @38 PCTTP23 &p4 @45 PCT75Ai24 &f10 @56 PCT75Bi24 &f9  @66 PCT75Ci24 &f10  @77 PCT75Di24 &f10  @88 PCT75Ei24 &f10  @99 PCT75Fi24 &f10  @110 PCT75Gi24 &f10  @123 PCT75Hi24 &f10
@136 PCT75Ii24 &f10
/@3'  25 to 34 Years'    @27 PCT49i25 &f10 @38 PCTTP24 &p4 @45 PCT75Ai25 &f10 @56 PCT75Bi25 &f9  @66 PCT75Ci25 &f10  @77 PCT75Di25 &f10  @88 PCT75Ei25 &f10  @99 PCT75Fi25 &f10  @110 PCT75Gi25 &f10  @123 PCT75Hi25 &f10
@136 PCT75Ii25 &f10
/@3'  35 to 44 Years'    @27 PCT49i26 &f10 @38 PCTTP25 &p4 @45 PCT75Ai26 &f10 @56 PCT75Bi26 &f9  @66 PCT75Ci26 &f10  @77 PCT75Di26 &f10  @88 PCT75Ei26 &f10  @99 PCT75Fi26 &f10  @110 PCT75Gi26 &f10  @123 PCT75Hi26 &f10
@136 PCT75Ii26 &f10
/@3'  45 to 54 Years'    @27 PCT49i27 &f10 @38 PCTTP26 &p4 @45 PCT75Ai27 &f10 @56 PCT75Bi27 &f9  @66 PCT75Ci27 &f10  @77 PCT75Di27 &f10  @88 PCT75Ei27 &f10  @99 PCT75Fi27 &f10  @110 PCT75Gi27 &f10  @123 PCT75Hi27 &f10
@136 PCT75Ii27 &f10
/@3'  55 to 64 Years'    @27 PCT49i28 &f10 @38 PCTTP27 &p4 @45 PCT75Ai28 &f10 @56 PCT75Bi28 &f9  @66 PCT75Ci28 &f10  @77 PCT75Di28 &f10  @88 PCT75Ei28 &f10  @99 PCT75Fi28 &f10  @110 PCT75Gi28 &f10  @123 PCT75Hi28 &f10
@136 PCT75Ii28 &f10
/@3'  65 to 74 Years'    @27 PCT49i29 &f10 @38 PCTTP28 &p4 @45 PCT75Ai29 &f10 @56 PCT75Bi29 &f9  @66 PCT75Ci29 &f10  @77 PCT75Di29 &f10  @88 PCT75Ei29 &f10  @99 PCT75Fi29 &f10  @110 PCT75Gi29 &f10  @123 PCT75Hi29 &f10
@136 PCT75Ii29 &f10
/@3'  75 Years and Over' @27 PCT49i30 &f10 @38 PCTTP29 &p4 @45 PCT75Ai30 &f10 @56 PCT75Bi30 &f9  @66 PCT75Ci30 &f10  @77 PCT75Di30 &f10  @88 PCT75Ei30 &f10  @99 PCT75Fi30 &f10  @110 PCT75Gi30 &f10  @123 PCT75Hi30 &f10
@136 PCT75Ii30 &f10 ;

PUT # 56
 @3'  * Poverty universe includes all people EXCEPT (1) those in institutions, military group quarters, and college dormitories and (2) unrelated'
/   @6' individuals under 15 years old (children who are not related family members).'
/@3' ** For Census 2000, persons could report more than one race, but the seven racial categories shown are mutually exclusive and include everyone.'
/@3'*** Hispanic or Latino is NOT considered a race. People who reported themselves as Hispanic or Latino are also counted in the seven racial'
/@6' categories.';
link HeadFoot;
end;  *<-----------of code to generate 4th page----;

IF INDEX(_pages,'5') THEN DO;


%PutTitle(
   %STR(Poverty Profile 5: PERSONS BY SEX, AGE, RACE & HISPANIC/LATINO (PART 2 OF 2: ABOVE POVERTY)),
   %STR(Pov-5)) ;

***--Draw horizontal lines--**;
PUT #55 @2 147*'-';

**--Draw (internal) vertical lines--**;

do _i_=14 to 52;
  PUT #_I_ @38 ':';
  end;

do _i_=14 to 52;
  PUT #_I_ @120 ':';
  end;

*--Generate table PCT49/PCT75 A-I.--**;

PUT #9
@3'PCT49/PCT75 A-I. POVERTY STATUS IN 1999 BY SEX BY AGE BY RACE/HISPANIC [PART 2 OF 2 - INCOME IN 1999 AT OR ABOVE POVERTY LEVEL]'
/@3'Universe: Population for whom poverty status is determined (*)'
//                       @27'--------------------------- Population with Income in 1999 at or above Poverty level ----------------------------------'
//                       @40'--------------------------------- Race** --------------------------------------'                                                                                        @122'------- Hispanic*** ----'
/                                                                                                                                    @88'Native'
/                                                                                        @64'American'                               @86'Hawaiian'
/                                                                  @53'Black or'         @66'Indian'                                 @87'& Other'          @101'Some'                                                          @141'White'
/                                                                  @54'African'          @64'& Alaska'                               @87'Pacific'          @100'Other'           @113'Two'                                     @136 'Alone, Not'
/                                            @45'White'            @53'American'         @66'Native'           @78'Asian'            @86'Islander'         @101'Race'            @109'or More'          @125'Hispanic'         @138 'Hispanic'
/                       @28'All Races'       @45'Alone'            @56'Alone'            @67'Alone'            @78'Alone'            @89'Alone'            @100'Alone'           @111'Races'            @124'or Latino'        @137'or Latino'
/@3'Total in Universe* at/'
/@3'above Poverty Level:' @27 PCT49i31 &f10 @40 PCT75Ai31 &f10 @51 PCT75Bi31 &f10 @62 PCT75Ci31 &f10 @73 PCT75Di31 &f10 @84 PCT75Ei31 &f10 @95 PCT75Fi31 &f10 @106 PCT75Gi31 &f10 @123 PCT75Hi31 &f10 @136 PCT75Ii31 &f10

//@3' Male:'            @27 PCT49i32 &f10 @40 PCT75Ai32 &f10 @51 PCT75Bi32 &f10 @62 PCT75Ci32 &f10 @73 PCT75Di32 &f10 @84 PCT75Ei32 &f10 @95 PCT75Fi32 &f10 @106 PCT75Gi32 &f10 @123 PCT75Hi32 &f10 @136 PCT75Ii32 &f10
/@3'  Under 5 Years'    @27 PCT49i33 &f10 @40 PCT75Ai33 &f10 @51 PCT75Bi33 &f10 @62 PCT75Ci33 &f10 @73 PCT75Di33 &f10 @84 PCT75Ei33 &f10 @95 PCT75Fi33 &f10 @106 PCT75Gi33 &f10 @123 PCT75Hi33 &f10 @136 PCT75Ii33 &f10
/@3'  5 Years'          @27 PCT49i34 &f10 @40 PCT75Ai34 &f10 @51 PCT75Bi34 &f10 @62 PCT75Ci34 &f10 @73 PCT75Di34 &f10 @84 PCT75Ei34 &f10 @95 PCT75Fi34 &f10 @106 PCT75Gi34 &f10 @123 PCT75Hi34 &f10 @136 PCT75Ii34 &f10
/@3'  6 to 11 Years'    @27 PCT49i35 &f10 @40 PCT75Ai35 &f10 @51 PCT75Bi35 &f10 @62 PCT75Ci35 &f10 @73 PCT75Di35 &f10 @84 PCT75Ei35 &f10 @95 PCT75Fi35 &f10 @106 PCT75Gi35 &f10 @123 PCT75Hi35 &f10 @136 PCT75Ii35 &f10
/@3'  12 to 14 Years'   @27 PCT49i36 &f10 @40 PCT75Ai36 &f10 @51 PCT75Bi36 &f10 @62 PCT75Ci36 &f10 @73 PCT75Di36 &f10 @84 PCT75Ei36 &f10 @95 PCT75Fi36 &f10 @106 PCT75Gi36 &f10 @123 PCT75Hi36 &f10 @136 PCT75Ii36 &f10
/@3'  15 Years'         @27 PCT49i37 &f10 @40 PCT75Ai37 &f10 @51 PCT75Bi37 &f10 @62 PCT75Ci37 &f10 @73 PCT75Di37 &f10 @84 PCT75Ei37 &f10 @95 PCT75Fi37 &f10 @106 PCT75Gi37 &f10 @123 PCT75Hi37 &f10 @136 PCT75Ii37 &f10
/@3'  16 and 17 Years'  @27 PCT49i38 &f10 @40 PCT75Ai38 &f10 @51 PCT75Bi38 &f10 @62 PCT75Ci38 &f10 @73 PCT75Di38 &f10 @84 PCT75Ei38 &f10 @95 PCT75Fi38 &f10 @106 PCT75Gi38 &f10 @123 PCT75Hi38 &f10 @136 PCT75Ii38 &f10
/@3'  18 to 24 Years'   @27 PCT49i39 &f10 @40 PCT75Ai39 &f10 @51 PCT75Bi39 &f10 @62 PCT75Ci39 &f10 @73 PCT75Di39 &f10 @84 PCT75Ei39 &f10 @95 PCT75Fi39 &f10 @106 PCT75Gi39 &f10 @123 PCT75Hi39 &f10 @136 PCT75Ii39 &f10
/@3'  25 to 34 Years'   @27 PCT49i40 &f10 @40 PCT75Ai40 &f10 @51 PCT75Bi40 &f10 @62 PCT75Ci40 &f10 @73 PCT75Di40 &f10 @84 PCT75Ei40 &f10 @95 PCT75Fi40 &f10 @106 PCT75Gi40 &f10 @123 PCT75Hi40 &f10 @136 PCT75Ii40 &f10
/@3'  35 to 44 Years'   @27 PCT49i41 &f10 @40 PCT75Ai41 &f10 @51 PCT75Bi41 &f10 @62 PCT75Ci41 &f10 @73 PCT75Di41 &f10 @84 PCT75Ei41 &f10 @95 PCT75Fi41 &f10 @106 PCT75Gi41 &f10 @123 PCT75Hi41 &f10 @136 PCT75Ii41 &f10
/@3'  45 to 54 Years'   @27 PCT49i42 &f10 @40 PCT75Ai42 &f10 @51 PCT75Bi42 &f10 @62 PCT75Ci42 &f10 @73 PCT75Di42 &f10 @84 PCT75Ei42 &f10 @95 PCT75Fi42 &f10 @106 PCT75Gi42 &f10 @123 PCT75Hi42 &f10 @136 PCT75Ii42 &f10
/@3'  55 to 64 Years'   @27 PCT49i43 &f10 @40 PCT75Ai43 &f10 @51 PCT75Bi43 &f10 @62 PCT75Ci43 &f10 @73 PCT75Di43 &f10 @84 PCT75Ei43 &f10 @95 PCT75Fi43 &f10 @106 PCT75Gi43 &f10 @123 PCT75Hi43 &f10 @136 PCT75Ii43 &f10
/@3'  65 to 74 Years'   @27 PCT49i44 &f10 @40 PCT75Ai44 &f10 @51 PCT75Bi44 &f10 @62 PCT75Ci44 &f10 @73 PCT75Di44 &f10 @84 PCT75Ei44 &f10 @95 PCT75Fi44 &f10 @106 PCT75Gi44 &f10 @123 PCT75Hi44 &f10 @136 PCT75Ii44 &f10
/@3'  75 Years and Over'@27 PCT49i45 &f10 @40 PCT75Ai45 &f10 @51 PCT75Bi45 &f10 @62 PCT75Ci45 &f10 @73 PCT75Di45 &f10 @84 PCT75Ei45 &f10 @95 PCT75Fi45 &f10 @106 PCT75Gi45 &f10 @123 PCT75Hi45 &f10 @136 PCT75Ii45 &f10

//@3' Female:'          @27 PCT49i46 &f10 @40 PCT75Ai46 &f10 @51 PCT75Bi46 &f10 @62 PCT75Ci46 &f10 @73 PCT75Di46 &f10 @84 PCT75Ei46 &f10 @95 PCT75Fi46 &f10 @106 PCT75Gi46 &f10 @123 PCT75Hi46 &f10 @136 PCT75Ii46 &f10
/@3'  Under 5 Years'    @27 PCT49i47 &f10 @40 PCT75Ai47 &f10 @51 PCT75Bi47 &f10 @62 PCT75Ci47 &f10 @73 PCT75Di47 &f10 @84 PCT75Ei47 &f10 @95 PCT75Fi47 &f10 @106 PCT75Gi47 &f10 @123 PCT75Hi47 &f10 @136 PCT75Ii47 &f10
/@3'  5 Years'          @27 PCT49i48 &f10 @40 PCT75Ai48 &f10 @51 PCT75Bi48 &f10 @62 PCT75Ci48 &f10 @73 PCT75Di48 &f10 @84 PCT75Ei48 &f10 @95 PCT75Fi48 &f10 @106 PCT75Gi48 &f10 @123 PCT75Hi48 &f10 @136 PCT75Ii48 &f10
/@3'  6 to 11 Years'    @27 PCT49i49 &f10 @40 PCT75Ai49 &f10 @51 PCT75Bi49 &f10 @62 PCT75Ci49 &f10 @73 PCT75Di49 &f10 @84 PCT75Ei49 &f10 @95 PCT75Fi49 &f10 @106 PCT75Gi49 &f10 @123 PCT75Hi49 &f10 @136 PCT75Ii49 &f10
/@3'  12 to 14 Years'   @27 PCT49i50 &f10 @40 PCT75Ai50 &f10 @51 PCT75Bi50 &f10 @62 PCT75Ci50 &f10 @73 PCT75Di50 &f10 @84 PCT75Ei50 &f10 @95 PCT75Fi50 &f10 @106 PCT75Gi50 &f10 @123 PCT75Hi50 &f10 @136 PCT75Ii50 &f10
/@3'  15 Years'         @27 PCT49i51 &f10 @40 PCT75Ai51 &f10 @51 PCT75Bi51 &f10 @62 PCT75Ci51 &f10 @73 PCT75Di51 &f10 @84 PCT75Ei51 &f10 @95 PCT75Fi51 &f10 @106 PCT75Gi51 &f10 @123 PCT75Hi51 &f10 @136 PCT75Ii51 &f10
/@3'  16 and 17 Years'  @27 PCT49i52 &f10 @40 PCT75Ai52 &f10 @51 PCT75Bi52 &f10 @62 PCT75Ci52 &f10 @73 PCT75Di52 &f10 @84 PCT75Ei52 &f10 @95 PCT75Fi52 &f10 @106 PCT75Gi52 &f10 @123 PCT75Hi52 &f10 @136 PCT75Ii52 &f10
/@3'  18 to 24 Years'   @27 PCT49i53 &f10 @40 PCT75Ai53 &f10 @51 PCT75Bi53 &f10 @62 PCT75Ci53 &f10 @73 PCT75Di53 &f10 @84 PCT75Ei53 &f10 @95 PCT75Fi53 &f10 @106 PCT75Gi53 &f10 @123 PCT75Hi53 &f10 @136 PCT75Ii53 &f10
/@3'  25 to 34 Years'   @27 PCT49i54 &f10 @40 PCT75Ai54 &f10 @51 PCT75Bi54 &f10 @62 PCT75Ci54 &f10 @73 PCT75Di54 &f10 @84 PCT75Ei54 &f10 @95 PCT75Fi54 &f10 @106 PCT75Gi54 &f10 @123 PCT75Hi54 &f10 @136 PCT75Ii54 &f10
/@3'  35 to 44 Years'   @27 PCT49i55 &f10 @40 PCT75Ai55 &f10 @51 PCT75Bi55 &f10 @62 PCT75Ci55 &f10 @73 PCT75Di55 &f10 @84 PCT75Ei55 &f10 @95 PCT75Fi55 &f10 @106 PCT75Gi55 &f10 @123 PCT75Hi55 &f10 @136 PCT75Ii55 &f10
/@3'  45 to 54 Years'   @27 PCT49i56 &f10 @40 PCT75Ai56 &f10 @51 PCT75Bi56 &f10 @62 PCT75Ci56 &f10 @73 PCT75Di56 &f10 @84 PCT75Ei56 &f10 @95 PCT75Fi56 &f10 @106 PCT75Gi56 &f10 @123 PCT75Hi56 &f10 @136 PCT75Ii56 &f10
/@3'  55 to 64 Years'   @27 PCT49i57 &f10 @40 PCT75Ai57 &f10 @51 PCT75Bi57 &f10 @62 PCT75Ci57 &f10 @73 PCT75Di57 &f10 @84 PCT75Ei57 &f10 @95 PCT75Fi57 &f10 @106 PCT75Gi57 &f10 @123 PCT75Hi57 &f10 @136 PCT75Ii57 &f10
/@3'  65 to 74 Years'   @27 PCT49i58 &f10 @40 PCT75Ai58 &f10 @51 PCT75Bi58 &f10 @62 PCT75Ci58 &f10 @73 PCT75Di58 &f10 @84 PCT75Ei58 &f10 @95 PCT75Fi58 &f10 @106 PCT75Gi58 &f10 @123 PCT75Hi58 &f10 @136 PCT75Ii58 &f10
/@3'  75 Years and Over'@27 PCT49i59 &f10 @40 PCT75Ai59 &f10 @51 PCT75Bi59 &f10 @62 PCT75Ci59 &f10 @73 PCT75Di59 &f10 @84 PCT75Ei59 &f10 @95 PCT75Fi59 &f10 @106 PCT75Gi59 &f10 @123 PCT75Hi59 &f10 @136 PCT75Ii59 &f10 ;

PUT # 56
 @3'  * Poverty universe includes all people EXCEPT (1) those in institutions, military group quarters, and college dormitories and (2) unrelated'
/@3'    individuals under 15 years old (children who are not related family members).'
/@3' ** For Census 2000, persons could report more than one race, but the seven racial categories shown are mutually exclusive and include everyone.'
/@3'*** Hispanic or Latino is NOT considered a race. People who reported themselves as Hispanic or Latino are also counted in the seven racial'
/    @7'categories.';
link HeadFoot;
end;  *<-----------of code to generate 5th page----;

IF INDEX(_pages,'6') THEN DO;


%PutTitle(
   %STR(Poverty Profile 6: RELATED CHILDREN UNDER 18 YEARS BY RACE AND HISPANIC/LATINO),
   %STR(Pov-6)) ;

**--Draw horizontal lines--**;
PUT #55 @2 147*'-';

**--Draw (internal) vertical lines--**;

do _i_=12 to 53;
  PUT #_I_ @50 ':';
  end;

do _i_=12 to 53;
  PUT #_I_ @123 ':';
  end;

*--Generate table PCT52/PCT76 A-I.--**;

*--Percent Poverty Rate for Related Children Under 18 Years --**;

IF  PCT52i1=0 THEN PU18Y1=. ; ELSE PU18Y1=PCT52i2 *100/ PCT52i1;
IF PCT76Ai1=0 THEN PU18Y2=. ; ELSE PU18Y2=PCT76Ai2*100/PCT76Ai1;
IF PCT76Bi1=0 THEN PU18Y3=. ; ELSE PU18Y3=PCT76Bi2*100/PCT76Bi1;
IF PCT76Ci1=0 THEN PU18Y4=. ; ELSE PU18Y4=PCT76Ci2*100/PCT76Ci1;
IF PCT76Di1=0 THEN PU18Y5=. ; ELSE PU18Y5=PCT76Di2*100/PCT76Di1;
IF PCT76Ei1=0 THEN PU18Y6=. ; ELSE PU18Y6=PCT76Ei2*100/PCT76Ei1;
IF PCT76Fi1=0 THEN PU18Y7=. ; ELSE PU18Y7=PCT76Fi2*100/PCT76Fi1;
IF PCT76Gi1=0 THEN PU18Y8=. ; ELSE PU18Y8=PCT76Gi2*100/PCT76Gi1;
IF PCT76Hi1=0 THEN PU18Y9=. ; ELSE PU18Y9=PCT76Hi2*100/PCT76Hi1;
IF PCT76Ii1=0 THEN PU18Y10=.; ELSE PU18Y10=PCT76Ii2*100/PCT76Ii1;

PUT #9
@3 'PCT52/PCT76 A-I. POVERTY STATUS IN 1999 OF RELATED CHILDREN UNDER 18 YEARS BY FAMILY TYPE BY AGE BY RACE AND HISPANIC/LATINO'
/@3 'Universe: Related Children under 18 years'
//             @52'----------------------------- Race* ---------------------------------'                                                      @126'---- Hispanic** ----'
/                                                                      @93'  Native'
/                                            @73'American'             @93'Hawaiian'
/                           @63'Black or'    @75'Indian'               @94'& Other'    @107'Some'                                   @141'White'
/                           @64'African'     @73'& Alaska'             @94'Pacific'    @106'Other'  @118'Two'                       @136'Alone, Not'
/  @46'All'    @56'White'   @63'American'    @75'Native'   @86'Asian'  @93'Islander'   @107'Race'   @114'or More'  @127'Hispanic'   @138'Hispanic'
/  @44'Races'  @56'Alone'   @66'Alone'       @76'Alone'    @86'Alone'  @96'Alone'      @106'Alone'  @116'Races'    @126'or Latino'  @137'or Latino'
//@3'Total Related Children under 18 yrs:'@40 PCT52i1  &f9 @52 PCT76Ai1  &f9 @62 PCT76Bi1  &f9 @72 PCT76Ci1  &f9 @82 PCT76Di1  &f9 @92 PCT76Ei1  &f9 @102 PCT76Fi1  &f9 @112 PCT76Gi1  &f9 @126 PCT76Hi1  &f9 @137 PCT76Ii1  &f9
 /@3'   Percent below Poverty Level'      @40 PU18Y1 &p9      @52 PU18Y2 &p9       @62 PU18Y3 &p9       @72 PU18Y4 &p9       @82 PU18Y5 &p9       @92 PU18Y6 &p9       @102 PU18Y7 &p9       @112 PU18Y8 &p9       @126 PU18Y9 &p9       @137 PU18Y10 &p9
//@3' In Families with'
/@3' Income in 1999 below Poverty Level:' @40 PCT52i2  &f9 @52 PCT76Ai2  &f9 @62 PCT76Bi2  &f9 @72 PCT76Ci2  &f9 @82 PCT76Di2  &f9 @92 PCT76Ei2  &f9 @102 PCT76Fi2  &f9 @112 PCT76Gi2  &f9 @126 PCT76Hi2  &f9 @137 PCT76Ii2  &f9
/@3'  In Married-Couple Families:'        @40 PCT52i3  &f9 @52 PCT76Ai3  &f9 @62 PCT76Bi3  &f9 @72 PCT76Ci3  &f9 @82 PCT76Di3  &f9 @92 PCT76Ei3  &f9 @102 PCT76Fi3  &f9 @112 PCT76Gi3  &f9 @126 PCT76Hi3  &f9 @137 PCT76Ii3  &f9
/@3'    Under 5 Years'                    @40 PCT52i4  &f9 @52 PCT76Ai4  &f9 @62 PCT76Bi4  &f9 @72 PCT76Ci4  &f9 @82 PCT76Di4  &f9 @92 PCT76Ei4  &f9 @102 PCT76Fi4  &f9 @112 PCT76Gi4  &f9 @126 PCT76Hi4  &f9 @137 PCT76Ii4  &f9
/@3'    5 Years'                          @40 PCT52i5  &f9 @52 PCT76Ai5  &f9 @62 PCT76Bi5  &f9 @72 PCT76Ci5  &f9 @82 PCT76Di5  &f9 @92 PCT76Ei5  &f9 @102 PCT76Fi5  &f9 @112 PCT76Gi5  &f9 @126 PCT76Hi5  &f9 @137 PCT76Ii5  &f9
/@3'    6 to 17 Years'                    @40 PCT52i6  &f9 @52 PCT76Ai6  &f9 @62 PCT76Bi6  &f9 @72 PCT76Ci6  &f9 @82 PCT76Di6  &f9 @92 PCT76Ei6  &f9 @102 PCT76Fi6  &f9 @112 PCT76Gi6  &f9 @126 PCT76Hi6  &f9 @137 PCT76Ii6  &f9
/@3'  In Other Families:'                 @40 PCT52i7  &f9 @52 PCT76Ai7  &f9 @62 PCT76Bi7  &f9 @72 PCT76Ci7  &f9 @82 PCT76Di7  &f9 @92 PCT76Ei7  &f9 @102 PCT76Fi7  &f9 @112 PCT76Gi7  &f9 @126 PCT76Hi7  &f9 @137 PCT76Ii7  &f9
/@3'   Male Householder, No Wife:'        @40 PCT52i8  &f9 @52 PCT76Ai8  &f9 @62 PCT76Bi8  &f9 @72 PCT76Ci8  &f9 @82 PCT76Di8  &f9 @92 PCT76Ei8  &f9 @102 PCT76Fi8  &f9 @112 PCT76Gi8  &f9 @126 PCT76Hi8  &f9 @137 PCT76Ii8  &f9
/@3'    Under 5 Years'                    @40 PCT52i9  &f9 @52 PCT76Ai9  &f9 @62 PCT76Bi9  &f9 @72 PCT76Ci9  &f9 @82 PCT76Di9  &f9 @92 PCT76Ei9  &f9 @102 PCT76Fi9  &f9 @112 PCT76Gi9  &f9 @126 PCT76Hi9  &f9 @137 PCT76Ii9  &f9
/@3'    5 Years'                          @40 PCT52i10 &f9 @52 PCT76Ai10 &f9 @62 PCT76Bi10 &f9 @72 PCT76Ci10 &f9 @82 PCT76Di10 &f9 @92 PCT76Ei10 &f9 @102 PCT76Fi10 &f9 @112 PCT76Gi10 &f9 @126 PCT76Hi10 &f9 @137 PCT76Ii10 &f9
/@3'    6 to 17 Years'                    @40 PCT52i11 &f9 @52 PCT76Ai11 &f9 @62 PCT76Bi11 &f9 @72 PCT76Ci11 &f9 @82 PCT76Di11 &f9 @92 PCT76Ei11 &f9 @102 PCT76Fi11 &f9 @112 PCT76Gi11 &f9 @126 PCT76Hi11 &f9 @137 PCT76Ii11 &f9
/@3'   Female Householder, No Husband:'   @40 PCT52i12 &f9 @52 PCT76Ai12 &f9 @62 PCT76Bi12 &f9 @72 PCT76Ci12 &f9 @82 PCT76Di12 &f9 @92 PCT76Ei12 &f9 @102 PCT76Fi12 &f9 @112 PCT76Gi12 &f9 @126 PCT76Hi12 &f9 @137 PCT76Ii12 &f9
/@3'    Under 5 Years'                    @40 PCT52i13 &f9 @52 PCT76Ai13 &f9 @62 PCT76Bi13 &f9 @72 PCT76Ci13 &f9 @82 PCT76Di13 &f9 @92 PCT76Ei13 &f9 @102 PCT76Fi13 &f9 @112 PCT76Gi13 &f9 @126 PCT76Hi13 &f9 @137 PCT76Ii13 &f9
/@3'    5 Years'                          @40 PCT52i14 &f9 @52 PCT76Ai14 &f9 @62 PCT76Bi14 &f9 @72 PCT76Ci14 &f9 @82 PCT76Di14 &f9 @92 PCT76Ei14 &f9 @102 PCT76Fi14 &f9 @112 PCT76Gi14 &f9 @126 PCT76Hi14 &f9 @137 PCT76Ii14 &f9
/@3'    6 to 17 Years'                    @40 PCT52i15 &f9 @52 PCT76Ai15 &f9 @62 PCT76Bi15 &f9 @72 PCT76Ci15 &f9 @82 PCT76Di15 &f9 @92 PCT76Ei15 &f9 @102 PCT76Fi15 &f9 @112 PCT76Gi15 &f9 @126 PCT76Hi15 &f9 @137 PCT76Ii15 &f9

//@3' In Families with Income in 1999'
/@3' at or above Poverty Level:'@40 PCT52i16 &f9 @52 PCT76Ai16 &f9 @62 PCT76Bi16 &f9 @72 PCT76Ci16 &f9 @82 PCT76Di16 &f9 @92 PCT76Ei16 &f9 @102 PCT76Fi16 &f9 @112 PCT76Gi16 &f9 @126 PCT76Hi16 &f9 @137 PCT76Ii16 &f9
/@3'  In Married-Couple Families:'        @40 PCT52i17 &f9 @52 PCT76Ai17 &f9 @62 PCT76Bi17 &f9 @72 PCT76Ci17 &f9 @82 PCT76Di17 &f9 @92 PCT76Ei17 &f9 @102 PCT76Fi17 &f9 @112 PCT76Gi17 &f9 @126 PCT76Hi17 &f9 @137 PCT76Ii17 &f9
/@3'    Under 5 Years'                    @40 PCT52i18 &f9 @52 PCT76Ai18 &f9 @62 PCT76Bi18 &f9 @72 PCT76Ci18 &f9 @82 PCT76Di18 &f9 @92 PCT76Ei18 &f9 @102 PCT76Fi18 &f9 @112 PCT76Gi18 &f9 @126 PCT76Hi18 &f9 @137 PCT76Ii18 &f9
/@3'    5 Years'                          @40 PCT52i19 &f9 @52 PCT76Ai19 &f9 @62 PCT76Bi19 &f9 @72 PCT76Ci19 &f9 @82 PCT76Di19 &f9 @92 PCT76Ei19 &f9 @102 PCT76Fi19 &f9 @112 PCT76Gi19 &f9 @126 PCT76Hi19 &f9 @137 PCT76Ii19 &f9
/@3'    6 to 17 Years'                    @40 PCT52i20 &f9 @52 PCT76Ai20 &f9 @62 PCT76Bi20 &f9 @72 PCT76Ci20 &f9 @82 PCT76Di20 &f9 @92 PCT76Ei20 &f9 @102 PCT76Fi20 &f9 @112 PCT76Gi20 &f9 @126 PCT76Hi20 &f9 @137 PCT76Ii20 &f9
/@3'  In Other Families:'                 @40 PCT52i21 &f9 @52 PCT76Ai21 &f9 @62 PCT76Bi21 &f9 @72 PCT76Ci21 &f9 @82 PCT76Di21 &f9 @92 PCT76Ei21 &f9 @102 PCT76Fi21 &f9 @112 PCT76Gi21 &f9 @126 PCT76Hi21 &f9 @137 PCT76Ii21 &f9
/@3'   Male Householder, No Wife:'        @40 PCT52i22 &f9 @52 PCT76Ai22 &f9 @62 PCT76Bi22 &f9 @72 PCT76Ci22 &f9 @82 PCT76Di22 &f9 @92 PCT76Ei22 &f9 @102 PCT76Fi22 &f9 @112 PCT76Gi22 &f9 @126 PCT76Hi22 &f9 @137 PCT76Ii22 &f9
/@3'    Under 5 Years'                    @40 PCT52i23 &f9 @52 PCT76Ai23 &f9 @62 PCT76Bi23 &f9 @72 PCT76Ci23 &f9 @82 PCT76Di23 &f9 @92 PCT76Ei23 &f9 @102 PCT76Fi23 &f9 @112 PCT76Gi23 &f9 @126 PCT76Hi23 &f9 @137 PCT76Ii23 &f9
/@3'    5 Years'                          @40 PCT52i24 &f9 @52 PCT76Ai24 &f9 @62 PCT76Bi24 &f9 @72 PCT76Ci24 &f9 @82 PCT76Di24 &f9 @92 PCT76Ei24 &f9 @102 PCT76Fi24 &f9 @112 PCT76Gi24 &f9 @126 PCT76Hi24 &f9 @137 PCT76Ii24 &f9
/@3'    6 to 17 Years'                    @40 PCT52i25 &f9 @52 PCT76Ai25 &f9 @62 PCT76Bi25 &f9 @72 PCT76Ci25 &f9 @82 PCT76Di25 &f9 @92 PCT76Ei25 &f9 @102 PCT76Fi25 &f9 @112 PCT76Gi25 &f9 @126 PCT76Hi25 &f9 @137 PCT76Ii25 &f9
/@3'   Female Householder, No Husband:'   @40 PCT52i26 &f9 @52 PCT76Ai26 &f9 @62 PCT76Bi26 &f9 @72 PCT76Ci26 &f9 @82 PCT76Di26 &f9 @92 PCT76Ei26 &f9 @102 PCT76Fi26 &f9 @112 PCT76Gi26 &f9 @126 PCT76Hi26 &f9 @137 PCT76Ii26 &f9
/@3'    Under 5 Years'                    @40 PCT52i27 &f9 @52 PCT76Ai27 &f9 @62 PCT76Bi27 &f9 @72 PCT76Ci27 &f9 @82 PCT76Di27 &f9 @92 PCT76Ei27 &f9 @102 PCT76Fi27 &f9 @112 PCT76Gi27 &f9 @126 PCT76Hi27 &f9 @137 PCT76Ii27 &f9
/@3'    5 Years'                          @40 PCT52i28 &f9 @52 PCT76Ai28 &f9 @62 PCT76Bi28 &f9 @72 PCT76Ci28 &f9 @82 PCT76Di28 &f9 @92 PCT76Ei28 &f9 @102 PCT76Fi28 &f9 @112 PCT76Gi28 &f9 @126 PCT76Hi28 &f9 @137 PCT76Ii28 &f9
/@3'    6 to 17 Years'                    @40 PCT52i29 &f9 @52 PCT76Ai29 &f9 @62 PCT76Bi29 &f9 @72 PCT76Ci29 &f9 @82 PCT76Di29 &f9 @92 PCT76Ei29 &f9 @102 PCT76Fi29 &f9 @112 PCT76Gi29 &f9 @126 PCT76Hi29 &f9 @137 PCT76Ii29 &f9 ;

PUT # 56
 @3' * For Census 2000, persons could report more than one race, but the seven racial categories shown are mutually exclusive and include everyone.'
/@3'** Hispanic or Latino is NOT considered a race. People who reported themselves as Hispanic or Latino are also counted in the seven racial'
/@3'   categories.';
link HeadFoot;
end;  *<-----------of code to generate 6th page----;

IF INDEX(_pages,'7') THEN DO;


%PutTitle(
   %STR(Poverty Profile 7: PERSONS BY AGE & ALTERNATIVE POVERTY LEVELS; FAMILIES BY INCOME SOURCES),
   %STR(Pov-7)) ;

**--Draw horizontal lines--**;
PUT #34 @2 147*'-';
PUT #57 @2 147*'-';

*--Generate table PCT50.--**;

*--Total Population below Poverty Level--**;

 * 13 Age groups by 10 levels (zeroth level is a place holder: total age cohort) ;
ARRAY PCT50array[13,0:10] PCT50i2-PCT50i144 ;
ARRAY PCT50t[10] ; * totals across all age groups ;
DO Level=1 TO 10;
  PCT50t[Level]=0 ;
  DO Age= 1 TO 13 ;
    PCT50t[Level]+PCT50array[Age,Level] ;
  END ;
END ;


*--Total Population Rate by Age--**;

IF  PCT50i1=0  THEN RTBA1=. ; ELSE RTBA1=  (PCT49i3 + PCT49i17)*100/ PCT50i1;
IF  PCT50i2=0  THEN RTBA2=. ; ELSE RTBA2=  (PCT49i4 + PCT49i18)*100/ PCT50i2;
IF  PCT50i13=0 THEN RTBA3=. ; ELSE RTBA3=  (PCT49i5 + PCT49i19)*100/ PCT50i13;
IF  PCT50i24=0 THEN RTBA4=. ; ELSE RTBA4=  (PCT49i6 + PCT49i20)*100/ PCT50i24;
IF  PCT50i35=0 THEN RTBA5=. ; ELSE RTBA5=  (PCT49i7 + PCT49i21)*100/ PCT50i35;
IF  PCT50i46=0 THEN RTBA6=. ; ELSE RTBA6=  (PCT49i8 + PCT49i22)*100/ PCT50i46;
IF  PCT50i57=0 THEN RTBA7=. ; ELSE RTBA7=  (PCT49i9 + PCT49i23)*100/ PCT50i57;
IF  PCT50i68=0 THEN RTBA8=. ; ELSE RTBA8=  (PCT49i10+ PCT49i24)*100/ PCT50i68;
IF  PCT50i79=0 THEN RTBA9=. ; ELSE RTBA9=  (PCT49i11+ PCT49i25)*100/ PCT50i79;
IF  PCT50i90=0 THEN RTBA10=. ; ELSE RTBA10=(PCT49i12+ PCT49i26)*100/ PCT50i90;
IF  PCT50i101=0 THEN RTBA11=.; ELSE RTBA11=(PCT49i13+ PCT49i27)*100/ PCT50i101;
IF  PCT50i112=0 THEN RTBA12=.; ELSE RTBA12=(PCT49i14+ PCT49i28)*100/ PCT50i112;
IF  PCT50i123=0 THEN RTBA13=.; ELSE RTBA13=(PCT49i15+ PCT49i29)*100/ PCT50i123;
IF  PCT50i134=0 THEN RTBA14=.; ELSE RTBA14=(PCT49i16+ PCT49i30)*100/ PCT50i134;

*--Total Population Under 18 Years--**;

TOTU18Y1  =PCT50i2 +PCT50i13+PCT50i24+PCT50i35+PCT50i46+PCT50i57;
TOTU18Y2  =PCT50i3 +PCT50i14+PCT50i25+PCT50i36+PCT50i47+PCT50i58;
TOTU18Y3  =PCT50i4 +PCT50i15+PCT50i26+PCT50i37+PCT50i48+PCT50i59;
TOTU18Y4  =PCT50i5 +PCT50i16+PCT50i27+PCT50i38+PCT50i49+PCT50i60;
TOTU18Y5  =PCT50i6 +PCT50i17+PCT50i28+PCT50i39+PCT50i50+PCT50i61;
TOTU18Y6  =PCT50i7 +PCT50i18+PCT50i29+PCT50i40+PCT50i51+PCT50i62;
TOTU18Y7  =PCT50i8 +PCT50i19+PCT50i30+PCT50i41+PCT50i52+PCT50i63;
TOTU18Y8  =PCT50i9 +PCT50i20+PCT50i31+PCT50i42+PCT50i53+PCT50i64;
TOTU18Y9  =PCT50i10+PCT50i21+PCT50i32+PCT50i43+PCT50i54+PCT50i65;
TOTU18Y10 =PCT50i11+PCT50i22+PCT50i33+PCT50i44+PCT50i55+PCT50i66;
TOTU18Y11 =PCT50i12+PCT50i23+PCT50i34+PCT50i45+PCT50i56+PCT50i67;

*--Percent Under 18 Years--**;

IF TOTU18Y1=0 THEN DO ;
  PCTU18Y2 =. ; PCTU18Y3 =. ; PCTU18Y4 =. ; PCTU18Y5 =. ; PCTU18Y6 =. ;
  PCTU18Y7 =. ; PCTU18Y8 =. ; PCTU18Y9 =. ; PCTU18Y10=. ; PCTU18Y11=. ;
END ;
ELSE DO ;
  PCTU18Y2 = (TOTU18Y2* 100/TOTU18Y1);
  PCTU18Y3 = (TOTU18Y3* 100/TOTU18Y1) +PCTU18Y2;
  PCTU18Y4 = (TOTU18Y4* 100/TOTU18Y1) +PCTU18Y3;
  PCTU18Y5 = (TOTU18Y5* 100/TOTU18Y1) +PCTU18Y4;
  PCTU18Y6 = (TOTU18Y6* 100/TOTU18Y1) +PCTU18Y5;
  PCTU18Y7 = (TOTU18Y7* 100/TOTU18Y1) +PCTU18Y6;
  PCTU18Y8 = (TOTU18Y8* 100/TOTU18Y1) +PCTU18Y7;
  PCTU18Y9 = (TOTU18Y9* 100/TOTU18Y1) +PCTU18Y8;
  PCTU18Y10= (TOTU18Y10*100/TOTU18Y1) +PCTU18Y9;
  PCTU18Y11= (TOTU18Y11*100/TOTU18Y1)+PCTU18Y10;
END ;

*--Total Population Over  65 Years--**;

TOTO65Y1  =PCT50i123 +PCT50i134;
TOTO65Y2  =PCT50i124 +PCT50i135;
TOTO65Y3  =PCT50i125 +PCT50i136;
TOTO65Y4  =PCT50i126 +PCT50i137;
TOTO65Y5  =PCT50i127 +PCT50i138;
TOTO65Y6  =PCT50i128 +PCT50i139;
TOTO65Y7  =PCT50i129 +PCT50i140;
TOTO65Y8  =PCT50i130 +PCT50i141;
TOTO65Y9  =PCT50i131 +PCT50i142;
TOTO65Y10 =PCT50i132 +PCT50i143;
TOTO65Y11 =PCT50i133 +PCT50i144;

*--Percent Over 65 Years--**;

IF TOTO65Y1=0 THEN DO ;
  PCTO65Y2 =. ; PCTO65Y3 =. ; PCTO65Y4 =. ; PCTO65Y5 =. ; PCTO65Y6 =. ;
  PCTO65Y7 =. ; PCTO65Y8 =. ; PCTO65Y9 =. ; PCTO65Y10=. ; PCTO65Y11=. ;
END ;
ELSE DO ;
  PCTO65Y2 = (TOTO65Y2* 100/TOTO65Y1);
  PCTO65Y3 = (TOTO65Y3* 100/TOTO65Y1) +PCTO65Y2;
  PCTO65Y4 = (TOTO65Y4* 100/TOTO65Y1) +PCTO65Y3;
  PCTO65Y5 = (TOTO65Y5* 100/TOTO65Y1) +PCTO65Y4;
  PCTO65Y6 = (TOTO65Y6* 100/TOTO65Y1) +PCTO65Y5;
  PCTO65Y7 = (TOTO65Y7* 100/TOTO65Y1) +PCTO65Y6;
  PCTO65Y8 = (TOTO65Y8* 100/TOTO65Y1) +PCTO65Y7;
  PCTO65Y9 = (TOTO65Y9* 100/TOTO65Y1) +PCTO65Y8;
  PCTO65Y10= (TOTO65Y10*100/TOTO65Y1) +PCTO65Y9;
  PCTO65Y11= (TOTO65Y11*100/TOTO65Y1) +PCTO65Y10;
END ;

PUT #8
@3'PCT50. AGE BY RATIO OF INCOME IN 1999 TO POVERTY LEVEL'
/@3'Universe: Population for whom poverty status is determined (*)'
//                                @55'0.50'   @66'0.75'  @77'1.00'    @88'1.25'  @99 '1.30' @110'1.50'  @121 '1.75'   @132 '1.85' @143 '2.00'
/     @34'Pov.'     @43'Under'    @56'to'     @67 'to'   @78'to'      @89'to'    @100'to'   @111 'to'   @122'to'      @133'to'    @144 'and'
/                                  @28 'Total'   @34'Rate'     @44 '0.50'    @55'0.74'   @66'0.99'  @77'1.24'    @88 '1.29' @99'1.49'  @110'1.74'  @121 '1.84' @132'1.99' @143 'Over'
//@3'Total Universe*:'@23 PCT50i1   &f10 @34 RTBA1 &p4 @39 PCT50t1   &f9  @49 PCT50t2   &f10 @60 PCT50t3   &f10 @71 PCT50t4   &f10 @82 PCT50t5   &f10 @93 PCT50t6   &f10 @104 PCT50t7   &f10 @115 PCT50t8   &f10
@126 PCT50t9   &f10  @137 PCT50t10 &f10
/ @3' Under 5 Years'     @23 PCT50i2   &f10 @34 RTBA2 &p4 @39 PCT50i3   &f9  @49 PCT50i4   &f10 @60 PCT50i5   &f10 @71 PCT50i6   &f10 @82 PCT50i7   &f10 @93 PCT50i8   &f10 @104 PCT50i9   &f10 @115 PCT50i10  &f10
@126 PCT50i11  &f10  @137 PCT50i12 &f10
/ @3' 5 Years'           @23 PCT50i13  &f10 @34 RTBA3 &p4 @39 PCT50i14  &f9  @49 PCT50i15  &f10 @60 PCT50i16  &f10 @71 PCT50i17  &f10 @82 PCT50i18  &f10 @93 PCT50i19  &f10 @104 PCT50i20  &f10 @115 PCT50i21  &f10
@126 PCT50i22  &f10  @137 PCT50i23 &f10
/ @3' 6 to 11 Years'     @23 PCT50i24  &f10 @34 RTBA4 &p4 @39 PCT50i25  &f9  @49 PCT50i26  &f10 @60 PCT50i27  &f10 @71 PCT50i28  &f10 @82 PCT50i29  &f10 @93 PCT50i30  &f10 @104 PCT50i31  &f10 @115 PCT50i32  &f10
@126 PCT50i33  &f10  @137 PCT50i34 &f10
/ @3' 12 to 14 Years'    @23 PCT50i35  &f10 @34 RTBA5 &p4 @39 PCT50i36  &f9  @49 PCT50i37  &f10 @60 PCT50i38  &f10 @71 PCT50i39  &f10 @82 PCT50i40  &f10 @93 PCT50i41  &f10 @104 PCT50i42  &f10 @115 PCT50i43  &f10
@126 PCT50i44  &f10  @137 PCT50i45 &f10
/ @3' 15 Years'          @23 PCT50i46  &f10 @34 RTBA6 &p4 @39 PCT50i47  &f9  @49 PCT50i48  &f10 @60 PCT50i49  &f10 @71 PCT50i50  &f10 @82 PCT50i51  &f10 @93 PCT50i52  &f10 @104 PCT50i53  &f10 @115 PCT50i54  &f10
@126 PCT50i55  &f10  @137 PCT50i56 &f10
/ @3' 16 and 17 Years'   @23 PCT50i57  &f10 @34 RTBA7 &p4 @39 PCT50i58  &f9  @49 PCT50i59  &f10 @60 PCT50i60  &f10 @71 PCT50i61  &f10 @82 PCT50i62  &f10 @93 PCT50i63  &f10 @104 PCT50i64  &f10 @115 PCT50i65  &f10
@126 PCT50i66  &f10  @137 PCT50i67 &f10
/ @3' 18 to 24 Years'    @23 PCT50i68  &f10 @34 RTBA8 &p4 @39 PCT50i69  &f9  @49 PCT50i70  &f10 @60 PCT50i71  &f10 @71 PCT50i72  &f10 @82 PCT50i73  &f10 @93 PCT50i74  &f10 @104 PCT50i75  &f10 @115 PCT50i76  &f10
@126 PCT50i77  &f10  @137 PCT50i78 &f10
/ @3' 25 to 34 Years'    @23 PCT50i79  &f10 @34 RTBA9 &p4 @39 PCT50i80  &f9  @49 PCT50i81  &f10 @60 PCT50i82  &f10 @71 PCT50i83  &f10 @82 PCT50i84  &f10 @93 PCT50i85  &f10 @104 PCT50i86  &f10 @115 PCT50i87  &f10
@126 PCT50i88  &f10  @137 PCT50i89 &f10
/ @3' 35 to 44 Years'    @23 PCT50i90  &f10 @34 RTBA10 &p4 @39 PCT50i91  &f9  @49 PCT50i92  &f10 @60 PCT50i93  &f10 @71 PCT50i94  &f10 @82 PCT50i95  &f10 @93 PCT50i96  &f10 @104 PCT50i97  &f10 @115 PCT50i98  &f10
@126 PCT50i99  &f10  @137 PCT50i100 &f10
/ @3' 45 to 54 Years'    @23 PCT50i101 &f10 @34 RTBA11 &p4 @39 PCT50i102 &f9  @49 PCT50i103 &f10 @60 PCT50i104 &f10 @71 PCT50i105 &f10 @82 PCT50i106 &f10 @93 PCT50i107 &f10 @104 PCT50i108 &f10 @115 PCT50i109 &f10
@126 PCT50i110 &f10  @137 PCT50i111 &f10
/ @3' 55 to 64 Years'    @23 PCT50i112 &f10 @34 RTBA12 &p4 @39 PCT50i113 &f9  @49 PCT50i114 &f10 @60 PCT50i115 &f10 @71 PCT50i116 &f10 @82 PCT50i117 &f10 @93 PCT50i118 &f10 @104 PCT50i119 &f10 @115 PCT50i120 &f10
@126 PCT50i121 &f10  @137 PCT50i122 &f10
/ @3' 65 to 74 Years'    @23 PCT50i123 &f10 @34 RTBA13 &p4 @39 PCT50i124 &f9  @49 PCT50i125 &f10 @60 PCT50i126 &f10 @71 PCT50i127 &f10 @82 PCT50i128 &f10 @93 PCT50i129 &f10 @104 PCT50i130 &f10 @115 PCT50i131 &f10
@126 PCT50i132 &f10  @137 PCT50i133 &f10
/ @3' 75 Years and Over' @23 PCT50i134 &f10 @34 RTBA14 &p4 @39 PCT50i135 &f9  @49 PCT50i136 &f10 @60 PCT50i137 &f10 @71 PCT50i138 &f10 @82 PCT50i139 &f10 @93 PCT50i140 &f10 @104 PCT50i141 &f10 @115 PCT50i142 &f10
@126 PCT50i143 &f10  @137 PCT50i144 &f10
//@3'Number under 18 yrs:'@23TOTU18Y1  &f10               @39 TOTU18Y2  &f9  @49 TOTU18Y3 &f10  @60 TOTU18Y4 &f10  @71 TOTU18Y5 &f10  @82 TOTU18Y6 &f10  @93 TOTU18Y7 &f10  @104 TOTU18Y8 &f10  @115 TOTU18Y9 &f10
@126 TOTU18Y10 &f10  @137 TOTU18Y11 &f10
/@3'Cumulative Percent under 18:'                         @39 PCTU18Y2  &p9  @49 PCTU18Y3  &p10 @60 PCTU18Y4  &p10 @71 PCTU18Y5  &p10    @82 PCTU18Y6  &p10    @93 PCTU18Y7  &p10    @104 PCTU18Y8  &p10    @115 PCTU18Y9  &p10
@126 PCTU18Y10  &p10    @137 PCTU18Y11  &p10
/@3'Number 65 yrs & over:'@24TOTO65Y1  &f9                @39 TOTO65Y2  &f9  @49 TOTO65Y3  &f10 @60 TOTO65Y4  &f10 @71 TOTO65Y5  &f10 @82 TOTO65Y6  &f10 @93 TOTO65Y7 &f10  @104 TOTO65Y8 &f10  @115 TOTO65Y9 &f10
@126 TOTO65Y10  &f10 @137 TOTO65Y11  &f10
/@3'Cumulative Percent 65 & over:'                        @39 PCTO65Y2  &p9  @49 PCTO65Y3  &p10 @60 PCTO65Y4  &p10 @71 PCTO65Y5  &p10    @82 PCTO65Y6  &p10    @93 PCTO65Y7  &p10    @104 PCTO65Y8  &p10    @115 PCTO65Y9  &p10
@126 PCTO65Y10  &p10    @137 PCTO65Y11  &p10 ;

**--Generate table PCT59.--**;

**--Other Families.--**;

OFAMTOT1=PCT59i12+PCT59i19;
OFAMTOT2=PCT59i15+PCT59i22;
OFAMTOT3=PCT59i35+PCT59i42;
OFAMTOT4=PCT59i38+PCT59i45;

**--Total Families.--**;

TOTFAM1=OFAMTOT1+PCT59i4;
TOTFAM2=OFAMTOT2+PCT59i7;
TOTFAM3=OFAMTOT3+PCT59i27;
TOTFAM4=OFAMTOT4+PCT59i30;

**--Total Families with Income above and below Poverty Level.--**;

TOT1=TOTFAM1+TOTFAM2+TOTFAM3+TOTFAM4;
TOT2=PCT59i4+PCT59i7+PCT59i27+PCT59i30;
TOT3=PCT59i5+PCT59i8+PCT59i28+PCT59i31;
TOT4=PCT59i6+PCT59i9+PCT59i29+PCT59i32;
TOT5=OFAMTOT1+OFAMTOT2+OFAMTOT3+OFAMTOT4;
TOT6=PCT59i12+PCT59i15+PCT59i35+PCT59i38;
TOT7=PCT59i13+PCT59i16+PCT59i36+PCT59i39;
TOT8=PCT59i14+PCT59i17+PCT59i37+PCT59i40;
TOT9=PCT59i19+PCT59i22+PCT59i42+PCT59i45;
TOT10=PCT59i20+PCT59i23+PCT59i43+PCT59i46;
TOT11=PCT59i21+PCT59i24+PCT59i44+PCT59i47;

PUT # 36

@3'PCT59. POVERTY STATUS IN 1999 OF FAMILIES BY FAMILY TYPE BY SOCIAL SECURITY INCOME BY SUPPLEMENTAL SECURITY INCOME (SSI) AND/OR PUBLIC ASSISTANCE'
/ @10'INCOME'
/ @3'Universe: Families'                                                           @82 'Families with Income'                       @117 '  Families with Income'
/                                                                                   @75'-- in 1999 below Poverty Level --'           @113 'in 1999 at or above Poverty Level'
/                                                                                   @79'With Social'         @91 '|  Without Social' @117 'With Social'      @129'|  Without Social'
/                                                                                   @75'Security Income'     @91 '| Security Income' @113 'Security Income'  @129'| Security Income'
/                                                                                   @83'in 1999'             @91 '|         in 1999' @121 'in 1999'          @129'|         in 1999'
/                                                            @65'Total'                                      @91 '|'                                         @129'|'
/ @3'Total Families:'                                        @60 TOT1  &f10      @80 TOTFAM1     &f10  @98 TOTFAM2   &f10  @118 TOTFAM3   &f10  @136 TOTFAM4  &f10
// @3' Married-Couple Families:'                             @60 TOT2  &f10      @80 PCT59i4     &f10  @98 PCT59i7    &f10 @118 PCT59i27  &f10  @136 PCT59i30 &f10
/ @3'   With SSI and/or Public Assistance Income in 1999 '   @60 TOT3  &f10      @80 PCT59i5     &f10  @98 PCT59i8   &f10  @118 PCT59i28  &f10  @136 PCT59i31 &f10
/ @3'   Without SSI and/or Public Assistance Income in 1999' @60 TOT4  &f10      @80 PCT59i6     &f10  @98 PCT59i9   &f10  @118 PCT59i29  &f10  @136 PCT59i32 &f10
/ @3' Other Families:'                                       @60 TOT5  &f10      @80 OFAMTOT1    &f10  @98 OFAMTOT2  &f10  @118 OFAMTOT3  &f10  @136 OFAMTOT4 &f10
/ @3'  Male Householder, No wife Present:'                   @60 TOT6  &f10      @80 PCT59i12    &f10  @98 PCT59i15  &f10  @118 PCT59i35  &f10  @136 PCT59i38 &f10
/ @3'   With SSI and/or Public Assistance Income in 1999'    @60 TOT7  &f10      @80 PCT59i13    &f10  @98 PCT59i16  &f10  @118 PCT59i36  &f10  @136 PCT59i39 &f10
/ @3'   Without SSI and/or Public Assistance Income in 1999' @60 TOT8  &f10      @80 PCT59i14    &f10  @98 PCT59i17  &f10  @118 PCT59i37  &f10  @136 PCT59i40 &f10
/ @3'  Female Householder, No Husband Present:'              @60 TOT9  &f10      @80 PCT59i19    &f10  @98 PCT59i22  &f10  @118 PCT59i42  &f10  @136 PCT59i45 &f10
/ @3'   With SSI and/or Public Assistance Income in 1999'    @60 TOT10 &f10      @80 PCT59i20    &f10  @98 PCT59i23  &f10  @118 PCT59i43  &f10  @136 PCT59i46 &f10
/ @3'   Without SSI and/or Public Assistance Income in 1999' @60 TOT11 &f10      @80 PCT59i21    &f10  @98 PCT59i24  &f10  @118 PCT59i44  &f10  @136 PCT59i47 &f10 ;

PUT # 59
 @3' * Poverty universe includes all people EXCEPT (1) those in institutions, military group quarters, and college dormitories and (2) unrelated'
/@3'   individuals under 15 years old (children who are not related family members).';
link HeadFoot;
end;  *<-----------of code to generate 7th page----;

IF INDEX(_pages,'8') THEN DO;


%PutTitle(
   %STR(Poverty Profile 8: FAMILIES BY WORK EXPERIENCE AND BY ALTERNATE POVERTY LEVELS),
   %STR(Pov-8)) ;

**--Draw horizontal lines--**;
PUT #29 @2 147*'-';

**--Draw (internal) vertical lines--**;

do _i_=9 to 27;
  PUT #_I_ @75 ':';
  end;

do _i_=9 to 27;
  PUT #_I_ @113 ':';
  end;

do _i_=33 to 60;
  PUT #_I_ @117 ':';
  end;

*--Generate table PCT60.--**;

**-----Calculate Total/Married Couple Families below Poverty-----**;
array mdfB(3);
array ofB(3);
array tfB(3);

mdfB1 = PCT60i5 + PCT60i6  + PCT60i7;
mdfB2 = PCT60i9 + PCT60i10 + PCT60i11;
mdfB3 = PCT60i13+ PCT60i14 + PCT60i15;

ofB1 = PCT60i18 + PCT60i22;
ofB2 = PCT60i19 + PCT60i23;
ofB3 = PCT60i20 + PCT60i24;

Do i=1 to 3;
tfB (i) = mdfB(i) + ofB(i);
end;

**-----Calculate Total/Married Couple Families below Poverty-----**;

array mdfA(3);
array ofA(3);
array tfA(3);

mdfA1 = PCT60i28 + PCT60i29 + PCT60i30;
mdfA2 = PCT60i32 + PCT60i33 + PCT60i34;
mdfA3 = PCT60i36 + PCT60i37 + PCT60i38;

ofA1 = PCT60i41 + PCT60i45;
ofA2 = PCT60i42 + PCT60i46;
ofA3 = PCT60i43 + PCT60i47;

Do i=1 to 3;
tfA (i) = mdfA(i) + ofA(i);
end;

**--Percent Householder worked full- Time --**;

IF (tfB1  + tfA1)=0        THEN PFT1=. ; ELSE PFT1= tfB1    *100/(tfB1  + tfA1);
IF (mdfB1 + mdfA1)=0       THEN PFT2=. ; ELSE PFT2= mdfB1   *100/(mdfB1 + mdfA1);
IF (PCT60i5 +  PCT60i28)=0 THEN PFT3=. ; ELSE PFT3= PCT60i5 *100/(PCT60i5 +  PCT60i28);
IF (PCT60i6 +  PCT60i29)=0 THEN PFT4=. ; ELSE PFT4= PCT60i6 *100/(PCT60i6 +  PCT60i29);
IF (PCT60i7 +  PCT60i30)=0 THEN PFT5=. ; ELSE PFT5= PCT60i7 *100/(PCT60i7 +  PCT60i30);
IF (PCT60i18 + PCT60i41)=0 THEN PFT6=. ; ELSE PFT6= PCT60i18*100/(PCT60i18 + PCT60i41);
IF (PCT60i22 + PCT60i45)=0 THEN PFT7=. ; ELSE PFT7= PCT60i22*100/(PCT60i22 + PCT60i45);
IF (ofB1+ofA1) =0          THEN PFTo=. ; ELSE PFTo= ofB1    *100/(ofB1+ofA1) ;

**--Percent Householder worked less than full- Time --**;

IF (tfB2  + tfA2)=0        THEN PLFT1=. ; ELSE PLFT1= tfB2    *100/(tfB2  + tfA2);
IF (mdfB2 + mdfA2)=0       THEN PLFT2=. ; ELSE PLFT2= mdfB2   *100/(mdfB2 + mdfA2);
IF (PCT60i9  + PCT60i32)=0 THEN PLFT3=. ; ELSE PLFT3= PCT60i9 *100/(PCT60i9  + PCT60i32);
IF (PCT60i10 + PCT60i33)=0 THEN PLFT4=. ; ELSE PLFT4= PCT60i10*100/(PCT60i10 + PCT60i33);
IF (PCT60i11 + PCT60i34)=0 THEN PLFT5=. ; ELSE PLFT5= PCT60i11*100/(PCT60i11 + PCT60i34);
IF (PCT60i19 + PCT60i42)=0 THEN PLFT6=. ; ELSE PLFT6= PCT60i19*100/(PCT60i19 + PCT60i42);
IF (PCT60i23 + PCT60i46)=0 THEN PLFT7=. ; ELSE PLFT7= PCT60i23*100/(PCT60i23 + PCT60i46);
IF (ofB2+ofA2) =0          THEN PLFTo=. ; ELSE PLFTo= ofB2    *100/(ofB2+ofA2) ;

**--Percent Householder Did not work --**;

IF (tfB3 + tfA3)=0         THEN PDNW1=. ; ELSE PDNW1= tfB3    *100/(tfB3 + tfA3);
IF (mdfB3 + mdfA3)=0       THEN PDNW2=. ; ELSE PDNW2= mdfB3   *100/(mdfB3 + mdfA3);
IF (PCT60i13 + PCT60i36)=0 THEN PDNW3=. ; ELSE PDNW3= PCT60i13*100/(PCT60i13 + PCT60i36);
IF (PCT60i14 + PCT60i37)=0 THEN PDNW4=. ; ELSE PDNW4= PCT60i14*100/(PCT60i14 + PCT60i37);
IF (PCT60i15 + PCT60i38)=0 THEN PDNW5=. ; ELSE PDNW5= PCT60i15*100/(PCT60i15 + PCT60i38);
IF (PCT60i20 + PCT60i43)=0 THEN PDNW6=. ; ELSE PDNW6= PCT60i20*100/(PCT60i20 + PCT60i43);
IF (PCT60i24 + PCT60i47)=0 THEN PDNW7=. ; ELSE PDNW7= PCT60i24*100/(PCT60i24 + PCT60i47);
IF (ofB3+ofA3) =0          THEN PDNWo=. ; ELSE PDNWo= ofB3    *100/(ofB3+ofA3) ;

PUT #7
@3'PCT60. POVERTY STATUS IN 1999 OF FAMILIES BY FAMILY TYPE BY WORK EXPERIENCE OF HOUSEHOLDER AND SPOUSE'
/@3'Universe: Families'
/                                    @41'-Householder Worked Full-Time,-'                  @79'--Householder Worked less than-'                  @116'----Householder Did Not Work---'
/                                    @41'-------Year-Round in 1999------'                  @79'-Full-Time, Year-Round in 1999-'                  @116'------------in 1999------------'
/                                    @41'--Below Poverty--'         @59'Above Poverty'     @79 '--Below Poverty--'        @97 'Above Poverty'    @116'--Below Poverty--'           @134 'Above Poverty'
/                                        @45'Number   Pct.'                                    @83 'Number   Pct.'                                   @120'Number   Pct.'
//@3'Total Families:'                @41 tfB1    &f10  @54 PFT1 &p4   @62 tfA1      &f10   @79  tfB2     &f10   @92PLFT1 &p4 @100 tfA2    &f10    @116 tfB3     &f10   @129 PDNW1 &p4  @137 tfA3     &f10
 /@3' Married-Couple Families:'      @41 mdfB1   &f10  @54 PFT2 &p4   @62 mdfA1     &f10   @79  mdfB2    &f10   @92PLFT2 &p4 @100 mdfA2    &f10   @116 mdfB3    &f10   @129 PDNW2 &p4  @137 mdfA3    &f10
//@3'  Spouse Worked Full-Time,'
 /@3'    Year-Round in 1999'         @41 PCT60i5  &f10 @54 PFT3 &p4   @62 PCT60i28  &f10   @79  PCT60i9  &f10   @92PLFT3 &p4 @100 PCT60i32 &f10   @116 PCT60i13 &f10   @129 PDNW3 &p4  @137 PCT60i36 &f10
//@3'  Spouse Worked less than Full-Time,'
 /@3'    Year-Round in 1999'         @41 PCT60i6  &f10 @54 PFT4 &p4   @62 PCT60i29  &f10   @79  PCT60i10 &f10   @92PLFT4 &p4 @100 PCT60i33 &f10   @116 PCT60i14 &f10   @129 PDNW4 &p4  @137 PCT60i37 &f10
//@3'  Spouse Did Not Work in 1999'  @41 PCT60i7  &f10 @54 PFT5 &p4   @62 PCT60i30  &f10   @79  PCT60i11 &f10   @92PLFT5 &p4 @100 PCT60i34 &f10   @116 PCT60i15 &f10   @129 PDNW5 &p4  @137 PCT60i38 &f10
//@3' Other Families:'               @41 ofB1    &f10  @54 PFTo &p4   @62 ofA1      &f10   @79  ofB2     &f10   @92PLFTo &p4 @100 ofA2    &f10    @116 ofB3     &f10   @129 PDNWo &p4  @137 ofA3     &f10
 /@3'  Male Householder, No Wife'    @41 PCT60i18 &f10 @54 PFT6 &p4   @62 PCT60i41  &f10   @79  PCT60i19 &f10   @92PLFT6 &p4 @100 PCT60i42 &f10   @116 PCT60i20 &f10   @129 PDNW6 &p4  @137 PCT60i43 &f10
 /@3'  Female Householder, No Husband'@41 PCT60i22 &f10 @54 PFT7 &p4  @62 PCT60i45  &f10   @79  PCT60i23 &f10   @92PLFT7 &p4 @100 PCT60i46 &f10   @116 PCT60i24 &f10   @129 PDNW7 &p4  @137 PCT60i47 &f10 ;

*--Generate table PCT61.--**;

ARRAY und100(19)   P90i3 -  P90i21 ;
ARRAY abov100(19) P90i23 -  P90i41 ;
ARRAY und130(19) PCT61i3 -PCT61i21;
ARRAY to149(19)  PCT61i23-PCT61i41; * i.e. 1.30 to 1.49 ;
ARRAY to184(19)  PCT61i43-PCT61i61; * i.e. 1.50 to 1.84 ;
ARRAY diff  (19); * 1.00  to 1.29 ;
ARRAY CT150u(19); * Cumul to <1.50 ;
ARRAY CT185u(19); * Cumul to <1.85 ;
ARRAY TotAll(19); * All levels ;

DO i=1 TO 19 ;
  diff(i) = und130(i) - und100(i) ;
  CT150u(i)=und130(i) + to149(i) ;
  CT185u(i)=CT150u(i) + to184(i) ;
  TotAll(i)=und100(i) + abov100(i) ;
END ;
diff0 = PCT61i2 - P90i2 ;
CT150u0=PCT61i2 + PCT61i22 ;
CT185u0=CT150u0 + PCT61i42 ;

PUT #31
  @3'P90/PCT61. RATIO OF INCOME IN 1999 TO POVERTY LEVEL OF FAMILIES BY FAMILY TYPE BY PRESENCE AND AGE OF RELATED CHILDREN UNDER 18 YEARS OF AGE'
 /@3'Universe: Families'
 /                                                                                   @76'1.00'         @87' 1.30'          @100'1.50'         @112 '1.85'         @122'Cumulative'  @136'Cumulative'
 /                                                                   @63'Under'      @76'  to'           @89' to'           @101' to'          @113 'and'              @127'Total'       @141'Total'
 /                                               @45   '      Total'  @64'1.00'      @76'1.29'         @87' 1.49'          @100'1.84'        @111 'above'         @122'under 1.50'  @136'under 1.85'
//@3'Total Families:'                            @45   P90i1  &f11  @58 P90i2  &f10 @70 diff0   &f10  @82 PCT61i22 &f10  @94 PCT61i42 &f10 @106 PCT61i62 &f10   @121 CT150u0  &f11 @135 CT185u0  &f11
 /@3'  Married-Couple Families:'                 @45 TotAll1  &f11  @58 P90i3  &f10 @70 diff1   &f10  @82 PCT61i23 &f10  @94 PCT61i43 &f10 @106 PCT61i63 &f10   @121 CT150u1  &f11 @135 CT185u1  &f11
//@3'   With Related Children under 18 Yrs:'     @45 TotAll2  &f11  @58 P90i4  &f10 @70 diff2   &f10  @82 PCT61i24 &f10  @94 PCT61i44 &f10 @106 PCT61i64 &f10   @121 CT150u2  &f11 @135 CT185u2  &f11
 /@3'     Under 5 Years Only'                    @45 TotAll3  &f11  @58 P90i5  &f10 @70 diff3   &f10  @82 PCT61i25 &f10  @94 PCT61i45 &f10 @106 PCT61i65 &f10   @121 CT150u3  &f11 @135 CT185u3  &f11
 /@3'     Under 5 Years and 5 to 17 Years'       @45 TotAll4  &f11  @58 P90i6  &f10 @70 diff4   &f10  @82 PCT61i26 &f10  @94 PCT61i46 &f10 @106 PCT61i66 &f10   @121 CT150u4  &f11 @135 CT185u4  &f11
 /@3'     5 to 17 Years Only'                    @45 TotAll5  &f11  @58 P90i7  &f10 @70 diff5   &f10  @82 PCT61i27 &f10  @94 PCT61i47 &f10 @106 PCT61i67 &f10   @121 CT150u5  &f11 @135 CT185u5  &f11
 /@3'    No Related Children under 18 Years'     @45 TotAll6  &f11  @58 P90i8  &f10 @70 diff6   &f10  @82 PCT61i28 &f10  @94 PCT61i48 &f10 @106 PCT61i68 &f10   @121 CT150u6  &f11 @135 CT185u6  &f11
//@3' Other Families:'                           @45 TotAll7  &f11  @58 P90i9  &f10 @70 diff7   &f10  @82 PCT61i29 &f10  @94 PCT61i49 &f10 @106 PCT61i69 &f10   @121 CT150u7  &f11 @135 CT185u7  &f11
//@3'  Male Householder, No Wife Present:'       @45 TotAll8  &f11  @58 P90i10 &f10 @70 diff8   &f10  @82 PCT61i30 &f10  @94 PCT61i50 &f10 @106 PCT61i70 &f10   @121 CT150u8  &f11 @135 CT185u8  &f11
 /@3'    With Related Children under 18 Yrs:'    @45 TotAll9  &f11  @58 P90i11 &f10 @70 diff9   &f10  @82 PCT61i31 &f10  @94 PCT61i51 &f10 @106 PCT61i71 &f10   @121 CT150u9  &f11 @135 CT185u9  &f11
 /@3'     Under 5 Years Only'                    @45 TotAll10 &f11  @58 P90i12 &f10 @70 diff10  &f10  @82 PCT61i32 &f10  @94 PCT61i52 &f10 @106 PCT61i72 &f10   @121 CT150u10 &f11 @135 CT185u10 &f11
 /@3'     Under 5 Years and 5 to 17 Years'       @45 TotAll11 &f11  @58 P90i13 &f10 @70 diff11  &f10  @82 PCT61i33 &f10  @94 PCT61i53 &f10 @106 PCT61i73 &f10   @121 CT150u11 &f11 @135 CT185u11 &f11
 /@3'     5 to 17 Years Only'                    @45 TotAll12 &f11  @58 P90i14 &f10 @70 diff12  &f10  @82 PCT61i34 &f10  @94 PCT61i54 &f10 @106 PCT61i74 &f10   @121 CT150u12 &f11 @135 CT185u12 &f11
 /@3'    No Related Children under 18 Years'     @45 TotAll13 &f11  @58 P90i15 &f10 @70 diff13  &f10  @82 PCT61i35 &f10  @94 PCT61i55 &f10 @106 PCT61i75 &f10   @121 CT150u13 &f11 @135 CT185u13 &f11
//@3'  Female Householder, No Husband Present:'  @45 TotAll14 &f11  @58 P90i16 &f10 @70 diff14  &f10  @82 PCT61i36 &f10  @94 PCT61i56 &f10 @106 PCT61i76 &f10   @121 CT150u14 &f11 @135 CT185u14 &f11
 /@3'    With Related Children under 18 Yrs:'    @45 TotAll15 &f11  @58 P90i17 &f10 @70 diff15  &f10  @82 PCT61i37 &f10  @94 PCT61i57 &f10 @106 PCT61i77 &f10   @121 CT150u15 &f11 @135 CT185u15 &f11
 /@3'      Under 5 Years Only'                   @45 TotAll16 &f11  @58 P90i18 &f10 @70 diff16  &f10  @82 PCT61i38 &f10  @94 PCT61i58 &f10 @106 PCT61i78 &f10   @121 CT150u16 &f11 @135 CT185u16 &f11
 /@3'      Under 5 Years and 5 to 17 Years'      @45 TotAll17 &f11  @58 P90i19 &f10 @70 diff17  &f10  @82 PCT61i39 &f10  @94 PCT61i59 &f10 @106 PCT61i79 &f10   @121 CT150u17 &f11 @135 CT185u17 &f11
 /@3'      5 to 17 Years Only'                   @45 TotAll18 &f11  @58 P90i20 &f10 @70 diff18  &f10  @82 PCT61i40 &f10  @94 PCT61i60 &f10 @106 PCT61i80 &f10   @121 CT150u18 &f11 @135 CT185u18 &f11
 /@3'    No Related Children under 18 Years'     @45 TotAll19 &f11  @58 P90i21 &f10 @70 diff19  &f10  @82 PCT61i41 &f10  @94 PCT61i61 &f10 @106 PCT61i81 &f10   @121 CT150u19 &f11 @135 CT185u19 &f11
;

LINK HeadFoot ;
END ;  *<-----------of code to generate 8th page----;
RETURN ;