secprof:

/* Code to produce Secondary Tables from Census 2000 Summary File 3 */
/* Page 1 of 4 contains tables: P12, P14, P16, and P39              */
/* Page 2 of 4 contains tables: P19, P20, P22, and P23              */
/* Page 3 of 4 contains tables: P24, P25, P32, P34, and P35         */
/* Page 4 of 4 contains tables: P40, P41, and P42                   */
/* Xan Stevens, Policy Research Institute, The University of Kansas */
/* email: xan@ku.edu                   URL: http://www.ku.edu/pri   */

/* 6/21/02 changed 2 var names to eliminate conflict with Income profile--rw */
/* 7/15/02 fixed some bugs including nonfam totals in P12--rw */

* do all 4 pages if _pages is null, blank or ALL ;
IF _pages IN ('',' ','all','ALL') THEN _pages='1234' ;
IF INDEX(_pages,'1') THEN DO;

/* ----- START PAGE 1 of 4 -----*/

%PutTitle(
%STR(Secondary Profile 1: HOUSEHOLD TYPE BY CHILDREN AND HOUSEHOLD SIZE; VETERAN STATUS BY SEX),2NDRY-1);


* Draw horizontal lines;
PUT #32 @2 106*'_';
PUT #47 @2 147*'_';

* Draw (internal) vertical line;
do _i_=6 to 47;
    PUT #_i_ @107 '|';
    end;

* Generate table P12;
* calculate pct for table where pct=p12ix/p12i1 for all entries;
array hshld{45} p12i1-p12i31 p10i6-p10i16 p14i9 p10i2 p10i17 ;
array hshpct{45};

do i=1 to 45;
    if p12i1=0 then hshpct{i}=.;
        else hshpct{i}=hshld{i}/p12i1*100;
end;

PUT #6
      @3 'P12. HOUSEHOLDS BY AGE OF HOUSEHOLDER BY HOUSEHOLD TYPE BY PRESENCE OF OWN CHILDREN UNDER 18 YEARS'
    / @3 'Universe: Households'
    /
    /                                         @48 '   Householder'    @69 '   Householder'   @89 '   Householder'
    /                                         @48 '---- Any Age ---'  @69 '----15 to 64----' @89 '---65 and Over---'
    /
    / @3 'All types of households:'          @46 p12i1 comma11. @59 hshpct1 5.1 @67 p12i2 comma11. @80 hshpct2 5.1 @88 p12i17 comma11. @101 hshpct17 5.1
    /
    / @4 'Family households:'                @46 p10i6 comma11. @59 hshpct32 5.1 @67 p12i3 comma11. @80 hshpct3 5.1 @88 p12i18 comma11. @101 hshpct18 5.1
   // @5 'Married couple families:'          @46 p10i7 comma11. @59 hshpct33 5.1 @67 p12i4 comma11. @80 hshpct4 5.1 @88 p12i19 comma11. @101 hshpct19 5.1
    / @6 'With own children under 18 years'  @46 p10i8 comma11. @59 hshpct34 5.1 @67 p12i5 comma11. @80 hshpct5 5.1 @88 p12i20 comma11. @101 hshpct20 5.1
    / @6 'No own children under 18 years'    @46 p10i9 comma11. @59 hshpct35 5.1 @67 p12i6 comma11. @80 hshpct6 5.1 @88 p12i21 comma11. @101 hshpct21 5.1
    /
    / @5 'Other families:'                   @46 p10i10 comma11. @59 hshpct36 5.1 @67 p12i7 comma11. @80 hshpct7 5.1 @88 p12i22 comma11. @101 hshpct22 5.1
    / @6 'Male householder, no wife present:'@46 p10i11 comma11. @59 hshpct37 5.1 @67 p12i8 comma11. @80 hshpct8 5.1 @88 p12i23 comma11. @101 hshpct23 5.1
    / @7 'With own children under 18 years'  @46 p10i12 comma11. @59 hshpct38 5.1 @67 p12i9 comma11. @80 hshpct9 5.1 @88 p12i24 comma11. @101 hshpct24 5.1
    / @7 'No own children under 18 years'    @46 p10i13 comma11. @59 hshpct39 5.1 @67 p12i10 comma11. @80 hshpct10 5.1 @88 p12i25 comma11. @101 hshpct25 5.1
    / @6 'Female householder, no husband present:'   @46 p10i14 comma11. @59 hshpct40 5.1 @67 p12i11 comma11. @80 hshpct11 5.1 @88 p12i26 comma11. @101 hshpct26 5.1
    / @7 'With own children under 18 years'  @46 p10i15 comma11. @59 hshpct41 5.1 @67 p12i12 comma11. @80 hshpct12 5.1 @88 p12i27 comma11. @101 hshpct27 5.1
    / @7 'No own children under 18 years'    @46 p10i16 comma11. @59 hshpct42 5.1 @67 p12i13 comma11. @80 hshpct13 5.1 @88 p12i28 comma11. @101 hshpct28 5.1
    /
    / @4 'Nonfamily households:'             @46 p14i9  comma11. @59 hshpct43 5.1 @67 p12i14 comma11. @80 hshpct14 5.1 @88 p12i29 comma11. @101 hshpct29 5.1
    / @5 'Householder living alone'          @46 p10i2  comma11. @59 hshpct44 5.1 @67 p12i15 comma11. @80 hshpct15 5.1 @88 p12i30 comma11. @101 hshpct30 5.1
    / @5 'Householder not living alone'      @46 p10i17 comma11. @59 hshpct45 5.1 @67 p12i16 comma11. @80 hshpct16 5.1 @88 p12i31 comma11. @101 hshpct31 5.1
    ;
    * END of table P12;

    * generate table P16 ;

    totun3=  p16i3 + p16i12 + p16i20;
    tot3_4=  p16i4 + p16i13 + p16i21;
    tot5=    p16i5 + p16i14 + p16i22;
    tot6_11= p16i6 + p16i15 + p16i23;
    tot12_13=p16i7 + p16i16 + p16i24;
    tot14=   p16i8 + p16i17 + p16i25;
    tot15_17=p16i9 + p16i18 + p16i26;

    array child {33} p16i1-p16i26 totun3 tot3_4 tot5 tot6_11 tot12_13 tot14 tot15_17;
    array cpct {33};

    do i=1 to 33;
    if p16i1=0 then cpct{i}=.;
        else cpct{i}=child{i}/p16i1*100;
    end;

PUT #33
  @3 'P16. OWN CHILDREN UNDER 18 BY FAMILY TYPE BY AGE'
/ @3 'Universe: Own Children under 18 years'
/ @68 '----------In Other Families---------'
/       @27 '--In All Types--' @46 'In Married Couple' @67 'Male Householder,' @86 'Female Householder,'
/       @27 '---of Families--' @47 '----Families----' @67 ' No Wife Present' @86 'No Husband Present'
/ @3 'Total under 18:'  @26 p16i1 comma11.      @38 cpct1 5.1 @46 p16i2 comma11. @58 cpct2 5.1 @66 p16i11 comma11. @78 cpct11 5.1 @86 p16i19 comma11. @98 cpct19 5.1
/ @5 'Under 3 years'    @26 totun3 comma11.     @38 cpct27 5.1 @46 p16i3 comma11. @58 cpct3 5.1 @66 p16i12 comma11. @78 cpct12 5.1 @86 p16i20 comma11. @98 cpct20 5.1
/ @5 '3 and 4 years'    @26 tot3_4 comma11.     @38 cpct28 5.1 @46 p16i4 comma11. @58 cpct4 5.1 @66 p16i13 comma11. @78 cpct13 5.1 @86 p16i21 comma11. @98 cpct21 5.1
/ @5 '5 years'          @26 tot5 comma11.       @38 cpct29 5.1 @46 p16i5 comma11. @58 cpct5 5.1 @66 p16i14 comma11. @78 cpct14 5.1 @86 p16i22 comma11. @98 cpct22 5.1
/ @5 '6 to 11 years'    @26 tot6_11 comma11.    @38 cpct30 5.1 @46 p16i6 comma11. @58 cpct6 5.1 @66 p16i15 comma11. @78 cpct15 5.1 @86 p16i23 comma11. @98 cpct23 5.1
/ @5 '12 and 13 years'  @26 tot12_13 comma11.   @38 cpct31 5.1 @46 p16i7 comma11. @58 cpct7 5.1 @66 p16i16 comma11. @78 cpct16 5.1 @86 p16i24 comma11. @98 cpct24 5.1
/ @5 '14 years'         @26 tot14 comma11.      @38 cpct32 5.1 @46 p16i8 comma11. @58 cpct8 5.1 @66 p16i17 comma11. @78 cpct17 5.1 @86 p16i25 comma11. @98 cpct25 5.1
/ @5 '15 to 17 years'   @26 tot15_17 comma11.   @38 cpct33 5.1 @46 p16i9 comma11. @58 cpct9 5.1 @66 p16i18 comma11. @78 cpct18 5.1 @86 p16i26 comma11. @98 cpct26 5.1
;
*end table P16;

*generate table P14;

tot2=p14i3+p14i11;
tot3=p14i4+p14i12;
tot4=p14i5+p14i13;
tot5=p14i6+p14i14;
tot6=p14i7+p14i15;
tot7=p14i8+p14i16;

array p14{22} p14i1-p14i16 tot2-tot7;
array p14pct{22};

do i=1 to 22;
    if p14i1=0 then p14pct{i}=.;
        else p14pct{i}=p14{i}/p14i1*100;
end;

PUT #6
      @108 'P14. HOUSEHOLDS BY TYPE BY HOUSEHOLD SIZE'
    / @108 'Universe: Households'
    /
    /                                                @144 'Pct.'
    / @108 'All households:'     @131 p14i1 comma11.@143 p14pct1 5.1
    / @109 '1-person households' @131 p14i10 comma11.@143 p14pct10 5.1
    / @109 '2-person households' @131 tot2 comma11. @143 p14pct17 5.1
    / @109 '3-person households' @131 tot3 comma11. @143 p14pct18 5.1
    / @109 '4-person households' @131 tot4 comma11. @143 p14pct19 5.1
    / @109 '5-person households' @131 tot5 comma11. @143 p14pct20 5.1
    / @109 '6-person households' @131 tot6 comma11. @143 p14pct21 5.1
    / @109 '7-or-more person'
    / @110 'households'          @131 tot7 comma11. @143 p14pct22 5.1
    /
    / @108 'Family households:'  @131 p14i2 comma11. @143 p14pct2 5.1
    / @109 '2-person households' @131 p14i3 comma11. @143 p14pct3 5.1
    / @109 '3-person households' @131 p14i4 comma11. @143 p14pct4 5.1
    / @109 '4-person households' @131 p14i5 comma11. @143 p14pct5 5.1
    / @109 '5-person households' @131 p14i6 comma11. @143 p14pct6 5.1
    / @109 '6-person households' @131 p14i7 comma11. @143 p14pct7 5.1
    / @109 '7-or-more person'
    / @110 'households'          @131 p14i8 comma11. @143 p14pct8 5.1
    /
    / @108 'Nonfamily households:'@131 p14i9 comma11. @143 p14pct9 5.1
    / @109 '1-person households' @131 p14i10 comma11. @143 p14pct10 5.1
    / @109 '2-person households' @131 p14i11 comma11. @143 p14pct11 5.1
    / @109 '3-person households' @131 p14i12 comma11. @143 p14pct12 5.1
    / @109 '4-person households' @131 p14i13 comma11. @143 p14pct13 5.1
    / @109 '5-person households' @131 p14i14 comma11. @143 p14pct14 5.1
    / @109 '6-person households' @131 p14i15 comma11. @143 p14pct15 5.1
    / @109 '7-or-more person'
    / @110 'households'          @131 p14i16 comma11. @143 p14pct16 5.1
    ;
    *end table P14;

*generate table P39;

totma = p39i4 + p39i9;
totmc = p39i5 + p39i10;
totmv = p39i6 + p39i11;
totmn = p39i7 + p39i12;
totfa = p39i15 + p39i20;
totfc = p39i16 + p39i21;
totfv = p39i17 + p39i22;
totfn = p39i18 + p39i23;

totaXan = totma + totfa;
totcXan = totmc + totfc;
totv = totmv + totfv;
totn = totmn + totfn;

tota18_64 = p39i4 + p39i15;
totc18_64 = p39i5 + p39i16;
totv18_64 = p39i6 + p39i17;
totn18_64 = p39i7 + p39i18;
totgrand18_64 = tota18_64+totc18_64 ;

tota65 = p39i9 + p39i20;
totc65 = p39i10 + p39i21;
totv65 = p39i11 + p39i22;
totn65 = p39i12 + p39i23;
totgrand65 = tota65 + totc65 ;

PUT #49
      @3 'P39. ARMED FORCES STATUS BY VETERAN STATUS BY SEX BY AGE'
    / @3 'Universe: Population 18 years and over'
    /
    / @27 '--------------Total-------------' @67 '---------18 to 64 Years---------' @106 '--------65 Years and over---------'
    /                       @28 'Total' @42 'Male' @52 'Female' @69 'Total' @81 'Male' @92 'Female' @109 'Total' @122 'Male' @133 'Female'
    / @3 'Total pop. 18+:'  @23 p39i1 comma11.   @36 p39i2 comma11. @48 p39i13 comma11. @64 totgrand18_64 comma11. @76 p39i3 comma11. @88 p39i14 comma11. @104 totgrand65 comma11. @116 p39i8 comma11. @129 p39i19 comma11. 
    / @5 'In armed forces'  @23 totaXan comma11. @36 totma comma11. @48 totfa comma11. @64 tota18_64 comma11. @76 p39i4 comma11. @88 p39i15 comma11. @104 tota65 comma11. @116 p39i9 comma11. @129 p39i20 comma11.
    / @5 'Civilian:'        @23 totcXan comma11. @36 totmc comma11. @48 totfc comma11. @64 totc18_64 comma11. @76 p39i5 comma11. @88 p39i16 comma11. @104 totc65 comma11. @116 p39i10 comma11. @129 p39i21 comma11.
    / @6 'Veteran'          @23 totv comma11.    @36 totmv comma11. @48 totfv comma11. @64 totv18_64 comma11. @76 p39i6 comma11. @88 p39i17 comma11. @104 totv65 comma11. @116 p39i11 comma11. @129 p39i22 comma11.
    / @6 'Nonveteran'       @23 totn comma11.    @36 totmn comma11. @48 totfn comma11. @64 totn18_64 comma11. @76 p39i7 comma11. @88 p39i18 comma11. @104 totn65 comma11. @116 p39i12 comma11. @129 p39i23 comma11.
    ;

    link HeadFoot;
    end;     /* ------- END PAGE 1 of 4 ------ */

/* ----- START PAGE 2 of 4 -----*/
IF INDEX(_pages,'2') THEN DO;
%PutTitle(
%STR(Secondary Profile 2: LANGUAGE SPOKEN BY AGE; HOUSEHOLD LANGUAGE; FOREIGN-BORN POPULATION),2NDRY-2);


* Draw horizontal lines;
PUT #37 @2 147*'_' ;

* Draw (internal) vertical lines;
do _i_=38 to 61;
    PUT #_i_ @56 '|' @102 '|' ;
end;

* generate table p19;

tote1 = p19i3 + p19i25 + p19i47;

tots1 = p19i4 + p19i26 + p19i48;
tots2 = p19i5 + p19i27 + p19i49;
tots3 = p19i6 + p19i28 + p19i50;
tots4 = p19i7 + p19i29 + p19i51;
tots5 = p19i8 + p19i30 + p19i52;

totie1 = p19i9 + p19i31 + p19i53;
totie2 = p19i10 + p19i32 + p19i54;
totie3 = p19i11 + p19i33 + p19i55;
totie4 = p19i12 + p19i34 + p19i56;
totie5 = p19i13 + p19i35 + p19i57;

totap1 = p19i14 + p19i36 + p19i58;
totap2 = p19i15 + p19i37 + p19i59;
totap3 = p19i16 + p19i38 + p19i60;
totap4 = p19i17 + p19i39 + p19i61;
totap5 = p19i18 + p19i40 + p19i62;

toto1 = p19i19 + p19i41 + p19i63;
toto2 = p19i20 + p19i42 + p19i64;
toto3 = p19i21 + p19i43 + p19i65;
toto4 = p19i22 + p19i44 + p19i66;
toto5 = p19i23 + p19i45 + p19i67;

array lang{88} p19i1-p19i67 tote1 tots1-tots5 totie1-totie5 totap1-totap5 toto1-toto5;
array lpct{88};

do i=1 to 88;
    if p19i1=0 then lpct{i}=.;
        else lpct{i}=lang{i}/p19i1*100;
end;

PUT #6
      @3 'P19. LANGUAGE SPOKEN AT HOME AND ABILITY TO SPEAK ENGLISH BY AGE'
    / @3 'Universe: Population 5 years old and over'
    /
    /                                          @45 'All Ages'    @57 'Pct.'      @72 '5 to 17'   @83 'Pct.'       @98 '18 to 64'   @109 'Pct.'      @122 '65 & Over'    @136 'Pct.'
   // @3 'Total population 5 and over:'     @42 p19i1 comma11. @55 lpct1 5.1 @68 p19i2 comma11. @82 lpct2 5.1 @95 p19i24 comma11. @108 lpct24 5.1 @120 p19i46 comma11. @135 lpct46 5.1
    / @5 'Speak only English'               @42 tote1 comma11. @55 lpct68 5.1 @68 p19i3 comma11. @82 lpct3 5.1 @95 p19i25 comma11. @108 lpct25 5.1 @120 p19i47 comma11. @135 lpct47 5.1
    /
    / @5 'Speak Spanish:'                   @42 tots1 comma11. @55 lpct69 5.1 @68 p19i4 comma11. @82 lpct4 5.1 @95 p19i26 comma11. @108 lpct26 5.1 @120 p19i48 comma11. @135 lpct48 5.1
    / @6 'Speak English "very well"'        @42 tots2 comma11. @55 lpct70 5.1 @68 p19i5 comma11. @82 lpct5 5.1 @95 p19i27 comma11. @108 lpct27 5.1 @120 p19i49 comma11. @135 lpct49 5.1
    / @6 'Speak English "well"'             @42 tots3 comma11. @55 lpct71 5.1 @68 p19i6 comma11. @82 lpct6 5.1 @95 p19i28 comma11. @108 lpct28 5.1 @120 p19i50 comma11. @135 lpct50 5.1
    / @6 'Speak English "not well"'         @42 tots4 comma11. @55 lpct72 5.1 @68 p19i7 comma11. @82 lpct7 5.1 @95 p19i29 comma11. @108 lpct29 5.1 @120 p19i51 comma11. @135 lpct51 5.1
    / @6 'Speak English "not at all"'       @42 tots5 comma11. @55 lpct73 5.1 @68 p19i8 comma11. @82 lpct8 5.1 @95 p19i30 comma11. @108 lpct30 5.1 @120 p19i52 comma11. @135 lpct52 5.1
    /
    / @5 'Speak other Indo-European lang.:' @42 totie1 comma11. @55 lpct74 5.1 @68 p19i9 comma11. @82 lpct9 5.1 @95 p19i31 comma11. @108 lpct31 5.1 @120 p19i53 comma11. @135 lpct53 5.1
    / @6 'Speak English "very well"'        @42 totie2 comma11. @55 lpct75 5.1 @68 p19i10 comma11. @82 lpct10 5.1 @95 p19i32 comma11. @108 lpct32 5.1 @120 p19i54 comma11. @135 lpct54 5.1
    / @6 'Speak English "well"'             @42 totie3 comma11. @55 lpct76 5.1 @68 p19i11 comma11. @82 lpct11 5.1 @95 p19i33 comma11. @108 lpct33 5.1 @120 p19i55 comma11. @135 lpct55 5.1
    / @6 'Speak English "not well"'         @42 totie4 comma11. @55 lpct77 5.1 @68 p19i12 comma11. @82 lpct12 5.1 @95 p19i34 comma11. @108 lpct34 5.1 @120 p19i56 comma11. @135 lpct56 5.1
    / @6 'Speak English "not at all"'       @42 totie5 comma11. @55 lpct78 5.1 @68 p19i13 comma11. @82 lpct13 5.1 @95 p19i35 comma11. @108 lpct35 5.1 @120 p19i57 comma11. @135 lpct57 5.1
    /
    / @5 'Speak Asian & Pacific Island lang.:'@42 totap1 comma11. @55 lpct79 5.1 @68 p19i14 comma11. @82 lpct14 5.1 @95 p19i36 comma11. @108 lpct36 5.1 @120 p19i58 comma11. @135 lpct58 5.1
    / @6 'Speak English "very well"'        @42 totap2 comma11. @55 lpct80 5.1 @68 p19i15 comma11. @82 lpct15 5.1 @95 p19i37 comma11. @108 lpct37 5.1 @120 p19i59 comma11. @135 lpct59 5.1
    / @6 'Speak English "well"'             @42 totap3 comma11. @55 lpct81 5.1 @68 p19i16 comma11. @82 lpct16 5.1 @95 p19i38 comma11. @108 lpct38 5.1 @120 p19i60 comma11. @135 lpct60 5.1
    / @6 'Speak English "not well"'         @42 totap4 comma11. @55 lpct82 5.1 @68 p19i17 comma11. @82 lpct17 5.1 @95 p19i39 comma11. @108 lpct39 5.1 @120 p19i61 comma11. @135 lpct61 5.1
    / @6 'Speak English "not at all"'       @42 totap5 comma11. @55 lpct83 5.1 @68 p19i18 comma11. @82 lpct18 5.1 @95 p19i40 comma11. @108 lpct40 5.1 @120 p19i62 comma11. @135 lpct62 5.1
    /
    / @5 'Speak other language:'            @42 toto1 comma11. @55 lpct84 5.1 @68 p19i19 comma11. @82 lpct19 5.1 @95 p19i41 comma11. @108 lpct41 5.1 @120 p19i63 comma11. @135 lpct63 5.1
    / @6 'Speak English "very well"'        @42 toto2 comma11. @55 lpct85 5.1 @68 p19i20 comma11. @82 lpct20 5.1 @95 p19i42 comma11. @108 lpct42 5.1 @120 p19i64 comma11. @135 lpct64 5.1
    / @6 'Speak English "well"'             @42 toto3 comma11. @55 lpct86 5.1 @68 p19i21 comma11. @82 lpct21 5.1 @95 p19i43 comma11. @108 lpct43 5.1 @120 p19i65 comma11. @135 lpct65 5.1
    / @6 'Speak English "not well"'         @42 toto4 comma11. @55 lpct87 5.1 @68 p19i22 comma11. @82 lpct22 5.1 @95 p19i44 comma11. @108 lpct44 5.1 @120 p19i66 comma11. @135 lpct66 5.1
    / @6 'Speak English "not at all"'       @42 toto5 comma11. @55 lpct88 5.1 @68 p19i23 comma11. @82 lpct23 5.1 @95 p19i45 comma11. @108 lpct45 5.1 @120 p19i67 comma11. @135 lpct67 5.1
    ;
    * end table p19;

    * generate table P20;

    array hlang{14} p20i1-p20i14;
    array hlpct{14};

    do i=1 to 14;
    if p20i1=0 then hlpct{i}=.;
        else hlpct{i}=hlang{i}/p20i1*100;
    end;

    PUT #38
      @3 'P20. HOUSEHOLD LANGUAGE BY LINGUISTIC ISOLATION'
    / @3 'Universe: Households'
    /
    /                                                       @50 'Pct.'
    / @3 'Total households:'            @37 p20i1 comma11. @49 hlpct1 5.1
    /
    / @5 'English'                      @37 p20i2 comma11. @49 hlpct2 5.1
    /
    / @5 'Spanish:'                     @37 p20i3 comma11. @49 hlpct3 5.1
    / @6 'Linguistically isolated'      @37 p20i4 comma11. @49 hlpct4 5.1
    / @6 'Not linguistically isolated'  @37 p20i5 comma11. @49 hlpct5 5.1
    /
    / @5 'Other Indo-European language:'@37 p20i6 comma11. @49 hlpct6 5.1
    / @6 'Linguistically isolated'      @37 p20i7 comma11. @49 hlpct7 5.1
    / @6 'Not linguistically isolated'  @37 p20i8 comma11. @49 hlpct8 5.1
    /
    / @5 'Asian or Pacific Island lang.:'@37 p20i9 comma11. @49 hlpct9 5.1
    / @6 'Linguistically isolated'       @37 p20i10 comma11. @49 hlpct10 5.1
    / @6 'Not linguistically isolated'   @37 p20i11 comma11. @49 hlpct11 5.1
    /
    / @5 'Other language:'              @37 p20i12 comma11. @49 hlpct12 5.1
    / @6 'Linguistically isolated'      @37 p20i13 comma11. @49 hlpct13 5.1
    / @6 'Not linguistically isolated'  @37 p20i14 comma11. @49 hlpct14 5.1
    ;
    * end table P20;

    * generate table P22;

    array fyear{9} p22i1-p22i9;
    array ypct{9};

    do i=1 to 9;
    if p22i1=0 then ypct{i}=.;
        else ypct{i}=fyear{i}/p22i1*100;
    end;

    PUT #38
      @58 'P22. YEAR OF ENTRY FOR THE FOREIGN-BORN'
    / @58 'POPULATION'
    / @58 'Universe: Foreign-born population'
    /
    /
    /                                              @95 'Pct.'
    / @58 'Total foreign-born:'@81 p22i1 comma11. @94 ypct1 5.1
    / @60 '1995 to March 2000' @81 p22i2 comma11. @94 ypct2 5.1
    / @60 '1990 to 1994' @81 p22i3 comma11. @94 ypct3 5.1
    / @60 '1985 to 1989' @81 p22i4 comma11. @94 ypct4 5.1
    / @60 '1980 to 1984' @81 p22i5 comma11. @94 ypct5 5.1
    / @60 '1975 to 1979' @81 p22i6 comma11. @94 ypct6 5.1
    / @60 '1970 to 1974' @81 p22i7 comma11. @94 ypct7 5.1
    / @60 '1965 to 1969' @81 p22i8 comma11. @94 ypct8 5.1
    / @60 'Before 1965' @81 p22i9 comma11. @94 ypct9 5.1
    ;
    *end table P22;

    *generate table P23;

    array citz{10} p23i1-p23i10;
    array zpct{10};

    do i=1 to 10;
    if p23i1=0 then zpct{i}=.;
        else zpct{i}=citz{i}/p23i1*100;
    end;

    PUT #38
      @104 'P23. YEAR OF ENTRY BY CITIZENSHIP STATUS FOR'
    / @104 'THE FOREIGN-BORN POPULATION'
    / @104 'Universe: Foreign-born population'
    /
    /                                                    @142 'Pct.'
    / @104 'Total foreign-born:'    @128 p23i1 comma11. @141 zpct1 5.1
    / @106 'Year of entry 1990'
    / @106 'to March 2000:'         @128 p23i2 comma11. @141 zpct2 5.1
    / @107 'Naturalized citizen'    @128 p23i3 comma11. @141 zpct3 5.1
    / @107 'Not a citizen'          @128 p23i4 comma11. @141 zpct4 5.1
    /
    / @106 'Year of entry 1980'
    / @106 'to 1989:'               @128 p23i5 comma11. @141 zpct5 5.1
    / @107 'Naturalized citizen'    @128 p23i6 comma11. @141 zpct6 5.1
    / @107 'Not a citizen'          @128 p23i7 comma11. @141 zpct7 5.1
    /
    / @106 'Year of entry'
    / @106 'before 1980:'           @128 p23i8 comma11. @141 zpct8 5.1
    / @107 'Naturalized citizen'    @128 p23i9 comma11. @141 zpct9 5.1
    / @107 'Not a citizen'          @128 p23i10 comma11. @141 zpct10 5.1
    ;
    *end table P23;


    link HeadFoot;
    end;    /* ------- END of PAGE 2 of 4 -------- */

    /* -------- START PAGE 3 of 4 ----------*/
IF INDEX(_pages,'3') THEN DO;

%PutTitle(
%STR(Secondary Profile 3: COMMUTE TIME; TIME LEAVING HOME; VEHICLE OCCUPANCY; RESIDENCE IN 1995),2NDRY-3);

* Draw horizontal lines;
PUT #19 @2 89*'_';

PUT #26 @91 58*'_';

PUT #40 @91 58*'_';

* Draw (internal) vertical line;
do _i_=6 to 61;
    PUT #_i_ @90 '|';
end;

* generate table p32;

totpub = p32i3 + p32i6 + p32i9 + p32i12;
tototh = p32i4 + p32i7 + p32i10 + p32i13;

array travel{15} p32i1-p32i13 totpub tototh;
array ttpct{15};

do i=1 to 15;
    if p32i1=0 then ttpct{i}=.;
        else ttpct{i}=travel{i}/p32i1*100;
end;

if p32i1=0 then mean1=. ; else mean1=p33i1/p32i1 ;
if totpub=0 then mean2=. ; else mean2=(p33i3 + p33i6 + p33i9 + p33i12)/totpub ;
if tototh=0 then mean3=. ; else mean3=(p33i4 + p33i7 + p33i10 + p33i13)/tototh ;

PUT #6
      @3 'P32/P33. TRAVEL TIME TO WORK BY MEANS OF TRANSPORTATION TO WORK'
    / @3 'Universe: Workers 16 years old and over who did not work at home'
    /
    /                        @53 'Public'             @75 'Other'
    / @35 'Total' @43 'Pct.' @53 'Transp.' @63 'Pct.' @75 'Means' @83 'Pct.'
    / @3 'Total out-of-home workers:'@29 p32i1 comma11. @42 ttpct1 5.1 @49 totpub comma11. @62 ttpct14 5.1 @69 tototh comma11. @82 ttpct15 5.1
    / @5 'Less than 30 min.'         @29 p32i2 comma11. @42 ttpct2 5.1 @49 p32i3  comma11. @62 ttpct3 5.1  @69 p32i4 comma11.  @82 ttpct4 5.1
    / @5 '30 to 44 min.'             @29 p32i5 comma11. @42 ttpct5 5.1 @49 p32i6  comma11. @62 ttpct6 5.1  @69 p32i7 comma11.  @82 ttpct7 5.1
    / @5 '45 to 59 min.'             @29 p32i8 comma11. @42 ttpct8 5.1 @49 p32i9  comma11. @62 ttpct9 5.1  @69 p32i10 comma11. @82 ttpct10 5.1
    / @5 '60 or more min.'           @29 p32i11 comma11.@42 ttpct11 5.1@49 p32i12 comma11. @62 ttpct12 5.1 @69 p32i13 comma11. @82 ttpct13 5.1
   // @3 'Mean travel time to work:'    @34 mean1 5.0 ' minutes'            @54 mean2 5.0 ' minutes'            @74 mean3 5.0 ' minutes'
;
    * end table P32;

* generate table p25;

array res{35} p25i1-p25i35;
array rpct{35};

do i=1 to 35;
    if p25i1=0 then rpct{i}=.;
        else rpct{i}=res{i}/p25i1*100;
end;

PUT #20
      @3 'P25. RESIDENCE IN 1995 - MSA/PMSA LEVEL'
    / @3 'Universe: Population 5 years old and over'
    /                                                                @60 'Pct.'
    / @3 'Total population 5 years old and over:'@45 p25i1 comma11. @59 rpct1 5.1
    / @5 'Living in an MSA/PMSA in 2000:'    @45 p25i2 comma11. @59 rpct2 5.1
    / @6 'Same house in 1995'               @45 p25i3 comma11. @59 rpct3 5.1
    / @6 'Different house in 1995:'          @45 p25i4 comma11. @59 rpct4 5.1
    / @7 'In United States in 1995:'         @45 p25i5 comma11. @59 rpct5 5.1
    / @8 'Same MSA/PMSA in 1995:'            @45 p25i6 comma11. @59 rpct6 5.1
    / @9 'Central city'                     @45 p25i7 comma11. @59 rpct7 5.1
    / @9 'Remainder of this MSA/PMSA'       @45 p25i8 comma11. @59 rpct8 5.1
    / @8 'Different MSA/PMSA in 1995:'       @45 p25i9 comma11. @59 rpct9 5.1
    / @9 'Central city'                     @45 p25i10 comma11. @59 rpct10 5.1
    / @9 'Remainder of different MSA/PMSA'  @45 p25i11 comma11. @59 rpct11 5.1
    / @8 'Not in an MSA/PMSA in 1995'       @45 p25i12 comma11. @59 rpct12 5.1
    / @7 'In Puerto Rico in 1995:'           @45 p25i13 comma11. @59 rpct13 5.1
    / @8 'Same MSA/PMSA in 1995:'            @45 p25i14 comma11. @59 rpct14 5.1
    / @9 'Central city'                     @45 p25i15 comma11. @59 rpct15 5.1
    / @9 'Remainder of this MSA/PMSA'       @45 p25i16 comma11. @59 rpct16 5.1
    / @8 'Different MSA/PMSA in 1995:'       @45 p25i17 comma11. @59 rpct17 5.1
    / @9 'Central city'                     @45 p25i18 comma11. @59 rpct18 5.1
    / @9 'Remainder of different MSA/PMSA'  @45 p25i19 comma11. @59 rpct19 5.1
    / @8 'Not in an MSA/PMSA in 1995'       @45 p25i20 comma11. @59 rpct20 5.1
    / @7 'Elsewhere in 1995'                @45 p25i21 comma11. @59 rpct21 5.1
    /
    / @5 'Not living in an MSA/PMSA in 2000:'    @45 p25i22 comma11. @59 rpct22 5.1
    / @6 'Same house in 1995'                   @45 p25i23 comma11. @59 rpct23 5.1
    / @6 'Different house in 1995:'              @45 p25i24 comma11. @59 rpct24 5.1
    / @7 'In United States in 1995:'             @45 p25i25 comma11. @59 rpct25 5.1
    / @8 'In an MSA/PMSA in 1995:'               @45 p25i26 comma11. @59 rpct26 5.1
    / @9 'Central city'                         @45 p25i27 comma11. @59 rpct27 5.1
    / @9 'Remainder of MSA/PMSA'                @45 p25i28 comma11. @59 rpct28 5.1
    / @8 'Not in MSA/PMSA in 1995'              @45 p25i29 comma11. @59 rpct29 5.1
    / @7 'In Puerto Rico in 1995:'               @45 p25i30 comma11. @59 rpct30 5.1
    / @8 'In an MSA/PMSA in 1995:'               @45 p25i31 comma11. @59 rpct31 5.1
    / @9 'Central city'                         @45 p25i32 comma11. @59 rpct32 5.1
    / @9 'Remainder of MSA/PMSA'                @45 p25i33 comma11. @59 rpct33 5.1
    / @8 'Not in an MSA/PMSA in 1995'           @45 p25i34 comma11. @59 rpct34 5.1
    / @7 'Elsewhere in 1995'                    @45 p25i35 comma11. @59 rpct35 5.1
    ;
    * end table P25;

* generate table 34;

array timel{17} p34i1-p34i17;
array tpct{17};

do i=1 to 17;
    if p34i1=0 then tpct{i}=.;
        else tpct{i}=timel{i}/p34i1*100;
end;

PUT #6
      @92 'P34. TIME LEAVING HOME TO GO TO WORK'
    / @92 'Universe: Workers 16 years old and over'
    /                                                    @141 'Pct.'
    / @92 'Total workers 16 and over:'@127 p34i1 comma11. @140 tpct1 5.1
    / @94 'Did not work at home:'   @127 p34i2 comma11. @140 tpct2 5.1
    / @95 '12:00 a.m. to 4:59 a.m.' @127 p34i3 comma11. @140 tpct3 5.1
    / @95 '5:00 a.m. to 5:29 a.m.'  @127 p34i4 comma11. @140 tpct4 5.1
    / @95 '5:30 a.m. to 5:59 a.m.'  @127 p34i5 comma11. @140 tpct5 5.1
    / @95 '6:00 a.m. to 6:29 a.m.'  @127 p34i6 comma11. @140 tpct6 5.1
    / @95 '6:30 a.m. to 6:59 a.m.'  @127 p34i7 comma11. @140 tpct7 5.1
    / @95 '7:00 a.m. to 7:29 a.m.'  @127 p34i8 comma11. @140 tpct8 5.1
    / @95 '7:30 a.m. to 7:59 a.m.'  @127 p34i9 comma11. @140 tpct9 5.1
    / @95 '8:00 a.m. to 8:29 a.m.'  @127 p34i10 comma11. @140 tpct10 5.1
    / @95 '8:30 a.m. to 8:59 a.m.'  @127 p34i11 comma11. @140 tpct11 5.1
    / @95 '9:00 a.m. to 9:59 a.m.'  @127 p34i12 comma11. @140 tpct12 5.1
    / @95 '10:00 a.m. to 10:59 a.m.' @127 p34i13 comma11. @140 tpct13 5.1
    / @95 '11:00 a.m. to 11:59 a.m.' @127 p34i14 comma11. @140 tpct14 5.1
    / @95 '12:00 p.m. to 3:59 p.m.' @127 p34i15 comma11. @140 tpct15 5.1
    / @95 '4:00 p.m. to 11:59 p.m.' @127 p34i16 comma11. @140 tpct16 5.1
    / @94 'Worked at home'          @127 p34i17 comma11. @140 tpct17 5.1
    ;

    *end table P34;

*generate table P35;

array priv{10} p35i1-p35i10;
array vpct{10};

do i=1 to 10;
    if p35i1=0 then vpct{i}=.;
        else vpct{i}=priv{i}/p35i1*100;
end;

PUT #27
      @92 'P35. PRIVATE VEHICLE OCCUPANCY'
    / @92 'Universe: Workers 16 years old and over'
   // @92 'Total workers 16 and over:'  @127 p35i1 comma11. @140 vpct1 5.1
    / @94 'Car, truck, or van:'         @127 p35i2 comma11. @140 vpct2 5.1
    / @95 'Drove alone'                 @127 p35i3 comma11. @140 vpct3 5.1
    / @95 'Carpooled:'                  @127 p35i4 comma11. @140 vpct4 5.1
    / @96 '2-person carpool'            @127 p35i5 comma11. @140 vpct5 5.1
    / @96 '3-person carpool'            @127 p35i6 comma11. @140 vpct6 5.1
    / @96 '4-person carpool'            @127 p35i7 comma11. @140 vpct7 5.1
    / @96 '5- or 6-person carpool'      @127 p35i8 comma11. @140 vpct8 5.1
    / @96 '7- or more person carpool'   @127 p35i9 comma11. @140 vpct9 5.1
    / @94 'Other means (inc. worked at home)' @127 p35i10 comma11. @140 vpct10 5.1
    ;

    * end table P35;

* generate table P24;

array sres{18} p24i1-p24i18;
array spct{18};

do i=1 to 18;
    if p24i1=0 then spct{i}=.;
        else spct{i}=sres{i}/p24i1*100;
end;

PUT #41
      @92 'P24. RESIDENCE IN 1995 - STATE AND COUNTY LEVEL'
    / @92 'Universe: Population 5 years old and over'
   // @92 'Total population 5 and over:'@127 p24i1 comma11. @140 spct1 5.1
    / @94 'Same house in 1995'      @127 p24i2 comma11. @140 spct2 5.1
    / @94 'Different house in 1995:' @127 p24i3 comma11. @140 spct3 5.1
    / @95 'In United States in 1995:'@127 p24i4 comma11. @140 spct4 5.1
    / @96 'Same county'             @127 p24i5 comma11. @140 spct5 5.1
    / @96 'Different county:'        @127 p24i6 comma11. @140 spct6 5.1
    / @97 'Same state'              @127 p24i7 comma11. @140 spct7 5.1
    / @97 'Different state:'         @127 p24i8 comma11. @140 spct8 5.1
    / @98 'Northeast'               @127 p24i9 comma11. @140 spct9 5.1
    / @98 'Midwest'                 @127 p24i10 comma11. @140 spct10 5.1
    / @98 'South'                   @127 p24i11 comma11. @140 spct11 5.1
    / @98 'West'                    @127 p24i12 comma11. @140 spct12 5.1
    / @95 'In Puerto Rico in 1995:'  @127 p24i13 comma11. @140 spct13 5.1
    / @96 'Same municipio'          @127 p24i14 comma11. @140 spct14 5.1
    / @96 'Different municipio'     @127 p24i15 comma11. @140 spct15 5.1
    / @95 'Elsewhere in 1995:'       @127 p24i16 comma11. @140 spct16 5.1
    / @96 'U.S. Island Areas'       @127 p24i17 comma11. @140 spct17 5.1
    / @96 'Foreign country or at sea' @127 p24i18 comma11. @140 spct18 5.1
    ;

    * end table p24;

link HeadFoot;
end; /* ---------- END OF PAGE 3 of 4 -----------*/

/*---------------- START PAGE 4 of 4 -----------------*/
IF INDEX(_pages,'4') THEN DO;
%PutTitle(
%STR(Secondary Profile 4: DISABILITY STATUS AND TYPES OF DISABILITY; PERIOD OF MILITARY SERVICE),2NDRY-4);


* Draw horizontal lines;
PUT #41 @2 147*'_';

* Draw (internal) vertical line;
do _i_=6 to 41;
    PUT #_i_ @83 '|';
end;


* generate table P42;

totdisM = p42i4 + p42i7 + p42i14 + p42i21 + p42i24;
totdisF = p42i28 + p42i31 + p42i38 + p42i45 + p42i48;
totdis = totdisM + totdisF;

totnodisM = p42i5 + p42i10 + p42i17 + p42i22 + p42i25;
totnodisF = p42i29 + p42i34 + p42i41 + p42i46 + p42i49;
totnodis = totnodisM + totnodisF;

tot5_15 = p42i3 + p42i27;
dis5_15 = p42i4 + p42i28;
nodis5_15 = p42i5 + p42i29;

tot16_20 = p42i6 + p42i30;
dis16_20 = p42i7 + p42i31;
dis16_20e = p42i8 + p42i32;
dis16_20ne = p42i9 + p42i33;
nodis16_20 = p42i10 + p42i34;
nodis16_20e = p42i11 + p42i35;
nodis16_20ne = p42i12 + p42i36;

tot21_64 = p42i13 + p42i37;
dis21_64 = p42i14 + p42i38;
dis21_64e = p42i15 + p42i39;
dis21_64ne = p42i16 + p42i40;
nodis21_64 = p42i17 + p42i41;
nodis21_64e = p42i18 + p42i42;
nodis21_64ne = p42i19 + p42i43;

tot65_74 = p42i20 + p42i44;
dis65_74 = p42i21 + p42i45;
nodis65_74 = p42i22 + p42i46;

tot75 = p42i23 + p42i47;
dis75 = p42i24 + p42i48;
nodis75 = p42i25 + p42i49;

totdiseM = p42i8 + p42i15;
totdiseF = p42i32 + p42i39;
totdise = totdiseM + totdiseF;

totdisneM = p42i9 + p42i16;
totdisneF = p42i33 + p42i40;
totdisne = totdisneM + totdisneF;

totnodiseM = p42i11 + p42i18;
totnodiseF = p42i35 + p42i42;
totnodise = totnodiseM + totnodiseF;

totnodisneM = p42i12 + p42i19;
totnodisneF = p42i36 + p42i43;
totnodisne = totnodisneM + totnodisneF;



array disstat{90} p42i1-p42i49 totdis totdisM totdisF totnodis totnodisM totnodisF
                    tot5_15 dis5_15 nodis5_15 tot16_20 dis16_20 dis16_20e dis16_20ne
                    nodis16_20 nodis16_20e nodis16_20ne tot21_64 dis21_64 dis21_64e dis21_64ne
                    nodis21_64 nodis21_64e nodis21_64ne tot65_74 dis65_74 nodis65_74
                    tot75 dis75 nodis75 totdise totdiseM totdiseF totdisne totdisneM
                    totdisneF totnodise totnodiseM totnodiseF totnodisne totnodisneM
                    totnodisneF;
array dspct{90};

do i=1 to 90;
    if p42i1=0 then dspct{i}=.;
        else dspct{i}=disstat{i}/p42i1*100;
end;


PUT #6
      @3 'P42. DISABILITY STATUS BY EMPLOYMENT STATUS BY SEX BY AGE'
    / @3 'Universe: Civilian noninstitutionalized population 5 years old and over'
    /
    / @31 'Total' @38 'Pct.' @52 'Male' @58 'Pct.' @70 'Female' @78 'Pct.'
    / @3 'All age groups:'             @25 p42i1 comma11. @37 dspct1 5.1 @45 p42i2 comma11. @57 dspct2 5.1 @65 p42i26 comma11. @77 dspct26 5.1
    / @5 'With a disability:' @25 totdis comma11. @37 dspct50 5.1 @45 totdisM comma11. @57 dspct51 5.1 @65 totdisF comma11. @77 dspct52 5.1
    / @7 'Employed*'          @25 totdise comma11. @37 dspct79 5.1 @45 totdiseM comma11. @57 dspct80 5.1 @65 totdiseF comma11. @77 dspct81 5.1
    / @7 'Not employed*'      @25 totdisne comma11. @37 dspct82 5.1 @45 totdisneM comma11. @57 dspct83 5.1 @65 totdisneF comma11. @77 dspct84 5.1
    / @5 'No disability:'     @25 totnodis comma11. @37 dspct53 5.1 @45 totnodisM comma11. @57 dspct54 5.1 @65 totnodisF comma11. @77 dspct55 5.1
    / @7 'Employed*'          @25 totnodise comma11. @37 dspct85 5.1 @45 totnodiseM comma11. @57 dspct86 5.1 @65 totnodiseF comma11. @77 dspct87 5.1
    / @7 'Not employed*'      @25 totnodisne comma11. @37 dspct88 5.1 @45 totnodisneM comma11. @57 dspct89 5.1 @65 totnodisneF comma11. @77 dspct90 5.1
   // @3 '5 to 15 years:'     @25 tot5_15 comma11. @37 dspct56 5.1 @45 p42i3 comma11. @57 dspct3 5.1 @65 p42i27 comma11. @77 dspct27 5.1
    / @5 'With a disability:' @25 dis5_15 comma11. @37 dspct57 5.1 @45 p42i4 comma11. @57 dspct4 5.1 @65 p42i28 comma11. @77 dspct28 5.1
    / @5 'No disability'     @25 nodis5_15 comma11. @37 dspct58 5.1 @45 p42i5 comma11. @57 dspct5 5.1 @65 p42i29 comma11. @77 dspct29 5.1
    / @3 '16 to 20 years:'     @25 tot16_20 comma11. @37 dspct59 5.1 @45 p42i6 comma11. @57 dspct6 5.1 @65 p42i30 comma11. @77 dspct30 5.1
    / @5 'With a disability:' @25 dis16_20 comma11. @37 dspct60 5.1 @45 p42i7 comma11. @57 dspct7 5.1 @65 p42i31 comma11. @77 dspct31 5.1
    / @7 'Employed'          @25 dis16_20e comma11. @37 dspct61 5.1 @45 p42i8 comma11. @57 dspct8 5.1 @65 p42i32 comma11. @77 dspct32 5.1
    / @7 'Not employed'      @25 dis16_20ne comma11. @37 dspct62 5.1 @45 p42i9 comma11. @57 dspct9 5.1 @65 p42i33 comma11. @77 dspct33 5.1
    / @5 'No disability:'     @25 nodis16_20 comma11. @37 dspct63 5.1 @45 p42i10 comma11. @57 dspct10 5.1 @65 p42i34 comma11. @77 dspct34 5.1
    / @7 'Employed'          @25 nodis16_20e comma11. @37 dspct64 5.1 @45 p42i11 comma11. @57 dspct11 5.1 @65 p42i35 comma11. @77 dspct35 5.1
    / @7 'Not employed'      @25 nodis16_20ne comma11. @37 dspct65 5.1 @45 p42i12 comma11. @57 dspct12 5.1 @65 p42i36 comma11. @77 dspct36 5.1
    / @3 '21 to 64 years:'     @25 tot21_64 comma11. @37 dspct66 5.1 @45 p42i13 comma11. @57 dspct13 5.1 @65 p42i37 comma11. @77 dspct37 5.1
    / @5 'With a disability:' @25 dis21_64 comma11. @37 dspct67 5.1 @45 p42i14 comma11. @57 dspct14 5.1 @65 p42i38 comma11. @77 dspct38 5.1
    / @7 'Employed'          @25 dis21_64e comma11. @37 dspct68 5.1 @45 p42i15 comma11. @57 dspct15 5.1 @65 p42i39 comma11. @77 dspct39 5.1
    / @7 'Not employed'      @25 dis21_64ne comma11. @37 dspct69 5.1 @45 p42i16 comma11. @57 dspct16 5.1 @65 p42i40 comma11. @77 dspct40 5.1
    / @5 'No disability:'     @25 nodis21_64 comma11. @37 dspct70 5.1 @45 p42i17 comma11. @57 dspct17 5.1 @65 p42i41 comma11. @77 dspct41 5.1
    / @7 'Employed'          @25 nodis21_64e comma11. @37 dspct71 5.1 @45 p42i18 comma11. @57 dspct18 5.1 @65 p42i42 comma11. @77 dspct42 5.1
    / @7 'Not employed'      @25 nodis21_64ne comma11. @37 dspct72 5.1 @45 p42i19 comma11. @57 dspct19 5.1 @65 p42i43 comma11. @77 dspct43 5.1
    / @3 '65 to 74 years:'    @25 tot65_74 comma11. @37 dspct73 5.1 @45 p42i20 comma11. @57 dspct20 5.1 @65 p42i44 comma11. @77 dspct44 5.1
    / @5 'With a disability' @25 dis65_74 comma11. @37 dspct74 5.1 @45 p42i21 comma11. @57 dspct21 5.1 @65 p42i45 comma11. @77 dspct45 5.1
    / @5 'No disability'     @25 nodis65_74 comma11. @37 dspct75 5.1 @45 p42i22 comma11. @57 dspct22 5.1 @65 p42i46 comma11. @77 dspct46 5.1
    / @3 '75 years and over:' @25 tot75 comma11. @37 dspct76 5.1 @45 p42i23 comma11. @57 dspct23 5.1 @65 p42i47 comma11. @77 dspct47 5.1
    / @5 'With a disability' @25 dis75 comma11. @37 dspct77 5.1 @45 p42i24 comma11. @57 dspct24 5.1 @65 p42i48 comma11. @77 dspct48 5.1
    / @5 'No disability'     @25 nodis75 comma11. @37 dspct78 5.1 @45 p42i25 comma11. @57 dspct25 5.1 @65 p42i49 comma11. @77 dspct49 5.1
    ;
    *end table P42;

* generate table P41;
    sensory = p41i3 + p41i8 + p41i15;
    phys =  p41i4 + p41i9 + p41i16;
    mental = p41i5 + p41i10 + p41i17;
    self = p41i6 + p41i11 + p41i18;
    outside= p41i12 + p41i19;

    array dis{24} p41i1-p41i19 sensory phys mental self outside;
    array dpct{24};

    do i=1 to 24;
    if p41i1=0 then dpct{i}=.;
        else dpct{i}=dis{i}/p41i1*100;
    end;

    PUT #6
          @84 'P41. TYPES OF DISABILITY BY AGE FOR THE CIVILIAN'
        / @84 '     NONINSTITUTIONALIZED POPULATION'
        / @84 'Universe: Total disabilities tallied for the civilian'
        / @84 'noninstitutionalized population 5 years & over with disabilities'
        /                                                             @144 'Pct.'
        / @84 'Total disabilities tallied, all age groups:'  @130 p41i1 comma11.     @143 dpct1 5.1
        / @86 'Sensory disability'          @130 sensory comma11.   @143 dpct20 5.1
        / @86 'Physical disability'         @130 phys comma11.      @143 dpct21 5.1
        / @86 'Mental disability'           @130 mental comma11.    @143 dpct22 5.1
        / @86 'Self-care disability'        @130 self comma11.      @143 dpct23 5.1
        / @86 'Go-outside-home disability**'@130 outside comma11.   @143 dpct24 5.1
        / @86 'Employment disability*'      @130 p41i13 comma11.    @143 dpct13 5.1
       // @84 'Total disabilities tallied for 5 to 15 yrs:' @130 p41i2 comma11. @143 dpct2 5.1
        / @86 'Sensory disability'          @130 p41i3 comma11. @143 dpct3 5.1
        / @86 'Physical disability'         @130 p41i4 comma11. @143 dpct4 5.1
        / @86 'Mental disability'           @130 p41i5 comma11. @143 dpct5 5.1
        / @86 'Self-care disability'        @130 p41i6 comma11. @143 dpct6 5.1
       // @84 'Total disabilities tallied for 16 to 64 yrs:' @130 p41i7 comma11.  @143 dpct7 5.1
        / @86 'Sensory disability'          @130 p41i8 comma11.  @143 dpct8 5.1
        / @86 'Physical disability'         @130 p41i9 comma11.  @143 dpct9 5.1
        / @86 'Mental disability'           @130 p41i10 comma11. @143 dpct10 5.1
        / @86 'Self-care disability'        @130 p41i11 comma11. @143 dpct11 5.1
        / @86 'Go-outside-home disability'  @130 p41i12 comma11. @143 dpct12 5.1
        / @86 'Employment disability'       @130 p41i13 comma11. @143 dpct13 5.1
       // @84 'Total disabilities tallied for 65 years plus:'  @130 p41i14 comma11. @143 dpct14 5.1
        / @86 'Sensory disability'          @130 p41i15 comma11. @143 dpct15 5.1
        / @86 'Physical disability'         @130 p41i16 comma11. @143 dpct16 5.1
        / @86 'Mental disability'           @130 p41i17 comma11. @143 dpct17 5.1
        / @86 'Self-care disability'        @130 p41i18 comma11. @143 dpct18 5.1
        / @86 'Go-outside-home disability'  @130 p41i19 comma11. @143 dpct19 5.1
        ;

        * end table p41;

* generate table P40;

array mil{21} p40i1-p40i21;
array mpct{21};

do i=1 to 21;
    if p40i1=0 then mpct{i}=.;
        else mpct{i}=mil{i}/p40i1*100;
end;

do _i_=46 to 57;
    PUT #_i_ @71 ':';
end;

PUT #43
      @3 'P40. PERIOD OF MILITARY SERVICE FOR VETERAN CIVILIANS'
    / @3 'Universe: Civilian veterans 18 years old and over (' p40i1 : comma11. +(-1) ')'
    /                                                                  @65 'Pct.'
    / @3 'August 1990 or later:'                   @50 p40i2 comma11. @64 mpct2 5.1     @76 'Vietnam era, no Korean War, no World War II'                            @141 'Pct.'
    / @5 'Served in Vietnam era'                   @50 p40i3 comma11. @64 mpct3 5.1     @77 'no August 1990 or later'                       @123 p40i14 comma11.    @140 mpct14 5.1
    / @5 'No Vietnam era service:'                 @50 p40i4 comma11. @64 mpct4 5.1     @76 'Vietnam era and Korean War, no World War II'       
    / @7 'Served Sept. 1980 or later only:'        @50 p40i5 comma11. @64 mpct5 5.1     @77 'no August 1990 or later'                       @123 p40i15 comma11.    @140 mpct15 5.1 
    / @9 'Served under 2 years'                    @50 p40i6 comma11. @64 mpct6 5.1     @76 'Vietnam era, Korean War, and World War II'                 
    / @9 'Served 2 or more years'                  @50 p40i7 comma11. @64 mpct7 5.1     @77 'no August 1990 or later'                       @123 p40i16 comma11.    @140 mpct16 5.1
    / @7 'Served prior to September 1980'          @50 p40i8 comma11. @64 mpct8 5.1     @76 'February 1955 to July 1964 only'               @123 p40i17 comma11.    @140 mpct17 5.1
    / @3 'May 1975 to July 1990 only:'             @50 p40i9 comma11.   @64 mpct9 5.1   @76 'Korean War, no Vietnam era, no World War II'  @123 p40i18 comma11.     @140 mpct18 5.1
    / @5 'September 1980 to July 1990 only:'       @50 p40i10 comma11.  @64 mpct10 5.1  @76 'Korean War and World War II, no Vietnam era'   @123 p40i19 comma11.    @140 mpct19 5.1
    / @7 'Served under 2 years'                    @50 p40i11 comma11.  @64 mpct11 5.1  @76 'World War II, no Korean War, no Vietnam era'   @123 p40i20 comma11.    @140 mpct20 5.1
    / @7 'Served 2 or more years'                  @50 p40i12 comma11.  @64 mpct12 5.1  @76 'Other service only'                            @123 p40i21 comma11.    @140 mpct21 5.1
    / @5 'Other May 1975 to July 1990 service'     @50 p40i13 comma11.  @64 mpct13 5.1
    / @2 147*'_'
   // @3 '*  Employment status by disability status was determined only for the 16 to 64 year old population.'
    / @3 '** Go-outside-home disability status was determined only for the population 16 years old and over.'
   ;

    *end table P40;

    link HeadFoot;
    end;
        /* END OF PAGE 4 of 4 */

RETURN; 
